@@ -7,18 +7,9 @@
 #define ASTYLECONFIGDLG_H
 
 #include <wx/intl.h>
+#include "astylepredefinedstyles.h"
 #include "configurationpanel.h"
 
-enum AStylePredefinedStyle
-{
-  aspsAnsi = 0,
-  aspsKr,
-  aspsLinux,
-  aspsGnu,
-  aspsJava,
-  aspsCustom
-};
-
 class AstyleConfigDlg : public cbConfigurationPanel
 {
 	public:
@@ -28,6 +19,7 @@ class AstyleConfigDlg : public cbConfigurationPanel
 	protected:
         void OnStyleChange(wxCommandEvent& event);
         void OnPreview(wxCommandEvent& event);
+        void OnBreakLineChange(wxCommandEvent& event);
 
         virtual wxString GetTitle() const { return _("Source formatter"); }
         virtual wxString GetBitmapBaseName() const { return _T("astyle-plugin"); }
