@@ -3,9 +3,6 @@
  * http://www.gnu.org/licenses/gpl-3.0.html
  */
 
-#ifdef __WXMSW__
-// this compiler is valid only in windows
-
 #ifndef COMPILERMSVC_H
 #define COMPILERMSVC_H
 
@@ -16,8 +13,6 @@ class CompilerMSVC : public Compiler
 	public:
 		CompilerMSVC();
 		virtual ~CompilerMSVC();
-        virtual void Reset();
-		virtual void LoadDefaultRegExArray();
         virtual AutoDetectResult AutoDetectInstallationDir();
 	protected:
         Compiler * CreateCopy();
@@ -25,5 +20,3 @@ class CompilerMSVC : public Compiler
 };
 
 #endif // COMPILERMSVC_H
-
-#endif // __WXMSW__
