@@ -5,10 +5,10 @@
 #include <wx/sizer.h>
 #include <wx/grid.h>
 #include <wx/button.h>
-#include <wx/dialog.h>
+#include "scrollingdialog.h"
 //*)
 
-class avChangesDlg: public wxDialog
+class avChangesDlg: public wxScrollingDialog
 {
 	public:
 
