@@ -16,7 +16,7 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
-// RCS-ID: $Id: BrowseMarks.cpp 25 2008-01-02 20:13:48Z Pecan $
+// RCS-ID: $Id: BrowseMarks.cpp 8727 2012-12-30 21:41:02Z killerbot $
 #if defined(CB_PRECOMP)
 #include "sdk.h"
 #else
@@ -62,12 +62,10 @@ BrowseMarks::BrowseMarks(wxString fullPath )
     m_fileShortName = fname.GetFullName();
 
     //#if defined(LOGGING)
-    //LOGIT( _T("BrowseMarks[%s][%s]"),m_filePath.c_str() ,m_fileShortName.c_str() );
+    //LOGIT( _T("BT BrowseMarks[%s][%s]"),m_filePath.c_str() ,m_fileShortName.c_str() );
     //#endif
 
-    m_EdPosnArray.Alloc(MaxEntries);
-    for (int i=0; i < MaxEntries; ++i )
-    	m_EdPosnArray[i] = -1;
+    m_EdPosnArray.SetCount(MaxEntries, -1);     //patch 2886
     m_currIndex = 0;    //index of current entry
     m_lastIndex = MaxEntries-1;    //index for insertion of new browse marks
     m_pEdMgr = Manager::Get()->GetEditorManager();
@@ -77,7 +75,7 @@ void BrowseMarks::SetBrowseMarksStyle( int userStyle )
 // ----------------------------------------------------------------------------
 {
     #if defined(LOGGING)
-    LOGIT( _T("BrowseMarks::SetBrowseMarksStyle[%d]"), userStyle );
+    LOGIT( _T("BT BrowseMarks::SetBrowseMarksStyle[%d]"), userStyle );
     #endif
     EditorBase* eb = m_pEdMgr->GetEditor(m_filePath);
     #if defined(LOGGING)
@@ -111,6 +109,8 @@ void BrowseMarks::SetBrowseMarksStyle( int userStyle )
             gBrowse_MarkerStyle  = BROWSETRACKER_HIDDEN_STYLE;
             break;
         }
+        default:
+            break;
     }//switch
 
     // Define scintilla BrowseTracker margin marker
@@ -120,13 +120,13 @@ void BrowseMarks::SetBrowseMarksStyle( int userStyle )
     // the following stmt seems to do nothing for wxSCI_MARK_DOTDOTDOT
     pControl->MarkerSetBackground( GetBrowseMarkerId(), wxColour(0xA0, 0xA0, 0xFF));
     #if defined(LOGGING)
-    LOGIT( _T("BrowseMarks::UserStyle[%d]MarkerId[%d]MarkerStyle[%d]"),userStyle,GetBrowseMarkerId(), GetBrowseMarkerStyle() );
+    LOGIT( _T("BT BrowseMarks::UserStyle[%d]MarkerId[%d]MarkerStyle[%d]"),userStyle,GetBrowseMarkerId(), GetBrowseMarkerStyle() );
     #endif
 
     // When the Marker types only change style, our work is done.
     // Scintilla did the work for us.
     #if defined(LOGGING)
-    LOGIT( _T("OldBrowseMarkerId[%d] NewBrowseMarkerId[%d]"), OldBrowseMarkerId, GetBrowseMarkerId() );
+    LOGIT( _T("BT OldBrowseMarkerId[%d] NewBrowseMarkerId[%d]"), OldBrowseMarkerId, GetBrowseMarkerId() );
     #endif
     if ( OldBrowseMarkerId == GetBrowseMarkerId() )
         return;
@@ -213,17 +213,17 @@ void BrowseMarks::CopyMarksFrom(const BrowseMarks& otherBrowse_Marks)
 // ----------------------------------------------------------------------------
 {
     #if defined(LOGGING)
-    ///LOGIT( _T("CopyMarksFrom BrowseMarks[%p]To[%p]"), &otherBrowse_Marks, this );
+    ///LOGIT( _T("BT CopyMarksFrom BrowseMarks[%p]To[%p]"), &otherBrowse_Marks, this );
     #endif
     for (int i=0; i<MaxEntries; ++i)
     {
         m_EdPosnArray[i] = otherBrowse_Marks.m_EdPosnArray[i];
         //#if defined(LOGGING)
-        //LOGIT( _T("CopyMarksFrom lhs[%d]rhs[%d]"),m_EdPosnArray[i],otherBrowse_Marks.m_EdPosnArray[i]  );
+        //LOGIT( _T("BT CopyMarksFrom lhs[%d]rhs[%d]"),m_EdPosnArray[i],otherBrowse_Marks.m_EdPosnArray[i]  );
         //#endif
     }
     ////#if defined(LOGGING)
-    ////LOGIT( _T("CopyMarksFrom[%s]To[%s]"),
+    ////LOGIT( _T("BT CopyMarksFrom[%s]To[%s]"),
     ////            ((BrowseMarks&)otherBrowse_Marks).GetFilePath().c_str(),
     ////            GetFilePath().c_str() );
     ////#endif
@@ -236,14 +236,15 @@ void BrowseMarks::ImportBrowse_Marks()
     // rebuild BrowseMarks from scintilla browse marks
 
     #if defined(LOGGING)
-    ///LOGIT( _T("ImportBrowse_Marks") );
+    ///LOGIT( _T("BT ImportBrowse_Marks") );
     #endif
 
     //-EditorBase* eb = m_pEditorBase ;
     EditorBase* eb = m_pEdMgr->GetEditor(m_filePath);
     #if defined(LOGGING)
-    if (not eb) asm("int3"); /*trap*/
+    LOGIT(_T("BT ImportBrowse_Marks entered with no active editor base."));
     #endif
+    // This can happens when editing script for example .
     if (not eb) return;
     cbEditor* pcbEditor = Manager::Get()->GetEditorManager()->GetBuiltinEditor( eb ) ;
     if (not pcbEditor) return;
@@ -318,7 +319,7 @@ void BrowseMarks::RecordMarksFrom(BrowseMarks& otherBrowse_Marks)
     }
 }
 // ----------------------------------------------------------------------------
-void BrowseMarks::GetBook_MarksFromEditor(wxString filename)
+void BrowseMarks::GetBook_MarksFromEditor(wxString /*filename*/)
 // ----------------------------------------------------------------------------
 {
     ImportBook_Marks();
@@ -493,13 +494,13 @@ void BrowseMarks::RebuildBrowse_Marks(cbEditor* cbed, bool addedLines)
     }
 }
 // ----------------------------------------------------------------------------
-wxString BrowseMarks::GetStringOfBrowse_Marks()
+wxString BrowseMarks::GetStringOfBrowse_Marks() const
 // ----------------------------------------------------------------------------
 {
     // return a comma delimited string of browse marks
 
     wxString browseMarks = wxT("");
-    for (int i=0; i<MaxEntries; ++i)
+    for (int i = 0; i < MaxEntries; ++i)
     {
         if ( m_EdPosnArray[i] == -1 ) continue;
         if (not browseMarks.IsEmpty())  browseMarks << wxT(",") ;
@@ -522,9 +523,9 @@ void BrowseMarks::RemoveMarkerTypes( int markerId )
     //cbEditor* cbed = Manager::Get()->GetEditorManager()->GetBuiltinActiveEditor();
     if (eb) cbed = Manager::Get()->GetEditorManager()->GetBuiltinEditor(eb);
     if (cbed) control = cbed->GetControl();
-    for (int i=0; i<MaxEntries; ++i )
+    for (int i = 0; i < MaxEntries; ++i )
     {
-            int pos = m_EdPosnArray[i];
+            const int pos = m_EdPosnArray[i];
             int line = -1;
             if (control && (pos != -1))
                 line = control->LineFromPosition(pos);
@@ -545,9 +546,9 @@ void BrowseMarks::PlaceMarkerTypes( int markerId )
     //cbEditor* cbed = Manager::Get()->GetEditorManager()->GetBuiltinActiveEditor();
     if (eb) cbed = Manager::Get()->GetEditorManager()->GetBuiltinEditor(eb);
     if (cbed) control = cbed->GetControl();
-    for (int i=0; i<MaxEntries; ++i )
+    for (int i = 0; i < MaxEntries; ++i )
     {
-            int pos = m_EdPosnArray[i];
+            const int pos = m_EdPosnArray[i];
             int line = -1;
             if (control && (pos != -1))
                 line = control->LineFromPosition(pos);
@@ -563,18 +564,18 @@ void BrowseMarks::Dump()
 
     #if defined(LOGGING)
     EditorBase* eb = m_pEdMgr->GetEditor(m_filePath);
-    LOGIT( _T("--BrowseMarks for[%p][%s]--"), eb, m_fileShortName.c_str() );
+    LOGIT( _T("BT --BrowseMarks for[%p][%s]--"), eb, m_fileShortName.c_str() );
     cbEditor* cbed = 0;
     cbStyledTextCtrl* control = 0;
     //cbEditor* cbed = Manager::Get()->GetEditorManager()->GetBuiltinActiveEditor();
     if (eb) cbed = Manager::Get()->GetEditorManager()->GetBuiltinEditor(eb);
     if (cbed) control = cbed->GetControl();
-    LOGIT( _T("Array[%p] Current[%d]Last[%d]"), this, m_currIndex, m_lastIndex);
-    for (int i=0; i<MaxEntries; ++i )
+    LOGIT( _T("BT Array[%p] Current[%d]Last[%d]"), this, m_currIndex, m_lastIndex);
+    for (int i = 0; i < MaxEntries; ++i )
     {
-            int pos = m_EdPosnArray[i];
+            const int pos = m_EdPosnArray[i];
             if (control && (pos != -1))
-            LOGIT( _T("Array[%p] index[%d]Line[%d]Pos[%d]"), this, i, control->LineFromPosition(pos) ,pos );
+            LOGIT(_T("BT Array[%p] index[%d]Line[%d]Pos[%d]"), this, i, control->LineFromPosition(pos) ,pos );
             else
             LOGIT( _T("Array[%p] index[%d]Pos[%d]"), this, i, pos );
     }
