@@ -17,7 +17,7 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
-// RCS-ID: $Id: snippetproperty.cpp 106 2007-12-01 18:31:55Z Pecan $
+// RCS-ID: $Id: snippetproperty.cpp 7443 2011-09-01 16:29:16Z mortenmacfly $
 // ----------------------------------------------------------------------------
 //  SnippetProperty.cpp                                         //(pecan 2006/9/12)
 // ----------------------------------------------------------------------------
@@ -31,23 +31,21 @@
     #include <wx/filename.h>
     #include <wx/dnd.h>
 
-#if defined(BUILDING_PLUGIN)
+//-#if defined(BUILDING_PLUGIN)
     #include "sdk.h"
-#endif
+//-#endif
 
 #include "codesnippetswindow.h"
 #include "snippetitemdata.h"
 #include "menuidentifiers.h"
-#include "messagebox.h"
+#include "GenericMessageBox.h"
 #include "snippetsconfig.h"
 #include "snippetproperty.h"
-
-    // FIXME: this stuff should be allocated in an Edit class
-    // wxScintila (Edit) stuff
-    //! global print data, to remember settings during the session
-    wxPrintData *g_printData = (wxPrintData*) 0;
-    wxPageSetupData *g_pageSetupData = (wxPageSetupData*) 0;
-    bool g_bPrinterIsSetup = false;
+#include "defsext.h"
+#include "dragscrollevent.h"
+#include "version.h"
+//#include "wxscintilla/include/wx/wxscintilla.h"   //svn5785
+#include <wx/wxscintilla.h>                         //svn5785
 
    BEGIN_EVENT_TABLE(SnippetProperty, SnippetPropertyForm)
     EVT_BUTTON(wxID_OK,             SnippetProperty::OnOk)
@@ -93,7 +91,13 @@ SnippetProperty::SnippetProperty(wxTreeCtrl* pTree, wxTreeItemId itemId, wxSemap
 // ----------------------------------------------------------------------------
     :SnippetPropertyForm(pTree->GetParent(),-1,wxT("Snippet Properties"))
 {
-    // ctor
+    InitSnippetProperty( pTree, itemId, pWaitSem );
+}
+// ----------------------------------------------------------------------------
+void SnippetProperty::InitSnippetProperty(wxTreeCtrl* pTree, wxTreeItemId itemId, wxSemaphore* pWaitSem)
+// ----------------------------------------------------------------------------
+{
+    // ctor initialization
 
     // The scintilla Editor is allocated by SnippetPropertyForm
 
@@ -110,10 +114,17 @@ SnippetProperty::SnippetProperty(wxTreeCtrl* pTree, wxTreeItemId itemId, wxSemap
     m_TreeItemId = itemId;
 
     // Initialize the properties fields
-    m_ItemLabelTextCtrl->   SetValue( pTree->GetItemText(itemId) );
-    m_SnippetEditCtrl->     SetText( wxT("Enter text or Filename") );
+    m_ItemLabelTextCtrl->SetValue( pTree->GetItemText(itemId) );
+    m_ItemLabelTextCtrl->Connect(wxEVT_COMMAND_TEXT_ENTER,
+        wxCommandEventHandler( SnippetProperty::OnOk ), NULL, this );
+
+    m_SnippetEditCtrl->SetText( wxT("Enter text or Filename") );
     m_SnippetEditCtrl->SetFocus();
 
+	wxColour txtBackground = m_ItemLabelTextCtrl->GetBackgroundColour();
+    //m_SnippetEditCtrl->SetBackgroundColour(txtBackground);
+    m_SnippetEditCtrl->StyleSetBackground (wxSCI_STYLE_DEFAULT, txtBackground);
+    m_SnippetEditCtrl->StyleClearAll();
 
 	// Get the item
 	if (( m_pSnippetDataItem = (SnippetItemData*)(pTree->GetItemData(itemId))))
@@ -131,86 +142,37 @@ SnippetProperty::SnippetProperty(wxTreeCtrl* pTree, wxTreeItemId itemId, wxSemap
         if ( not snippetText.IsEmpty() )
         {
             GetSnippetEditCtrl()-> SetText( snippetText );
+            GetSnippetEditCtrl()->SetSavePoint();
             // SetText() marked the file as modified
             // Unmarked it by saving to a dummy file
-            #if defined(__WXMSW__)
-                m_SnippetEditCtrl->SaveFile(wxT("nul"));
-            #else
-                m_SnippetEditCtrl->SaveFile(wxT("/dev/null"));
-            #endif
+            //#if defined(__WXMSW__)
+            //    m_SnippetEditCtrl->SaveFile(wxT("nul"));
+            //#else
+            //    m_SnippetEditCtrl->SaveFile(wxT("/dev/null"));
+            //#endif
             // reset the undo history to avoid undoing to a blank page
             m_SnippetEditCtrl->EmptyUndoBuffer();
         }//if
 
 
         // reset horiz scroll max width
-        m_nScrollWidthMax = GetSnippetEditCtrl()->GetLongestLinePixelWidth();
-        GetSnippetEditCtrl()->SetScrollWidth(m_nScrollWidthMax);
+        //-m_nScrollWidthMax = GetSnippetEditCtrl()->GetLongestLinePixelWidth();
+        //-GetSnippetEditCtrl()->SetScrollWidth(m_nScrollWidthMax);
 
 	}//if
 
 	SetDropTarget(new SnippetDropTarget(this));
 
-    // EVT_CHAR events
-    m_SnippetEditCtrl->Connect(wxEVT_KEY_DOWN,
-                     wxKeyEventHandler(SnippetProperty::OnKeyDownEvent),
-                     0, this);
-
 }//SnippetProperty ctor
 // ----------------------------------------------------------------------------
 SnippetProperty::~SnippetProperty()
 // ----------------------------------------------------------------------------
 {
     //dtor
-    m_SnippetEditCtrl->Disconnect(wxEVT_KEY_DOWN,
-                     wxKeyEventHandler(SnippetProperty::OnKeyDownEvent),
-                     0, this);
-
 }
 // ----------------------------------------------------------------------------
 // edit events
 // ----------------------------------------------------------------------------
-void SnippetProperty::OnKeyDownEvent (wxKeyEvent& event)
-// ----------------------------------------------------------------------------
-{
-    // pass cut/copy/paste/select/undo/redo on to scintilla
-    if ( not event.ControlDown() ) {event.Skip(); return;}
-    if ( event.ShiftDown() ) {event.Skip(); return;}
-
-    wxCommandEvent ev;
-    ev.SetEventType(wxEVT_COMMAND_MENU_SELECTED);
-    switch (event.GetKeyCode() )
-    {
-        case 'X': case 'x':
-            ev.SetId(wxID_CUT); break;
-        case 'C': case 'c':
-            ev.SetId(wxID_COPY); break;
-        case 'V': case 'v':
-            ev.SetId(wxID_PASTE); break;
-        case 'A': case 'a':
-            ev.SetId(wxID_SELECTALL); break;
-        case 'L': case 'l':
-            ev.SetId(myID_SELECTLINE); break;
-        case 'Y': case 'y':
-            ev.SetId(wxID_REDO); break;
-        case 'Z': case 'z':
-            ev.SetId(wxID_UNDO); break;
-
-        default: event.Skip(); return;
-    }
-
-    if (m_SnippetEditCtrl) m_SnippetEditCtrl->ProcessEvent (ev);
-
-}
-
-// ----------------------------------------------------------------------------
-void SnippetProperty::OnEditEvent (wxCommandEvent &event)
-// ----------------------------------------------------------------------------
-{
-     LOGIT( _T("SnippetProperty::OnEditEvent") );
-    if (m_SnippetEditCtrl) m_SnippetEditCtrl->ProcessEvent (event);
-}
-// ----------------------------------------------------------------------------
 //  Dialog events
 // ----------------------------------------------------------------------------
 void SnippetProperty::OnOk(wxCommandEvent& event)
@@ -249,13 +211,13 @@ void SnippetProperty::OnSnippetButton(wxCommandEvent& event)
     // Snippet button clicked from menubar edit(Menu) or properties context(Mnu)
     if ( ( g_activeMenuId == idMnuProperties ) //note: mnu vs menu
         //-#if defined(__WXMSW__) && !defined(BUILDING_PLUGIN)
-        #if !defined(BUILDING_PLUGIN)
-            || ( g_activeMenuId == idMenuProperties)
-        #endif
+        //-#if !defined(BUILDING_PLUGIN)
+        //-    || ( g_activeMenuId == idMenuProperties)
+        //-#endif
         )
     {
         if ( GetConfig()->SettingsExternalEditor.IsEmpty())
-        {   messageBox(wxT("Use Menu/Settings/Options to specify an external editor.") );
+        {   GenericMessageBox(wxT("Use Menu/Settings/Options to specify an external editor.") );
             return;
         }
             // let user edit the snippet text
@@ -297,7 +259,7 @@ void SnippetProperty::InvokeEditOnSnippetText()
         if (not tmpFile.IsOpened() )
         {
             //wxMessageBox(wxT("Open failed for:")+tmpFileName.GetFullPath());
-            messageBox(wxT("Open failed for:")+tmpFileName.GetFullPath());
+            GenericMessageBox(wxT("Open failed for:")+tmpFileName.GetFullPath());
             return ;
         }
         wxString snippetData( GetSnippet() );
@@ -305,6 +267,11 @@ void SnippetProperty::InvokeEditOnSnippetText()
         tmpFile.Close();
             // Invoke the external editor on the temporary file
             // file name must be surrounded with quotes when using wxExecute
+        wxString externalEditor = GetConfig()->SettingsExternalEditor;
+        if ( externalEditor == _T("Enter filename of external editor") )
+        {   GenericMessageBox(wxT("No external editor specified.\n Check settings.\n"));
+            return;
+        }
         wxString execString = GetConfig()->SettingsExternalEditor + wxT(" \"") + tmpFileName.GetFullPath() + wxT("\"");
 
         #ifdef LOGGING
@@ -316,7 +283,7 @@ void SnippetProperty::InvokeEditOnSnippetText()
             // Read the edited data back into the snippet text
         tmpFile.Open(tmpFileName.GetFullPath(), wxFile::read);
         if (not tmpFile.IsOpened() )
-        {   messageBox(wxT("Abort.Error reading temp data file."));
+        {   GenericMessageBox(wxT("Abort.Error reading temp data file."));
             return;
         }
         unsigned long fileSize = tmpFile.Length();
@@ -329,7 +296,7 @@ void SnippetProperty::InvokeEditOnSnippetText()
         char pBuf[fileSize+1];
         size_t nResult = tmpFile.Read( pBuf, fileSize );
         if ( wxInvalidOffset == (int)nResult )
-            messageBox(wxT("InvokeEditOnSnippetText()\nError reading temp file"));
+            GenericMessageBox(wxT("InvokeEditOnSnippetText()\nError reading temp file"));
         pBuf[fileSize] = 0;
         tmpFile.Close();
 
@@ -380,74 +347,74 @@ void SnippetProperty::InvokeEditOnSnippetFile()
     ::wxExecute( execString);
     return;
 }//InvokeEditOnSnippetFile
-// ----------------------------------------------------------------------------
-void SnippetProperty::OnLeaveWindow(wxMouseEvent& event)
-// ----------------------------------------------------------------------------
-{
-    // If mouse is dragging out of window with a text selection,
-    // create a drag source of the selected text.
-    // -----------------------
-    // LEAVE_WINDOW
-    // -----------------------
-
-    #ifdef LOGGING
-     //LOGIT( _T("SnippetProperty:MOUSE EVT_LEAVE_WINDOW") );
-    #endif //LOGGING
-
-    // Left mouse key must be down (dragging)
-    if (not event.LeftIsDown() ) {event.Skip();return;}
-
-    // check if data is available
-    wxString selectedData = m_SnippetEditCtrl->GetSelectedText();
-    if ( selectedData.IsEmpty()) {event.Skip();return;}
-
-    // we now have data, create both a simple text and filename drop source
-    wxTextDataObject* textData = new wxTextDataObject();
-    wxFileDataObject* fileData = new wxFileDataObject();
-        // fill text and file sources with snippet
-    wxDropSource textSource( *textData, (wxWindow*)event.GetEventObject() );
-    textData->SetText( selectedData );
-    wxDropSource fileSource( *fileData, (wxWindow*)event.GetEventObject() );
-    fileData->AddFile( (selectedData.Len() > 128) ? wxString(wxEmptyString) : selectedData );
-        // set composite data object to contain both text and file data
-    wxDataObjectComposite *data = new wxDataObjectComposite();
-    data->Add( (wxDataObjectSimple*)textData );
-    data->Add( (wxDataObjectSimple*)fileData, true ); // set file data as preferred
-        // create the drop source containing both data types
-    wxDropSource source( *data, (wxWindow*)event.GetEventObject()  );
-
-    #ifdef LOGGING
-     LOGIT( _T("DropSource Text[%s],File[%s]"),
-                textData->GetText().GetData(),
-                fileData->GetFilenames().Item(0).GetData() );
-    #endif //LOGGING
-        // allow both copy and move
-    int flags = 0;
-    flags |= wxDrag_AllowMove;
-    // do the dragNdrop
-    wxDragResult result = source.DoDragDrop(flags);
-    // report the results
-    #if LOGGING
-        wxString pc;
-        switch ( result )
-        {
-            case wxDragError:   pc = _T("Error!");    break;
-            case wxDragNone:    pc = _T("Nothing");   break;
-            case wxDragCopy:    pc = _T("Copied");    break;
-            case wxDragMove:    pc = _T("Moved");     break;
-            case wxDragCancel:  pc = _T("Cancelled"); break;
-            default:            pc = _T("Huh?");      break;
-        }
-        LOGIT( wxT("SnippetProperty::OnLeftDown DoDragDrop returned[%s]"),pc.GetData() );
-    #else
-        wxUnusedVar(result);
-    #endif // wxUSE_STATUSBAR
-
-
-    delete textData; //wxTextDataObject
-    delete fileData; //wxFileDataObject
-
-    event.Skip();
-    return;
-
-}
+////// ----------------------------------------------------------------------------
+////void SnippetProperty::OnLeaveWindow(wxMouseEvent& event)
+////// ----------------------------------------------------------------------------
+////{
+////    // If mouse is dragging out of window with a text selection,
+////    // create a drag source of the selected text.
+////    // -----------------------
+////    // LEAVE_WINDOW
+////    // -----------------------
+////
+////    #ifdef LOGGING
+////     //LOGIT( _T("SnippetProperty:MOUSE EVT_LEAVE_WINDOW") );
+////    #endif //LOGGING
+////
+////    // Left mouse key must be down (dragging)
+////    if (not event.LeftIsDown() ) {event.Skip();return;}
+////
+////    // check if data is available
+////    wxString selectedData = m_SnippetEditCtrl->GetSelectedText();
+////    if ( selectedData.IsEmpty()) {event.Skip();return;}
+////
+////    // we now have data, create both a simple text and filename drop source
+////    wxTextDataObject* textData = new wxTextDataObject();
+////    wxFileDataObject* fileData = new wxFileDataObject();
+////        // fill text and file sources with snippet
+////    wxDropSource textSource( *textData, (wxWindow*)event.GetEventObject() );
+////    textData->SetText( selectedData );
+////    wxDropSource fileSource( *fileData, (wxWindow*)event.GetEventObject() );
+////    fileData->AddFile( (selectedData.Len() > 128) ? wxString(wxEmptyString) : selectedData );
+////        // set composite data object to contain both text and file data
+////    wxDataObjectComposite *data = new wxDataObjectComposite();
+////    data->Add( (wxDataObjectSimple*)textData );
+////    data->Add( (wxDataObjectSimple*)fileData, true ); // set file data as preferred
+////        // create the drop source containing both data types
+////    wxDropSource source( *data, (wxWindow*)event.GetEventObject()  );
+////
+////    #ifdef LOGGING
+////     LOGIT( _T("DropSource Text[%s],File[%s]"),
+////                textData->GetText().GetData(),
+////                fileData->GetFilenames().Item(0).GetData() );
+////    #endif //LOGGING
+////        // allow both copy and move
+////    int flags = 0;
+////    flags |= wxDrag_AllowMove;
+////    // do the dragNdrop
+////    wxDragResult result = source.DoDragDrop(flags);
+////    // report the results
+////    #if LOGGING
+////        wxString pc;
+////        switch ( result )
+////        {
+////            case wxDragError:   pc = _T("Error!");    break;
+////            case wxDragNone:    pc = _T("Nothing");   break;
+////            case wxDragCopy:    pc = _T("Copied");    break;
+////            case wxDragMove:    pc = _T("Moved");     break;
+////            case wxDragCancel:  pc = _T("Cancelled"); break;
+////            default:            pc = _T("Huh?");      break;
+////        }
+////        LOGIT( wxT("SnippetProperty::OnLeftDown DoDragDrop returned[%s]"),pc.GetData() );
+////    #else
+////        wxUnusedVar(result);
+////    #endif // wxUSE_STATUSBAR
+////
+////
+////    delete textData; //wxTextDataObject
+////    delete fileData; //wxFileDataObject
+////
+////    event.Skip();
+////    return;
+////
+////}
