@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: updatedlg.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/devpak_plugin/updatedlg.cpp $
+ * $Revision: 7109 $
+ * $Id: updatedlg.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/devpak_plugin/updatedlg.cpp $
  */
 
 #include "updatedlg.h"
@@ -31,7 +31,7 @@ int idPopupDownload = wxNewId();
 int idPopupDownloadAndInstall = wxNewId();
 int idPopupUninstall = wxNewId();
 
-BEGIN_EVENT_TABLE(UpdateDlg, wxDialog)
+BEGIN_EVENT_TABLE(UpdateDlg, wxScrollingDialog)
     EVT_UPDATE_UI(-1, UpdateDlg::OnUpdateUI)
     EVT_TREE_SEL_CHANGED(XRCID("tvCategories"), UpdateDlg::OnTreeSelChanged)
     EVT_LIST_ITEM_SELECTED(XRCID("lvFiles"), UpdateDlg::OnFileSelected)
@@ -62,7 +62,7 @@ UpdateDlg::UpdateDlg(wxWindow* parent)
     m_Net(this, idNet, _T("http://devpaks.sourceforge.net/"))
 {
 	//ctor
-	wxXmlResource::Get()->LoadDialog(this, parent, _T("MainFrame"));
+	wxXmlResource::Get()->LoadObject(this, parent, _T("MainFrame"),_T("wxScrollingDialog"));
 	CreateListColumns();
     FillServers();
 	UpdateStatus(_("Ready"), 0);
@@ -79,7 +79,7 @@ void UpdateDlg::EndModal(int retCode)
 {
     if (!m_Net.IsConnected() || retCode != wxID_CANCEL)
     {
-        wxDialog::EndModal(retCode);
+        wxScrollingDialog::EndModal(retCode);
         return;
     }
 
@@ -94,11 +94,13 @@ void UpdateDlg::CreateListColumns()
     lst->InsertColumn(1, _("Version"));
     lst->InsertColumn(2, _("Installed"));
     lst->InsertColumn(3, _("Size"), wxLIST_FORMAT_RIGHT);
+    lst->InsertColumn(4, _("Rev"));
 
-    lst->SetColumnWidth(0, lst->GetSize().x - (64 * 3) - 2); // 1st column takes all remaining space
+    lst->SetColumnWidth(0, lst->GetSize().x - (64 * 3 + 40) - 6 ); // 1st column takes all remaining space
     lst->SetColumnWidth(1, 64);
     lst->SetColumnWidth(2, 64);
     lst->SetColumnWidth(3, 64);
+    lst->SetColumnWidth(4, 40);
 }
 
 void UpdateDlg::AddRecordToList(UpdateRec* rec)
@@ -111,6 +113,18 @@ void UpdateDlg::AddRecordToList(UpdateRec* rec)
     lst->SetItem(idx, 1, rec->version);
     lst->SetItem(idx, 2, rec->installed_version);
     lst->SetItem(idx, 3, rec->size);
+    lst->SetItem(idx, 4, rec->revision);
+}
+
+wxString UpdateDlg::GetListColumnText(int idx, int col) {
+    wxListCtrl* lst = XRCCTRL(*this, "lvFiles", wxListCtrl);
+    int index = idx == -1 ? lst->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) : idx;
+    wxListItem info;
+    info.SetId(index);
+    info.SetColumn(col);
+    info.SetMask(wxLIST_MASK_TEXT);
+    lst->GetItem(info);
+    return info.GetText();
 }
 
 void UpdateDlg::SetListColumnText(int idx, int col, const wxString& text)
@@ -393,7 +407,9 @@ UpdateRec* UpdateDlg::GetRecFromListView()
     if (index == -1)
         return 0;
     wxString title = lst->GetItemText(index);
-    return FindRecByTitle(title, m_Recs, m_RecsCount);
+    wxString version = GetListColumnText(index, 1);
+    wxString revision = GetListColumnText(index, 4);
+    return FindRec(title, version, revision, m_Recs, m_RecsCount);
 }
 
 void UpdateDlg::DownloadFile(bool dontInstall)
