@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 8350 $
+ * $Id: envvars_cfgdlg.cpp 8350 2012-09-04 08:05:13Z jenslody $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/envvars/envvars_cfgdlg.cpp $
  */
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
@@ -61,8 +61,7 @@ END_EVENT_TABLE()
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
-EnvVarsConfigDlg::EnvVarsConfigDlg(wxWindow* parent, EnvVars* plugin):
-  m_pPlugin(plugin)
+EnvVarsConfigDlg::EnvVarsConfigDlg(wxWindow* parent)
 {
   wxXmlResource::Get()->LoadPanel(this, parent, _T("dlgEnvVars"));
   LoadSettings();
@@ -72,7 +71,7 @@ EnvVarsConfigDlg::EnvVarsConfigDlg(wxWindow* parent, EnvVars* plugin):
 
 void EnvVarsConfigDlg::OnUpdateUI(wxUpdateUIEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnUpdateUI")));
 #endif
 
@@ -105,7 +104,7 @@ void EnvVarsConfigDlg::OnUpdateUI(wxUpdateUIEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::LoadSettings()
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("LoadSettings")));
 #endif
 
@@ -137,7 +136,7 @@ void EnvVarsConfigDlg::LoadSettings()
   // Read all envvar sets available
   wxArrayString set_names = nsEnvVars::GetEnvvarSetNames();
   unsigned int  num_sets  = set_names.GetCount();
-  EV_DBGLOG(_T("EnvVars: Found %d envvar sets in config."), num_sets);
+  EV_DBGLOG(_T("EnvVars: Found %u envvar sets in config."), num_sets);
   unsigned int num_sets_applied = 0;
   for (unsigned int i=0; i<num_sets; ++i)
   {
@@ -146,15 +145,16 @@ void EnvVarsConfigDlg::LoadSettings()
       active_set_idx = i;
     num_sets_applied++;
   }
-  EV_DBGLOG(_T("EnvVars: Setup %d/%d envvar sets from config."), num_sets_applied, num_sets);
+  EV_DBGLOG(_T("EnvVars: Setup %u/%u envvar sets from config."), num_sets_applied, num_sets);
   if ((int)choSet->GetCount()>active_set_idx) // Select the last active set (from config)
     choSet->SetSelection(active_set_idx);
 
   // Show currently activated set in debug log (for reference)
   wxString active_set_path = nsEnvVars::GetSetPathByName(active_set);
   EV_DBGLOG(_T("EnvVars: Active envvar set is '%s' at index %d, config path '%s'."),
-    active_set.c_str(), active_set_idx, active_set_path.c_str());
+    active_set.wx_str(), active_set_idx, active_set_path.wx_str());
 
+  // NOTE: Keep this in sync with nsEnvVars::EnvvarSetApply
   // Read and show all envvars from currently active set in listbox
   wxArrayString vars     = nsEnvVars::GetEnvvarsBySetPath(active_set_path);
   size_t envvars_total   = vars.GetCount();
@@ -166,20 +166,24 @@ void EnvVarsConfigDlg::LoadSettings()
     if (nsEnvVars::EnvvarArrayApply(var_array, lstEnvVars))
       envvars_applied++;
     else
-      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%d."),
-        active_set_path.c_str(), i);
+    {
+      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%u."),
+        active_set_path.wx_str(), i);
+    }
   }// for
 
   if (envvars_total>0)
-    EV_DBGLOG(_T("EnvVars: %d/%d envvars applied within C::B focus."),
-      envvars_applied, envvars_total);
+  {
+    EV_DBGLOG(_T("EnvVars: %lu/%lu envvars applied within C::B focus."),
+      static_cast<unsigned long>(envvars_applied), static_cast<unsigned long>(envvars_total));
+  }
 }// LoadSettings
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 void EnvVarsConfigDlg::SaveSettings()
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   if (Manager::Get() && Manager::Get()->GetLogManager());
     Manager::Get()->GetLogManager()->DebugLog(F(_T("SaveSettings")));
 #endif
@@ -208,10 +212,10 @@ void EnvVarsConfigDlg::SaveSettings()
 
   wxString active_set_path = nsEnvVars::GetSetPathByName(active_set, false);
   EV_DBGLOG(_T("EnvVars: Removing (old) envvar set '%s' at path '%s' from config."),
-    active_set.c_str(), active_set_path.c_str());
+    active_set.wx_str(), active_set_path.wx_str());
   cfg->DeleteSubPath(active_set_path);
 
-  EV_DBGLOG(_T("EnvVars: Saving (new) envvar set '%s'."), active_set.c_str());
+  EV_DBGLOG(_T("EnvVars: Saving (new) envvar set '%s'."), active_set.wx_str());
   cfg->SetPath(active_set_path);
 
   for (int i=0; i<(int)lstEnvVars->GetCount(); ++i)
@@ -237,7 +241,7 @@ void EnvVarsConfigDlg::SaveSettings()
 
 void EnvVarsConfigDlg::SaveSettingsActiveSet(wxString active_set)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("SaveSettingsActiveSet")));
 #endif
 
@@ -248,7 +252,7 @@ void EnvVarsConfigDlg::SaveSettingsActiveSet(wxString active_set)
   if (active_set.IsEmpty())
     active_set = nsEnvVars::EnvVarsDefault;
 
-  EV_DBGLOG(_T("EnvVars: Saving '%s' as active envvar set to config."), active_set.c_str());
+  EV_DBGLOG(_T("EnvVars: Saving '%s' as active envvar set to config."), active_set.wx_str());
   cfg->Write(_T("/active_set"), active_set);
 }// SaveSettingsActiveSet
 
@@ -256,7 +260,7 @@ void EnvVarsConfigDlg::SaveSettingsActiveSet(wxString active_set)
 
 void EnvVarsConfigDlg::OnSetClick(wxCommandEvent& event)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnSetClick")));
 #endif
 
@@ -268,7 +272,7 @@ void EnvVarsConfigDlg::OnSetClick(wxCommandEvent& event)
 
 void EnvVarsConfigDlg::OnCreateSetClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnCreateSetClick")));
 #endif
 
@@ -286,8 +290,8 @@ void EnvVarsConfigDlg::OnCreateSetClick(wxCommandEvent& WXUNUSED(event))
     return;
 
   EV_DBGLOG(_T("EnvVars: Unsetting variables of envvar set '%s'."),
-    choSet->GetString(choSet->GetCurrentSelection()).c_str());
-  nsEnvVars::EnvvarsClear(lstEnvVars); // Don't care about return value
+    choSet->GetString(choSet->GetCurrentSelection()).wx_str());
+  nsEnvVars::EnvvarsClearUI(lstEnvVars); // Don't care about return value
   lstEnvVars->Clear();
 
   int idx = choSet->Append(set.MakeLower());
@@ -301,7 +305,7 @@ void EnvVarsConfigDlg::OnCreateSetClick(wxCommandEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::OnCloneSetClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnCloneSetClick")));
 #endif
 
@@ -330,7 +334,7 @@ void EnvVarsConfigDlg::OnCloneSetClick(wxCommandEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::OnRemoveSetClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnRemoveSetClick")));
 #endif
 
@@ -362,13 +366,13 @@ void EnvVarsConfigDlg::OnRemoveSetClick(wxCommandEvent& WXUNUSED(event))
     wxString active_set     = choSet->GetString(active_set_idx);
 
     // Remove envvars from C::B focus (and listbox)
-    EV_DBGLOG(_T("EnvVars: Unsetting variables of envvar set '%s'."), active_set.c_str());
-    nsEnvVars::EnvvarsClear(lstEnvVars); // Don't care about return value
+    EV_DBGLOG(_T("EnvVars: Unsetting variables of envvar set '%s'."), active_set.wx_str());
+    nsEnvVars::EnvvarsClearUI(lstEnvVars); // Don't care about return value
 
     // Remove envvars set from config
     wxString active_set_path = nsEnvVars::GetSetPathByName(active_set, false);
     EV_DBGLOG(_T("EnvVars: Removing envvar set '%s' at path '%s' from config."),
-      active_set.c_str(), active_set_path.c_str());
+      active_set.wx_str(), active_set_path.wx_str());
     cfg->DeleteSubPath(active_set_path);
 
     // Remove envvars set from choicebox
@@ -388,7 +392,7 @@ void EnvVarsConfigDlg::OnRemoveSetClick(wxCommandEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::OnToggleEnvVarClick(wxCommandEvent& event)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnToggleEnvVarClick")));
 #endif
 
@@ -410,7 +414,8 @@ void EnvVarsConfigDlg::OnToggleEnvVarClick(wxCommandEvent& event)
   {
     // Is has been toggled ON -> set envvar now
     wxString value = lstEnvVars->GetString(sel).AfterFirst(_T('=')).Trim(true).Trim(false);
-    nsEnvVars::EnvvarApply(key, value, lstEnvVars, sel); // Don't care about return value
+    if (!nsEnvVars::EnvvarApply(key, value))
+      lstEnvVars->Check(sel, false); // Unset on UI to mark it's NOT set
   }
   else
   {
@@ -423,7 +428,7 @@ void EnvVarsConfigDlg::OnToggleEnvVarClick(wxCommandEvent& event)
 
 void EnvVarsConfigDlg::OnAddEnvVarClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnAddEnvVarClick")));
 #endif
 
@@ -441,12 +446,13 @@ void EnvVarsConfigDlg::OnAddEnvVarClick(wxCommandEvent& WXUNUSED(event))
     key.Trim(true).Trim(false);
     value.Trim(true).Trim(false);
 
-    if (nsEnvVars::EnvvarVeto(key))
+    if (nsEnvVars::EnvvarVetoUI(key, NULL, -1))
       return;
 
-    int sel = lstEnvVars->Append(key + _T(" = ") + value);
-    if (nsEnvVars::EnvvarApply(key, value, lstEnvVars, sel))
-      lstEnvVars->Check(sel, true);
+    int  sel     = lstEnvVars->Append(key + _T(" = ") + value);
+    bool success = nsEnvVars::EnvvarApply(key, value);
+    if (sel>=0)
+      lstEnvVars->Check(sel, success);
   }
 }// OnAddEnvVarClick
 
@@ -454,7 +460,7 @@ void EnvVarsConfigDlg::OnAddEnvVarClick(wxCommandEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::OnEditEnvVarClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnEditEnvVarClick")));
 #endif
 
@@ -469,6 +475,7 @@ void EnvVarsConfigDlg::OnEditEnvVarClick(wxCommandEvent& WXUNUSED(event))
   wxString key = lstEnvVars->GetStringSelection().BeforeFirst(_T('=')).Trim(true).Trim(false);
   if (key.IsEmpty())
     return;
+  bool was_checked = lstEnvVars->IsChecked(sel);
 
   wxString value     = lstEnvVars->GetStringSelection().AfterFirst(_T('=')).Trim(true).Trim(false);
   wxString old_key   = key;
@@ -500,23 +507,28 @@ void EnvVarsConfigDlg::OnEditEnvVarClick(wxCommandEvent& WXUNUSED(event))
     if (key != old_key)
     {
       nsEnvVars::EnvvarDiscard(old_key); // Don't care about return value
-      if (nsEnvVars::EnvvarVeto(key, lstEnvVars, sel))
+      if (nsEnvVars::EnvvarVetoUI(key, lstEnvVars, sel))
         return;
     }
 
     // set the new envvar
-    nsEnvVars::EnvvarApply(key, value, lstEnvVars, sel); // Don't care about return value
+    if (!nsEnvVars::EnvvarApply(key, value))
+    {
+      lstEnvVars->Check(sel, false); // Unset on UI to mark it's NOT set
+      was_checked = false;
+    }
   }
 
   // update the GUI to the (new/updated/same) key/value pair anyway
   lstEnvVars->SetString(sel, key + _T(" = ") + value);
+  lstEnvVars->Check(sel, was_checked);
 }// OnEditEnvVarClick
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 void EnvVarsConfigDlg::OnDeleteEnvVarClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnDeleteEnvVarClick")));
 #endif
 
@@ -545,7 +557,7 @@ void EnvVarsConfigDlg::OnDeleteEnvVarClick(wxCommandEvent& WXUNUSED(event))
 
 void EnvVarsConfigDlg::OnClearEnvVarsClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnClearEnvVarsClick")));
 #endif
 
@@ -560,14 +572,14 @@ void EnvVarsConfigDlg::OnClearEnvVarsClick(wxCommandEvent& WXUNUSED(event))
                    wxYES | wxNO | wxICON_QUESTION) != wxID_YES)
     return;
 
-  nsEnvVars::EnvvarsClear(lstEnvVars); // Don't care about return value
+  nsEnvVars::EnvvarsClearUI(lstEnvVars); // Don't care about return value
 }// OnClearEnvVarsClick
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 void EnvVarsConfigDlg::OnSetEnvVarsClick(wxCommandEvent& WXUNUSED(event))
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("OnSetEnvVarsClick")));
 #endif
 
@@ -595,6 +607,8 @@ void EnvVarsConfigDlg::OnSetEnvVarsClick(wxCommandEvent& WXUNUSED(event))
       {
         if (!nsEnvVars::EnvvarApply(key, value))
         {
+          lstEnvVars->Check(i, false); // Unset on UI to mark it's NOT set
+
           // Setting envvar failed. Remember this key to report later.
           if (envsNotSet.IsEmpty())
             envsNotSet << key;
@@ -609,7 +623,7 @@ void EnvVarsConfigDlg::OnSetEnvVarsClick(wxCommandEvent& WXUNUSED(event))
   {
     wxString msg;
     msg.Printf( _("There was an error setting the following environment variables:\n%s"),
-                envsNotSet.c_str() );
+                envsNotSet.wx_str() );
     cbMessageBox(msg, _("Error"), wxOK | wxCENTRE | wxICON_ERROR);
   }
 }// OnSetEnvVarsClick
