@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9125 $
+ * $Id: envvars_common.cpp 9125 2013-05-31 17:14:14Z jenslody $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/envvars/envvars_common.cpp $
  */
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
@@ -22,6 +22,9 @@
   #include "logmanager.h"
 #endif
 
+#include <map>
+#include <utility> // std::pair
+
 #include "envvars_common.h"
 
 // Uncomment this for tracing of method calls in C::B's DebugLog:
@@ -29,8 +32,12 @@
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
-const wxString nsEnvVars::EnvVarsSep     = _T("|");
-const wxString nsEnvVars::EnvVarsDefault = _T("default");
+namespace nsEnvVars
+{
+  const wxString              EnvVarsSep     = _T("|");
+  const wxString              EnvVarsDefault = _T("default");
+  std::map<wxString,wxString> EnvVarsStack;
+}
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
@@ -50,6 +57,14 @@ void nsEnvVars::EnvVarsDebugLog(const wxChar* msg, ...)
   va_list  arg_list;
 
   va_start(arg_list, msg);
+#if wxCHECK_VERSION(2,9,0) && wxUSE_UNICODE
+// in wx >=  2.9 unicode-build (default) we need the %ls here, or the strings get
+// cut after the first character
+    log_msg = msg;
+    log_msg.Replace(_T("%s"), _T("%ls"));
+    msg = log_msg.wx_str();
+#endif
+
   log_msg = wxString::FormatV(msg, arg_list);
   va_end(arg_list);
 
@@ -60,7 +75,7 @@ void nsEnvVars::EnvVarsDebugLog(const wxChar* msg, ...)
 
 wxArrayString nsEnvVars::EnvvarStringTokeniser(const wxString& str)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarStringTokeniser")));
 #endif
   // tokenise string like:
@@ -110,7 +125,7 @@ wxArrayString nsEnvVars::EnvvarStringTokeniser(const wxString& str)
 
 wxArrayString nsEnvVars::GetEnvvarSetNames()
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("GetEnvvarSetNames")));
 #endif
 
@@ -126,7 +141,7 @@ wxArrayString nsEnvVars::GetEnvvarSetNames()
   // Read all envvar sets available
   wxArrayString sets     = cfg->EnumerateSubPaths(_T("/sets"));
   unsigned int  num_sets = sets.GetCount();
-  EV_DBGLOG(_T("EnvVars: Found %d envvar sets in config."), num_sets);
+  EV_DBGLOG(_T("EnvVars: Found %u envvar sets in config."), num_sets);
 
   if (num_sets==0)
     set_names.Add(nsEnvVars::EnvVarsDefault);
@@ -136,7 +151,7 @@ wxArrayString nsEnvVars::GetEnvvarSetNames()
     {
       wxString set_name = sets[i];
       if (set_name.IsEmpty())
-        set_name.Printf(_T("Set%d"), i);
+        set_name.Printf(_T("Set%u"), i);
 
       set_names.Add(set_name);
     }// for
@@ -149,7 +164,7 @@ wxArrayString nsEnvVars::GetEnvvarSetNames()
 
 wxString nsEnvVars::GetActiveSetName()
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("GetActiveSetName")));
 #endif
 
@@ -165,7 +180,7 @@ wxString nsEnvVars::GetActiveSetName()
   if (!active_set_cfg.IsEmpty())
     active_set = active_set_cfg;
 
-  EV_DBGLOG(_T("EnvVars: Obtained '%s' as active envvar set from config."), active_set.c_str());
+  EV_DBGLOG(_T("EnvVars: Obtained '%s' as active envvar set from config."), active_set.wx_str());
   return active_set;
 }// GetActiveSetName
 
@@ -174,7 +189,7 @@ wxString nsEnvVars::GetActiveSetName()
 wxString nsEnvVars::GetSetPathByName(const wxString& set_name, bool check_exists,
                                      bool return_default)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("GetSetPathByName")));
 #endif
 
@@ -208,12 +223,12 @@ wxString nsEnvVars::GetSetPathByName(const wxString& set_name, bool check_exists
 
 wxArrayString nsEnvVars::GetEnvvarsBySetPath(const wxString& set_path)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("GetEnvvarsBySetPath")));
 #endif
 
   wxArrayString envvars;
-  EV_DBGLOG(_T("EnvVars: Searching for envvars in path '%s'."), set_path.c_str());
+  EV_DBGLOG(_T("EnvVars: Searching for envvars in path '%s'."), set_path.wx_str());
 
   ConfigManager *cfg = Manager::Get()->GetConfigManager(_T("envvars"));
   if (!cfg || set_path.IsEmpty())
@@ -229,8 +244,8 @@ wxArrayString nsEnvVars::GetEnvvarsBySetPath(const wxString& set_path)
     else
       EV_DBGLOG(_T("EnvVars: Warning: empty envvar detected and skipped."));
   }
-  EV_DBGLOG(_T("EnvVars: Read %d/%d envvars in path '%s'."),
-    envvars.GetCount(), num_envvars, set_path.c_str());
+  EV_DBGLOG(_T("EnvVars: Read %lu/%u envvars in path '%s'."),
+    static_cast<unsigned long>(envvars.GetCount()), num_envvars, set_path.wx_str());
 
   return envvars;
 }// GetEnvvarsBySetPath
@@ -239,7 +254,7 @@ wxArrayString nsEnvVars::GetEnvvarsBySetPath(const wxString& set_path)
 
 bool nsEnvVars::EnvvarSetExists(const wxString& set_name)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarSetExists")));
 #endif
 
@@ -255,10 +270,10 @@ bool nsEnvVars::EnvvarSetExists(const wxString& set_name)
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
-bool nsEnvVars::EnvvarVeto(const wxString& key, wxCheckListBox* lstEnvVars, int sel)
+bool nsEnvVars::EnvvarVetoUI(const wxString& key, wxCheckListBox* lstEnvVars, int sel)
 {
-#if TRACE_ENVVARS
-  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarVeto")));
+#if defined(TRACE_ENVVARS)
+  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarVetoUI")));
 #endif
 
   if (wxGetEnv(key, NULL))
@@ -271,7 +286,7 @@ bool nsEnvVars::EnvvarVeto(const wxString& key, wxCheckListBox* lstEnvVars, int
     warn_exist.Printf(_("Warning: Environment variable '%s' is already set.\n"
                         "Continue with updating it's value?\n"
                         "(Recursions like '%s' will be considered.)"),
-                        key.c_str(), recursion.c_str());
+                        key.wx_str(), recursion.wx_str());
 
     if (cbMessageBox(warn_exist, _("Confirmation"),
                      wxYES_NO | wxICON_QUESTION) == wxID_NO)
@@ -283,16 +298,18 @@ bool nsEnvVars::EnvvarVeto(const wxString& key, wxCheckListBox* lstEnvVars, int
   }// if
 
   return false;
-}// EnvvarVeto
+}// EnvvarVetoUI
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
-bool nsEnvVars::EnvvarsClear(wxCheckListBox* lstEnvVars)
+bool nsEnvVars::EnvvarsClearUI(wxCheckListBox* lstEnvVars)
 {
-#if TRACE_ENVVARS
-  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarsClear")));
+#if defined(TRACE_ENVVARS)
+  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarsClearUI")));
 #endif
 
+  if (!lstEnvVars) return false;
+
   wxString envsNotUnSet(wxEmptyString);
 
   // Unset all (checked) variables of lstEnvVars
@@ -323,32 +340,56 @@ bool nsEnvVars::EnvvarsClear(wxCheckListBox* lstEnvVars)
   {
     wxString msg;
     msg.Printf( _("There was an error unsetting the following environment variables:\n%s"),
-                envsNotUnSet.c_str() );
+                envsNotUnSet.wx_str() );
     cbMessageBox(msg, _("Error"), wxOK | wxCENTRE | wxICON_ERROR);
     return false;
   }
 
   return true;
-}// EnvvarsClear
+}// EnvvarsClearUI
+
+// ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
+
+bool nsEnvVars::EnvvarIsRecursive(const wxString& key, const wxString& value)
+{
+  // Replace all macros the user might have setup for the key
+  wxString the_key = key;
+  Manager::Get()->GetMacrosManager()->ReplaceMacros(the_key);
+
+  wxString recursion;
+  if (platform::windows) recursion = _T("%")+the_key+_("%");
+  else                   recursion = _T("$")+the_key;
+
+  if (value.Contains(recursion))
+    return true;
+
+  return false;
+}// EnvvarIsRecursive
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 bool nsEnvVars::EnvvarDiscard(const wxString &key)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarDiscard")));
 #endif
 
   // Replace all macros the user might have setup for the key
   wxString the_key = key;
   Manager::Get()->GetMacrosManager()->ReplaceMacros(the_key);
+  if (the_key.Trim().IsEmpty()) return false;
+  if (!wxGetEnv(the_key, NULL)) return false; // envvar was not set - nothing to do.
+
+  std::map<wxString,wxString>::iterator it = nsEnvVars::EnvVarsStack.find(the_key);
+  if (it!=nsEnvVars::EnvVarsStack.end()) // found an old envvar on the stack
+    return nsEnvVars::EnvvarApply(the_key, it->second); // restore old value
 
   if (!wxUnsetEnv(the_key))
   {
     Manager::Get()->GetLogManager()->Log(F(
-      _("Unsetting environment variable '%s' failed."), the_key.c_str()));
-    EV_DBGLOG(_T("EnvVars: Unsetting environment variable '%s' failed."),
-      the_key.c_str());
+      _("Unsetting environment variable '%s' failed."), the_key.wx_str())
+    );
+    EV_DBGLOG(_T("EnvVars: Unsetting environment variable '%s' failed."), the_key.wx_str());
     return false;
   }
 
@@ -357,51 +398,55 @@ bool nsEnvVars::EnvvarDiscard(const wxString &key)
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
-bool nsEnvVars::EnvvarApply(const wxString& key, const wxString& value,
-                            wxCheckListBox* lstEnvVars, int sel)
+bool nsEnvVars::EnvvarApply(const wxString& key, const wxString& value)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarApply")));
 #endif
 
-  // Key:   Replace all macros the user might have used
+  // Replace all macros the user might have setup for the key
   wxString the_key = key;
   Manager::Get()->GetMacrosManager()->ReplaceMacros(the_key);
+  if (the_key.Trim().IsEmpty()) return false;
 
   // Value: First, expand stuff like:
   //        set PATH=%PATH%;C:\NewPath OR export PATH=$PATH:/new_path
   //        After, replace all macros the user might have used in addition
-  wxString the_value = value;
   wxString value_set;
   bool     is_set    = wxGetEnv(the_key, &value_set);
+  wxString the_value = value;
   if (is_set)
   {
-    wxString recursion;
-    if (platform::windows) recursion = _T("%")+the_key+_("%");
-    else                   recursion = _T("$")+the_key;
+    std::map<wxString,wxString>::iterator it = nsEnvVars::EnvVarsStack.find(the_key);
+    if (it==nsEnvVars::EnvVarsStack.end()) // envvar not already on the stack
+      nsEnvVars::EnvVarsStack[the_key] = value_set; // remember the old value
 
-    if (the_value.Contains(recursion))
+    // Avoid endless recursion if the value set contains e.g. $PATH, too
+    if (nsEnvVars::EnvvarIsRecursive(the_key,the_value))
     {
-      // Avoid endless recursion if the value set contains e.g. $PATH, too
-      if (value_set.Contains(recursion))
+      if (nsEnvVars::EnvvarIsRecursive(the_key,value_set))
       {
         EV_DBGLOG(_T("EnvVars: Setting environment variable '%s' failed "
-                     "due to unsresolvable recursion."), the_key.c_str());
-        if (lstEnvVars && (sel>=0))
-          lstEnvVars->Check(sel, false); // Unset to visualise it's NOT set
+                     "due to unresolvable recursion."), the_key.wx_str());
         return false;
       }
-      the_value.Replace(recursion.c_str(), value_set.c_str());
+      // Restore original value in case of recursion before
+      if (it!=nsEnvVars::EnvVarsStack.end())
+        value_set = nsEnvVars::EnvVarsStack[the_key];
+      // Resolve recursion now (if any)
+      wxString recursion;
+      if (platform::windows) recursion = _T("%")+the_key+_("%");
+      else                   recursion = _T("$")+the_key;
+      the_value.Replace(recursion.wx_str(), value_set.wx_str());
     }
   }
+  // Replace all macros the user might have setup for the value
   Manager::Get()->GetMacrosManager()->ReplaceMacros(the_value);
 
-  EV_DBGLOG(_T("EnvVars: Trying to set environment variable '%s' to value '%s'..."), the_key.c_str(), the_value.c_str());
-  if (!wxSetEnv(the_key, the_value))
+  EV_DBGLOG(_T("EnvVars: Trying to set environment variable '%s' to value '%s'..."), the_key.wx_str(), the_value.wx_str());
+  if (!wxSetEnv(the_key, the_value)) // set the envvar as computed
   {
-    EV_DBGLOG(_T("EnvVars: Setting environment variable '%s' failed."), the_key.c_str());
-    if (lstEnvVars && (sel>=0))
-      lstEnvVars->Check(sel, false); // Unset to visualise it's NOT set
+    EV_DBGLOG(_T("EnvVars: Setting environment variable '%s' failed."), the_key.wx_str());
     return false;
   }
 
@@ -411,10 +456,10 @@ bool nsEnvVars::EnvvarApply(const wxString& key, const wxString& value,
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 bool nsEnvVars::EnvvarArrayApply(const wxArrayString& envvar,
-                                 wxCheckListBox* lstEnvVars)
+                                 wxCheckListBox*      lstEnvVars)
 {
-#if TRACE_ENVVARS
-  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarApply")));
+#if defined(TRACE_ENVVARS)
+  Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarArrayApply")));
 #endif
 
   if (envvar.GetCount() == 3)
@@ -427,7 +472,7 @@ bool nsEnvVars::EnvvarArrayApply(const wxArrayString& envvar,
     key.Trim(true).Trim(false);
     value.Trim(true).Trim(false);
 
-    int sel = 0;
+    int sel = -1;
     if (lstEnvVars)
     {
       sel = lstEnvVars->Append(key + _T(" = ") + value);
@@ -436,21 +481,24 @@ bool nsEnvVars::EnvvarArrayApply(const wxArrayString& envvar,
 
     if (bCheck)
     {
-      if (EnvvarApply(key, value, lstEnvVars, sel))
-        return true;
+      bool success = EnvvarApply(key, value);
+      if (!success && lstEnvVars && sel>=0)
+        lstEnvVars->Check(sel, false); // Unset on UI to mark it's NOT set
+
+      return success;
     }
     else
       return true; // No need to apply -> success, too.
   }// if
 
   return false;
-}// EnvvarApply
+}// EnvvarArrayApply
 
 // ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- ----- -----
 
 void nsEnvVars::EnvvarSetApply(const wxString& set_name, bool even_if_active)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarSetApply")));
 #endif
 
@@ -470,15 +518,16 @@ void nsEnvVars::EnvvarSetApply(const wxString& set_name, bool even_if_active)
   if (!even_if_active && set_to_apply.IsSameAs(last_set_applied))
   {
     EV_DBGLOG(_T("EnvVars: Set '%s' will not be applied (already active)."),
-      set_to_apply.c_str());
+              set_to_apply.wx_str());
     return;
   }
 
   // Show currently activated set in debug log (for reference)
   wxString set_path = nsEnvVars::GetSetPathByName(set_to_apply);
   EV_DBGLOG(_T("EnvVars: Active envvar set is '%s', config path '%s'."),
-    set_to_apply.c_str(), set_path.c_str());
+    set_to_apply.wx_str(), set_path.wx_str());
 
+  // NOTE: Keep this in sync with EnvVarsConfigDlg::LoadSettings
   // Read and apply all envvars from currently active set in config
   wxArrayString vars     = nsEnvVars::GetEnvvarsBySetPath(set_path);
   size_t envvars_total   = vars.GetCount();
@@ -490,15 +539,17 @@ void nsEnvVars::EnvvarSetApply(const wxString& set_name, bool even_if_active)
     if (nsEnvVars::EnvvarArrayApply(var_array))
       envvars_applied++;
     else
-      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%d."),
-        set_path.c_str(), i);
+    {
+      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%u."),
+        set_path.wx_str(), i);
+    }
   }// for
 
   if (envvars_total>0)
   {
     last_set_applied = set_to_apply;
-    EV_DBGLOG(_T("EnvVars: %d/%d envvars applied within C::B focus."),
-      envvars_applied, envvars_total);
+    EV_DBGLOG(_T("EnvVars: %lu/%lu envvars applied within C::B focus."),
+      static_cast<unsigned long>(envvars_applied), static_cast<unsigned long>(envvars_total));
   }
 }// EnvvarSetApply
 
@@ -506,7 +557,7 @@ void nsEnvVars::EnvvarSetApply(const wxString& set_name, bool even_if_active)
 
 void nsEnvVars::EnvvarSetDiscard(const wxString& set_name)
 {
-#if TRACE_ENVVARS
+#if defined(TRACE_ENVVARS)
   Manager::Get()->GetLogManager()->DebugLog(F(_T("EnvvarSetDiscard")));
 #endif
 
@@ -522,7 +573,7 @@ void nsEnvVars::EnvvarSetDiscard(const wxString& set_name)
   // Show currently activated set in debug log (for reference)
   wxString set_path = nsEnvVars::GetSetPathByName(set_to_discard);
   EV_DBGLOG(_T("EnvVars: Active envvar set is '%s', config path '%s'."),
-    set_to_discard.c_str(), set_path.c_str());
+    set_to_discard.wx_str(), set_path.wx_str());
 
   // Read and apply all envvars from currently active set in config
   wxArrayString vars       = nsEnvVars::GetEnvvarsBySetPath(set_path);
@@ -536,17 +587,23 @@ void nsEnvVars::EnvvarSetDiscard(const wxString& set_name)
     {
       wxString check = var_array[0];
       bool bCheck = check.Trim(true).Trim(false).IsSameAs(_T("1"))?true:false;
-      if (!bCheck || (bCheck && nsEnvVars::EnvvarDiscard(var_array[1]))) // key
+      // Do not unset envvars that are not activated (checked)
+      if (!bCheck) continue; // next for-loop
+
+      // unset the old envvar
+      if (nsEnvVars::EnvvarDiscard(var_array[1]))
         envvars_discarded++;
     }
     else
-      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%d."),
-        set_path.c_str(), i);
+    {
+      EV_DBGLOG(_T("EnvVars: Invalid envvar in '%s' at position #%u."),
+        set_path.wx_str(), i);
+    }
   }// for
 
   if (envvars_total>0)
   {
-    EV_DBGLOG(_T("EnvVars: %d/%d envvars discarded within C::B focus."),
-      envvars_discarded, envvars_total);
+    EV_DBGLOG(_T("EnvVars: %lu/%lu envvars discarded within C::B focus."),
+      static_cast<unsigned long>(envvars_discarded), static_cast<unsigned long>(envvars_total));
   }
 }// EnvvarSetDiscard
