@@ -2,7 +2,9 @@
 #define HELPCONFIGDIALOG_H
 
 #include <wx/intl.h>
-#include "configurationpanel.h"
+
+#include <configurationpanel.h>
+
 #include "help_common.h"
 
 class HelpPlugin;
