@@ -2,52 +2,58 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: help_plugin.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/help_plugin/help_plugin.cpp $
+ * $Revision: 9034 $
+ * $Id: help_plugin.cpp 9034 2013-05-04 03:02:57Z biplab $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/help_plugin/help_plugin.cpp $
  */
 
-#include "help_plugin.h"
-#include "MANFrame.h"
+#include "sdk.h"
+#ifndef CB_PRECOMP
+  #include <wx/filename.h>
+  #include <wx/fs_zip.h>
+  #include <wx/intl.h>
+  #include <wx/menuitem.h>
+  #include <wx/process.h>
+  #include <wx/xrc/xmlres.h>
+  #include "cbeditor.h"
+  #include "cbproject.h"
+  #include "configmanager.h"
+  #include "editormanager.h"
+  #include "globals.h"
+  #include "logmanager.h"
+  #include "macrosmanager.h"
+  #include "manager.h"
+  #include "projectmanager.h"
+#endif
 
-#include <wx/process.h>
-#include <wx/intl.h>
-#include <wx/textdlg.h>
-#include <wx/xrc/xmlres.h>
-#include <wx/fs_zip.h>
-#include <wx/menuitem.h>
-#include <wx/mimetype.h>
-#include <wx/filename.h>
-#include <globals.h> // cbMessageBox
-#include <manager.h>
-#include <configmanager.h>
-#include <editormanager.h>
-#include <logmanager.h>
-#include <projectmanager.h>
-#include <cbeditor.h>
-#include <cbproject.h>
-#include <macrosmanager.h>
 #include <vector>
-#include "cbstyledtextctrl.h"
 
+#include <wx/textdlg.h>
+#include <wx/mimetype.h>
 #include <wx/help.h> //(wxWindows chooses the appropriate help controller class)
 #include <wx/helpbase.h> //(wxHelpControllerBase class)
 #include <wx/helpwin.h> //(Windows Help controller)
+#include <wx/generic/helpext.h> //(external HTML browser controller)
+#include <wx/html/helpctrl.h> //(wxHTML based help controller: wxHtmlHelpController)
 
 #ifdef __WXMSW__
 #include <wx/msw/helpchm.h> // used in case we fail to load the OCX module (it could fail too)
 #include <wx/thread.h>
 #endif
 
-#include <wx/generic/helpext.h> //(external HTML browser controller)
-#include <wx/html/helpctrl.h> //(wxHTML based help controller: wxHtmlHelpController)
+#include <cbstyledtextctrl.h>
+#include <sc_base_types.h>
+#include <sqplus.h>
+
+
+#include "help_plugin.h"
+#include "MANFrame.h"
+
+
 
 // 20 wasn't enough
 #define MAX_HELP_ITEMS 32
 
-#include "scripting/bindings/sc_base_types.h"
-#include "scripting/sqplus/sqplus.h"
-
 int idHelpMenus[MAX_HELP_ITEMS];
 
 // Register the plugin
@@ -58,8 +64,8 @@ namespace
 };
 
 BEGIN_EVENT_TABLE(HelpPlugin, cbPlugin)
-	EVT_MENU(idViewMANViewer, HelpPlugin::OnViewMANViewer)
-	EVT_UPDATE_UI(idViewMANViewer, HelpPlugin::OnUpdateUI)
+    EVT_MENU(idViewMANViewer, HelpPlugin::OnViewMANViewer)
+    EVT_UPDATE_UI(idViewMANViewer, HelpPlugin::OnUpdateUI)
 END_EVENT_TABLE()
 
 #ifdef __WXMSW__
@@ -128,7 +134,11 @@ namespace
       link.pszWindow    = NULL;
       link.fIndexOnFail = TRUE;
 
+      #if defined(_WIN64) | defined(WIN64)
+      fp_htmlHelp(0L, (const wxChar*)m_filename, cbHH_KEYWORD_LOOKUP, (DWORDLONG)&link);
+      #else
       fp_htmlHelp(0L, (const wxChar*)m_filename, cbHH_KEYWORD_LOOKUP, (DWORD)&link);
+      #endif
     }
     else // do it the wx way then (which is the same thing, except for the 0L in the call to fp_htmlHelp)
     {
@@ -144,10 +154,8 @@ HelpPlugin::HelpPlugin()
 : m_pMenuBar(0), m_LastId(0), m_manFrame(0)
 {
   //ctor
-  if(!Manager::LoadResource(_T("help_plugin.zip")))
-  {
+  if (!Manager::LoadResource(_T("help_plugin.zip")))
     NotifyMissingFile(_T("help_plugin.zip"));
-  }
 
   // initialize IDs for Help and popup menu
   for (int i = 0; i < MAX_HELP_ITEMS; ++i)
@@ -166,9 +174,7 @@ HelpPlugin::HelpPlugin()
   ocx_module = LoadLibrary(_T("HHCTRL.OCX"));
 
   if (ocx_module)
-  {
     fp_htmlHelp = (HTMLHELP)GetProcAddress(ocx_module, HTMLHELP_NAME);
-  }
 #endif
 }
 
@@ -176,9 +182,7 @@ HelpPlugin::~HelpPlugin()
 {
 #ifdef __WXMSW__
   if (ocx_module)
-  {
     FreeLibrary(ocx_module);
-  }
 #endif
 }
 
@@ -196,9 +200,7 @@ void HelpPlugin::OnAttach()
         {
             // only add ; if a dir is already set
             if (all_man_dirs.Length() > man_prefix.Length())
-            {
                 all_man_dirs += _T(";");
-            }
 
             all_man_dirs += i->second.name.Mid(man_prefix.Length());
         }
@@ -222,14 +224,10 @@ void HelpPlugin::OnAttach()
     int baseFont = Manager::Get()->GetConfigManager(_T("help_plugin"))->ReadInt(_T("/base_font_size"), 0);
 
     if (baseFont > 0)
-    {
         m_manFrame->SetBaseFontSize(baseFont);
-    }
 
     if (Manager::Get()->GetConfigManager(_T("help_plugin"))->ReadBool(_T("/show_man_viewer"), false))
-    {
         ShowMANViewer();
-    }
 }
 
 cbConfigurationPanel* HelpPlugin::GetConfigurationPanel(wxWindow* parent)
@@ -244,23 +242,21 @@ void HelpPlugin::Reload()
     HelpCommon::HelpFilesVector::iterator it;
 
     for (it = m_Vector.begin(); it != m_Vector.end(); ++it)
-    {
       RemoveFromHelpMenu(idHelpMenus[--counter], it->first);
-    }
 
     // reload configuration (saved in the config dialog)
     HelpCommon::LoadHelpFilesVector(m_Vector);
     BuildHelpMenu();
 }
 
-void HelpPlugin::OnRelease(bool appShutDown)
+void HelpPlugin::OnRelease(bool /*appShutDown*/)
 {
     Manager::Get()->GetConfigManager(_T("help_plugin"))->Write(_T("/base_font_size"), m_manFrame->GetBaseFontSize());
     CodeBlocksDockEvent evt(cbEVT_REMOVE_DOCK_WINDOW);
     evt.pWindow = m_manFrame;
     Manager::Get()->ProcessEvent(evt);
-	m_manFrame->Destroy();
-	m_manFrame = 0;
+    m_manFrame->Destroy();
+    m_manFrame = 0;
 }
 
 void HelpPlugin::BuildHelpMenu()
@@ -271,13 +267,9 @@ void HelpPlugin::BuildHelpMenu()
     for (it = m_Vector.begin(); it != m_Vector.end(); ++it, ++counter)
     {
         if (counter == HelpCommon::getDefaultHelpIndex())
-        {
             AddToHelpMenu(idHelpMenus[counter], it->first + _T("\tF1"), it->second.readFromIni);
-        }
         else
-        {
             AddToHelpMenu(idHelpMenus[counter], it->first, it->second.readFromIni);
-        }
     }
 
     m_LastId = idHelpMenus[0] + counter;
@@ -286,15 +278,13 @@ void HelpPlugin::BuildHelpMenu()
 void HelpPlugin::BuildMenu(wxMenuBar *menuBar)
 {
     if (!IsAttached())
-    {
         return;
-    }
 
     m_pMenuBar = menuBar;
 
     BuildHelpMenu();
 
-    int idx = menuBar->FindMenu(_("View"));
+    int idx = menuBar->FindMenu(_("&View"));
     if (idx != wxNOT_FOUND)
     {
         wxMenu* view = menuBar->GetMenu(idx);
@@ -313,19 +303,15 @@ void HelpPlugin::BuildMenu(wxMenuBar *menuBar)
     }
 }
 
-void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const FileTreeData* data)
+void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const FileTreeData* /*data*/)
 {
   if (!menu || !IsAttached() || !m_Vector.size())
-  {
     return;
-  }
 
   if (type == mtEditorManager)
   {
     if (m_Vector.size() != 0)
-    {
       menu->AppendSeparator();
-    }
 
     // add entries in popup menu
     int counter = 0;
@@ -333,9 +319,7 @@ void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const File
     wxMenu *sub_menu = new wxMenu;
 
     for (it = m_Vector.begin(); it != m_Vector.end(); ++it)
-    {
       AddToPopupMenu(sub_menu, idHelpMenus[counter++], it->first, it->second.readFromIni);
-    }
 
     wxMenuItem *locate_in_menu = new wxMenuItem(0, wxID_ANY, _("&Locate in"), _T(""), wxITEM_NORMAL);
     locate_in_menu->SetSubMenu(sub_menu);
@@ -344,28 +328,28 @@ void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const File
   }
 }
 
-bool HelpPlugin::BuildToolBar(wxToolBar *toolBar)
+bool HelpPlugin::BuildToolBar(wxToolBar * /*toolBar*/)
 {
-	return false;
+    return false;
 }
 
-void HelpPlugin::AddToHelpMenu(int id, const wxString &help, bool fromIni)
+void HelpPlugin::AddToHelpMenu(int id, const wxString &help, bool
+#ifdef __WXMSW__
+    fromIni
+#endif
+)
 {
   if (!m_pMenuBar)
-  {
     return;
-  }
 
-  int pos = m_pMenuBar->FindMenu(_("Help"));
+  int pos = m_pMenuBar->FindMenu(_("&Help"));
 
   if (pos != wxNOT_FOUND)
   {
     wxMenu *helpMenu = m_pMenuBar->GetMenu(pos);
 
     if (id == idHelpMenus[0])
-    {
       helpMenu->AppendSeparator();
-    }
 
 #ifdef __WXMSW__
     if (fromIni)
@@ -378,20 +362,16 @@ void HelpPlugin::AddToHelpMenu(int id, const wxString &help, bool fromIni)
     }
     else
 #endif
-    {
       helpMenu->Append(id, help);
-    }
   }
 }
 
-void HelpPlugin::RemoveFromHelpMenu(int id, const wxString &help)
+void HelpPlugin::RemoveFromHelpMenu(int id, const wxString & /*help*/)
 {
   if (!m_pMenuBar)
-  {
     return;
-  }
 
-  int pos = m_pMenuBar->FindMenu(_("Help"));
+  int pos = m_pMenuBar->FindMenu(_("&Help"));
 
   if (pos != wxNOT_FOUND)
   {
@@ -399,14 +379,16 @@ void HelpPlugin::RemoveFromHelpMenu(int id, const wxString &help)
     wxMenuItem *mi = helpMenu->Remove(id);
 
     if (id)
-    {
       delete mi;
-    }
 
     // remove separator too (if it's the last thing left)
     mi = helpMenu->FindItemByPosition(helpMenu->GetMenuItemCount() - 1);
 
+    #if wxCHECK_VERSION(2, 9, 0)
+    if (mi && (mi->GetKind() == wxITEM_SEPARATOR || mi->GetItemLabelText().IsEmpty()))
+    #else
     if (mi && (mi->GetKind() == wxITEM_SEPARATOR || mi->GetText().IsEmpty()))
+    #endif
     {
       helpMenu->Remove(mi);
       delete mi;
@@ -414,7 +396,11 @@ void HelpPlugin::RemoveFromHelpMenu(int id, const wxString &help)
   }
 }
 
-void HelpPlugin::AddToPopupMenu(wxMenu *menu, int id, const wxString &help, bool fromIni)
+void HelpPlugin::AddToPopupMenu(wxMenu *menu, int id, const wxString &help, bool
+#ifdef __WXMSW__
+    fromIni
+#endif
+)
 {
   if (!help.IsEmpty())
   {
@@ -429,9 +415,7 @@ void HelpPlugin::AddToPopupMenu(wxMenu *menu, int id, const wxString &help, bool
     }
     else
 #endif
-    {
       menu->Append(id, help);
-    }
   }
 }
 
@@ -443,9 +427,7 @@ HelpCommon::HelpFileAttrib HelpPlugin::HelpFileFromId(int id)
   for (it = m_Vector.begin(); it != m_Vector.end(); ++it, ++counter)
   {
     if (idHelpMenus[counter] == id)
-    {
       return it->second;
-    }
   }
 
   return HelpCommon::HelpFileAttrib();
@@ -468,12 +450,12 @@ void HelpPlugin::ShowMANViewer(bool show)
     Manager::Get()->GetConfigManager(_T("help_plugin"))->Write(_T("/show_man_viewer"), show);
 }
 
-void HelpPlugin::OnUpdateUI(wxUpdateUIEvent& event)
+void HelpPlugin::OnUpdateUI(wxUpdateUIEvent& /*event*/)
 {
     wxMenuBar* pbar = Manager::Get()->GetAppFrame()->GetMenuBar();
 
     // uncheck checkbox if window was closed
-    if(m_manFrame && !IsWindowReallyShown(m_manFrame))
+    if (m_manFrame && !IsWindowReallyShown(m_manFrame))
         pbar->Check(idViewMANViewer, false);
 }
 
@@ -486,14 +468,10 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   // Patch by Yorgos Pagles: Use the new attributes to calculate the keyword
   wxString keyword = c_keyword.IsEmpty() ? defkeyword : c_keyword;
 
-  if(keyCase == HelpCommon::UpperCase)
-  {
+  if (keyCase == HelpCommon::UpperCase)
     keyword.MakeUpper();
-  }
   else if (keyCase == HelpCommon::LowerCase)
-  {
     keyword.MakeLower();
-  }
 
   helpfile.Replace(_T("$(keyword)"), keyword);
   Manager::Get()->GetMacrosManager()->ReplaceMacros(helpfile);
@@ -523,9 +501,7 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
         }
       }
       else
-      {
         Manager::Get()->GetLogManager()->DebugLog(_T("Couldn't run script"));
-      }
 
       return;
   }
@@ -536,13 +512,11 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
     Manager::Get()->GetLogManager()->DebugLog(_T("Launching ") + helpfile);
     cbMimePlugin* p = Manager::Get()->GetPluginManager()->GetMIMEHandlerForFile(helpfile);
     if (p)
-    {
-        p->OpenFile(helpfile);
-    }
+      p->OpenFile(helpfile);
     else
     {
-        reinterpret_cast<MANFrame *>(m_manFrame)->LoadPage(helpfile);
-        ShowMANViewer();
+      reinterpret_cast<MANFrame *>(m_manFrame)->LoadPage(helpfile);
+      ShowMANViewer();
     }
     return;
   }
@@ -559,18 +533,23 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   if (helpfile.Mid(0, man_prefix.size()).CmpNoCase(man_prefix) == 0)
   {
     if (reinterpret_cast<MANFrame *>(m_manFrame)->SearchManPage(c_helpfile, keyword))
-    {
-        Manager::Get()->GetLogManager()->DebugLog(_T("Couldn't find man page"));
-    }
+      Manager::Get()->GetLogManager()->DebugLog(_T("Couldn't find man page"));
     else
-    {
-        Manager::Get()->GetLogManager()->DebugLog(_T("Launching man page"));
-    }
+      Manager::Get()->GetLogManager()->DebugLog(_T("Launching man page"));
 
     ShowMANViewer();
     return;
   }
 
+#ifdef __WXMSW__
+  if (helpfile.StartsWith(_T("ms-xhelp:///")))
+  {
+    Manager::Get()->GetLogManager()->DebugLog(_T("Launching ") + helpfile);
+    ShellExecute(0, 0, helpfile.c_str(), 0, 0, SW_SHOWDEFAULT);
+    return;
+  }
+#endif // __WXMSW__
+
   wxFileName the_helpfile = wxFileName(helpfile);
   Manager::Get()->GetLogManager()->DebugLog(_T("Help File is ") + helpfile);
 
@@ -580,7 +559,7 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
     msg << _("Couldn't find the help file:\n")
         << the_helpfile.GetFullPath() << _("\n")
         << _("Do you want to run the associated program anyway?");
-    if (!(cbMessageBox(msg, _("Warning"), wxICON_WARNING | wxYES_NO | wxNO_DEFAULT) == wxID_YES));
+    if (!(cbMessageBox(msg, _("Warning"), wxICON_WARNING | wxYES_NO | wxNO_DEFAULT) == wxID_YES))
         return;
   }
 
@@ -590,21 +569,21 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   // Operate on help files with keyword search (windows only)
   if (!keyword.IsEmpty())
   {
-  	if (ext.CmpNoCase(_T("hlp")) == 0)
-  	{
+    if (ext.CmpNoCase(_T("hlp")) == 0)
+    {
       wxWinHelpController HelpCtl;
       HelpCtl.Initialize(helpfile);
       HelpCtl.KeywordSearch(keyword);
       return;
-  	}
+    }
 
-  	if (ext.CmpNoCase(_T("chm")) == 0)
-  	{
+    if ((ext.CmpNoCase(_T("chm")) == 0) || (ext.CmpNoCase(_T("col")) == 0))
+    {
       LaunchCHMThread *p_thread = new LaunchCHMThread(helpfile, keyword);
       p_thread->Create();
       p_thread->Run();
       return;
-  	}
+    }
   }
 #endif
 
