@@ -5,7 +5,7 @@
  * Copyright: (c) Pecan Heber
  * License:   GPL
  **************************************************************/
-// RCS-ID:      $Id: cbkeybinder.h 4874 2008-02-12 18:18:15Z pecan $
+// RCS-ID:      $Id: cbkeybinder.h 8328 2012-09-01 19:21:09Z pecan $
 
 #ifndef CBKEYBINDER_H
 #define CBKEYBINDER_H
@@ -26,7 +26,7 @@
 #include "keybinder.h"
 
 // --Version-Rlease-Feature-Fix-------
-#define VERSION "1.0.46 2008/02/12"
+#define VERSION "1.0.50 2012/09/1"
 // -----------------------------------
 class MyDialog;
 class wxKeyConfigPanel;
@@ -81,7 +81,7 @@ class cbKeyBinder : public cbPlugin
         // utility function to update the menu key labels
         // and re-attach the window event handlers after key changes
         void UpdateArr(wxKeyProfileArray &r);
-        void Rebind();
+        void Rebind(bool update=true);
         // key definition configuration dialog
         cbConfigurationPanel* OnKeyConfig(wxWindow* parent);
         void OnKeyConfigDialogDone(MyDialog* dlg);
@@ -94,6 +94,8 @@ class cbKeyBinder : public cbPlugin
         int IsEnabledMerge() const {return m_mergeEnabled;}
         bool IsMerging() const {return m_bMerging;}
         void IsMerging(bool state){m_bMerging = state;}
+        bool VerifyKeyBind(const wxString& strKeyCode, const int numShortcuts);
+        int RemoveKeyBindingsFor(const wxString& strKeyCode, wxKeyProfile* pkp);
 
     protected:
         wxADD_KEYBINDER_SUPPORT();
@@ -118,6 +120,8 @@ class cbKeyBinder : public cbPlugin
         void OnTimerAlarm(wxTimerEvent& event);
         void OnMenuBarModify(CodeBlocksEvent& event);
         wxString FindAppPath(const wxString& argv0, const wxString& cwd, const wxString& appVariableName);
+        void MergeAcceleratorTable(const bool mergeAccelTable = false);
+        int  RemoveCopyPasteBindings(wxKeyProfile* pkp);
 
 
         wxWindow*       pcbWindow;              //main app window
@@ -695,3 +699,14 @@ private:
 //          45) Killerbot changes to header includes 2008/12/28
 //          46) Fixed: [ Bug #12823 ] keybinder breaks layout submenu on linux
 // ----------------------------------------------------------------------------
+//  Commit  1.0.48 2009/06/8
+//          47) If tree item is a sub-menu don't allow key assignment
+//          48) Change KeyBinder menu access from GetLabel() to GetLabel().Trim() (wx2.8.9/10)
+// ----------------------------------------------------------------------------
+//  Commit  1.0.49 2010/03/3
+//          49) Apply patch 2885 by techy
+// ----------------------------------------------------------------------------
+//  Commit  1.0.50 2012/09/1
+//          50) Merge global accelerators into keybinder, leave the rest alone
+//              Remove bindings for Ctrl-C/P/X, allowing native behavior
+// ----------------------------------------------------------------------------
