@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 4504 $
-* $Id: wxsmithpluginregistrants.cpp 4504 2007-10-02 21:52:30Z byo $
-* $HeadURL: svn+ssh://byo@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/plugin/wxsmithpluginregistrants.cpp $
+* $Revision: 9151 $
+* $Id: processingdlg.cpp 9151 2013-06-12 14:32:09Z biplab $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/lib_finder/processingdlg.cpp $
 */
 
 #include "processingdlg.h"
@@ -31,13 +31,18 @@
 #include <prep.h>
 
 //(*InternalHeaders(ProcessingDlg)
-#include <wx/intl.h>
+#include <wx/gauge.h>
+#include <wx/sizer.h>
+#include <wx/button.h>
 #include <wx/string.h>
+#include <wx/intl.h>
+#include <wx/stattext.h>
 //*)
 
-#include "libraryconfigmanager.h"
+#include "librarydetectionmanager.h"
 #include "resultmap.h"
 #include "lib_finder.h"
+#include "libselectdlg.h"
 
 //(*IdInit(ProcessingDlg)
 const long ProcessingDlg::ID_STATICTEXT1 = wxNewId();
@@ -45,16 +50,15 @@ const long ProcessingDlg::ID_GAUGE1 = wxNewId();
 const long ProcessingDlg::ID_BUTTON1 = wxNewId();
 //*)
 
-BEGIN_EVENT_TABLE(ProcessingDlg,wxDialog)
+BEGIN_EVENT_TABLE(ProcessingDlg,wxScrollingDialog)
 	//(*EventTable(ProcessingDlg)
 	//*)
 END_EVENT_TABLE()
 
-ProcessingDlg::ProcessingDlg(wxWindow* parent,LibraryConfigManager& Manager,TypedResults& KnownResults,ResultMap& FoundResults,wxWindowID id):
+ProcessingDlg::ProcessingDlg(wxWindow* parent,LibraryDetectionManager& Manager,TypedResults& KnownResults,wxWindowID id):
     StopFlag(false),
     m_Manager(Manager),
-    m_KnownResults(KnownResults),
-    m_FoundResults(FoundResults)
+    m_KnownResults(KnownResults)
 {
 	//(*Initialize(ProcessingDlg)
 	Create(parent, id, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxCAPTION, _T("id"));
@@ -79,7 +83,7 @@ ProcessingDlg::~ProcessingDlg()
 {
 }
 
-void ProcessingDlg::OnButton1Click(wxCommandEvent& event)
+void ProcessingDlg::OnButton1Click(wxCommandEvent& /*event*//*event*/)
 {
     StopBtn->Disable();
     StopFlag = true;
@@ -143,45 +147,191 @@ void ProcessingDlg::ReadDir(const wxString& DirName)
 
 bool ProcessingDlg::ProcessLibs()
 {
-    Gauge1->SetRange(m_Manager.GetLibraryCount());
-
+    int TotalCount = 0;
     for ( int i=0; i<m_Manager.GetLibraryCount(); ++i )
     {
-        if ( StopFlag ) return false;
-        ProcessLibrary(m_Manager.GetLibrary(i));
+        TotalCount += (int)m_Manager.GetLibrary(i)->Configurations.size();
+    }
+
+    Gauge1->SetRange( TotalCount );
+
+    int progress = 1;
+    for ( int i=0; i<m_Manager.GetLibraryCount(); ++i )
+    {
+        const LibraryDetectionConfigSet* Set = m_Manager.GetLibrary(i);
+        for ( size_t j=0; j<Set->Configurations.size(); ++j )
+        {
+            if ( StopFlag ) return false;
+            Gauge1->SetValue( progress++ );
+
+            ProcessLibrary( &Set->Configurations[j], Set );
+        }
     }
 
     return !StopFlag;
 }
 
-void ProcessingDlg::ProcessLibrary(const LibraryConfig* Config)
+bool ProcessingDlg::ProcessLibs( const wxArrayString& Shortcuts )
+{
+    int TotalCount = 0;
+    for ( int i=0; i<m_Manager.GetLibraryCount(); ++i )
+    {
+        if ( const LibraryDetectionConfigSet* Set = m_Manager.GetLibrary( Shortcuts[i] ) )
+        {
+            TotalCount += (int)Set->Configurations.size();
+        }
+    }
+    Gauge1->SetRange( TotalCount );
+
+    int progress = 1;
+    for ( size_t i=0; i<Shortcuts.Count(); ++i )
+    {
+        if ( StopFlag ) return false;
+        Gauge1->SetValue( progress++ );
+        if ( const LibraryDetectionConfigSet* Set = m_Manager.GetLibrary( Shortcuts[i] ) )
+        {
+            for ( size_t j=0; j<Set->Configurations.size(); ++j )
+            {
+                if ( StopFlag ) return false;
+                Gauge1->SetValue( progress++ );
+
+                ProcessLibrary( &Set->Configurations[j], Set );
+            }
+        }
+    }
+
+    return !StopFlag;
+}
+
+void ProcessingDlg::ApplyResults(bool addOnly)
+{
+    ResultArray Results;
+    m_FoundResults.GetAllResults(Results);
+    if ( Results.Count() == 0 )
+    {
+        cbMessageBox(_("Didn't found any library"));
+        return;
+    }
+
+    wxArrayString Names;
+    wxArrayInt Selected;
+    wxString PreviousVar;
+    for ( size_t i=0; i<Results.Count(); ++i )
+    {
+        wxString& Name =
+            Results[i]->Description.IsEmpty() ?
+            Results[i]->LibraryName :
+            Results[i]->Description;
+
+        Names.Add(
+            wxString::Format(_T("%s : %s"),
+                Results[i]->ShortCode.c_str(),
+                Name.c_str()));
+        if ( PreviousVar != Results[i]->ShortCode )
+        {
+            Selected.Add((int)i);
+            PreviousVar = Results[i]->ShortCode;
+        }
+    }
+
+    LibSelectDlg Dlg( this, Names, addOnly );
+    Dlg.SetSelections( Selected );
+
+    if ( Dlg.ShowModal() == wxID_OK )
+    {
+        // Fetch selected libraries
+        Selected = Dlg.GetSelections();
+
+        // Clear all results if requested
+        if ( Dlg.GetClearAllPrevious() )
+        {
+            m_KnownResults[rtDetected].Clear();
+        }
+
+        // Here we will store names of libraries set-up so far
+        // by checking entries we will be able to find out whether
+        // we have to clear previous settings
+        wxArrayString AddedLibraries;
+
+        for ( size_t i = 0; i<Selected.Count(); i++ )
+        {
+            wxString Library = Results[Selected[i]]->ShortCode;
+
+            if ( true )
+            {
+                // Here we set-up internal libraries configuration
+                if ( Dlg.GetClearSelectedPrevious() )
+                {
+                    if ( AddedLibraries.Index(Library)==wxNOT_FOUND )
+                    {
+                        // Ok, have to delete previosu results since this is the first
+                        // occurence of this library in new set
+                        ResultArray& Previous = m_KnownResults[rtDetected].GetShortCode(Library);
+                        for ( size_t j=0; j<Previous.Count(); j++ )
+                        {
+                            delete Previous[j];
+                        }
+                        Previous.Clear();
+                    }
+                    AddedLibraries.Add(Library);
+                }
+                else if ( Dlg.GetDontClearPrevious() )
+                {
+                    // Find and remove duplicates
+                    ResultArray& Previous = m_KnownResults[rtDetected].GetShortCode(Library);
+                    for ( size_t j=0; j<Previous.Count(); j++ )
+                    {
+                        if ( *Previous[j] == *Results[Selected[i]] )
+                        {
+                            delete Previous[j];
+                            Previous.RemoveAt(j--);
+                        }
+                    }
+                }
+
+                // Add the result
+                m_KnownResults[rtDetected].GetShortCode(Library).Add(new LibraryResult(*Results[Selected[i]]));
+            }
+
+            if ( Dlg.GetSetupGlobalVars() )
+            {
+                // Here we set-up global variables
+                Results[Selected[i]]->SetGlobalVar();
+            }
+        }
+    }
+}
+
+
+void ProcessingDlg::ProcessLibrary(const LibraryDetectionConfig* Config,const LibraryDetectionConfigSet* Set)
 {
     Status->SetLabel(
         wxString::Format(
             _("Searching library \"%s\""),
-            Config->ShortCode.c_str()));
+            Set->ShortCode.c_str()));
 
-    CheckFilter(_T(""),wxStringStringMap(),wxArrayString(),Config,0);
+    CheckFilter(_T(""),wxStringStringMap(),wxArrayString(),Config,Set,0);
 }
 
 void ProcessingDlg::CheckFilter(
     const wxString& OldBasePath,
     const wxStringStringMap& OldVars,
     const wxArrayString& OldCompilers,
-    const LibraryConfig* Config,
+    const LibraryDetectionConfig* Config,
+    const LibraryDetectionConfigSet* Set,
     int WhichFilter)
 {
     if ( (int)Config->Filters.size() <= WhichFilter )
     {
-        FoundLibrary(OldBasePath,OldVars,OldCompilers,Config);
+        FoundLibrary(OldBasePath,OldVars,OldCompilers,Config,Set);
         return;
     }
 
-    const LibraryFilter& Filter = Config->Filters[WhichFilter];
+    const LibraryDetectionFilter& Filter = Config->Filters[WhichFilter];
 
     switch ( Filter.Type )
     {
-        case LibraryFilter::File:
+        case LibraryDetectionFilter::File:
         {
             // Split path
             wxArrayString Pattern;
@@ -242,12 +392,12 @@ void ProcessingDlg::CheckFilter(
                 }
 
                 // Ok, this filter matches, let's advance to next filet
-                CheckFilter(BasePath,Vars,OldCompilers,Config,WhichFilter+1);
+                CheckFilter(BasePath,Vars,OldCompilers,Config,Set,WhichFilter+1);
             }
             break;
         }
 
-        case LibraryFilter::Platform:
+        case LibraryDetectionFilter::Platform:
         {
             wxStringTokenizer Tokenizer(Filter.Value,_T("| \t"));
             bool IsPlatform = false;
@@ -339,12 +489,12 @@ void ProcessingDlg::CheckFilter(
 
             if ( IsPlatform )
             {
-                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,WhichFilter+1);
+                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,Set,WhichFilter+1);
             }
             break;
         }
 
-        case LibraryFilter::Exec:
+        case LibraryDetectionFilter::Exec:
         {
             bool IsExec = false;
             if ( wxIsAbsolutePath(Filter.Value) )
@@ -380,26 +530,26 @@ void ProcessingDlg::CheckFilter(
 
             if ( IsExec )
             {
-                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,WhichFilter+1);
+                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,Set,WhichFilter+1);
             }
             break;
         }
 
-        case LibraryFilter::PkgConfig:
+        case LibraryDetectionFilter::PkgConfig:
         {
             if ( m_KnownResults[rtPkgConfig].IsShortCode(Filter.Value) )
             {
-                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,WhichFilter+1);
+                CheckFilter(OldBasePath,OldVars,OldCompilers,Config,Set,WhichFilter+1);
             }
             break;
         }
 
-        case LibraryFilter::Compiler:
+        case LibraryDetectionFilter::Compiler:
         {
             if ( OldCompilers.IsEmpty() )
             {
                 // If this is the first compiler filter, let's build new list and continue
-                CheckFilter(OldBasePath,OldVars,wxStringTokenize(Filter.Value,_T("| \t")),Config,WhichFilter+1);
+                CheckFilter(OldBasePath,OldVars,wxStringTokenize(Filter.Value,_T("| \t")),Config,Set,WhichFilter+1);
             }
             else
             {
@@ -418,17 +568,19 @@ void ProcessingDlg::CheckFilter(
 
                 if ( !Compilers.IsEmpty() )
                 {
-                    CheckFilter(OldBasePath,OldVars,Compilers,Config,WhichFilter+1);
+                    CheckFilter(OldBasePath,OldVars,Compilers,Config,Set,WhichFilter+1);
                 }
             }
             break;
         }
 
-        case LibraryFilter::None:
+        case LibraryDetectionFilter::None:
         {
-            CheckFilter(OldBasePath,OldVars,OldCompilers,Config,WhichFilter+1);
+            CheckFilter(OldBasePath,OldVars,OldCompilers,Config,Set,WhichFilter+1);
             break;
         }
+        default:
+            break;
     }
 }
 
@@ -448,7 +600,7 @@ bool ProcessingDlg::IsVariable(const wxString& NamePart) const
     return true;
 }
 
-void ProcessingDlg::FoundLibrary(const wxString& OldBasePath,const wxStringStringMap& OldVars,const wxArrayString& Compilers,const LibraryConfig* Config)
+void ProcessingDlg::FoundLibrary(const wxString& OldBasePath,const wxStringStringMap& OldVars,const wxArrayString& Compilers,const LibraryDetectionConfig* Config,const LibraryDetectionConfigSet* Set)
 {
     wxStringStringMap Vars = OldVars;
     wxString BasePath = OldBasePath;
@@ -458,14 +610,14 @@ void ProcessingDlg::FoundLibrary(const wxString& OldBasePath,const wxStringStrin
     LibraryResult* Result = new LibraryResult();
 
     Result->Type = rtDetected;
-    Result->ShortCode = Config->ShortCode;
-    Result->LibraryName = FixVars(Config->LibraryName,Vars);
+    Result->ShortCode = Set->ShortCode;
+    Result->LibraryName = FixVars(Set->LibraryName,Vars);
     Result->BasePath = FixPath(BasePath);
     Result->PkgConfigVar = Config->PkgConfigVar;
     Result->Description = FixVars(Config->Description,Vars);
 
     Result->Compilers = Compilers;
-    Result->Categories = Config->Categories;
+    Result->Categories = Set->Categories;
 
     for ( size_t i=0; i<Config->IncludePaths.Count(); i++ )
     {
@@ -502,7 +654,10 @@ void ProcessingDlg::FoundLibrary(const wxString& OldBasePath,const wxStringStrin
         Result->LFlags.Add(FixVars(Config->LFlags[i],Vars));
     }
 
-    ResultArray& Array = m_FoundResults.GetShortCode(Config->ShortCode);
+    Result->Headers = Config->Headers;
+    Result->Require = Config->Require;
+
+    ResultArray& Array = m_FoundResults.GetShortCode(Set->ShortCode);
     Array.Add(Result);
 }
 
