@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 4504 $
-* $Id: wxsmithpluginregistrants.cpp 4504 2007-10-02 21:52:30Z byo $
-* $HeadURL: svn+ssh://byo@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/plugin/wxsmithpluginregistrants.cpp $
+* $Revision: 9336 $
+* $Id: projectconfigurationpanel.cpp 9336 2013-09-17 22:52:50Z fuscated $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/lib_finder/projectconfigurationpanel.cpp $
 */
 
 #include "projectconfigurationpanel.h"
@@ -36,11 +36,14 @@
 //*)
 
 #include <wx/tokenzr.h>
+#include <wx/choicdlg.h>
 
 #include "lib_finder.h"
+#include "headersdetectordlg.h"
 
 //(*IdInit(ProjectConfigurationPanel)
 const long ProjectConfigurationPanel::ID_LISTBOX1 = wxNewId();
+const long ProjectConfigurationPanel::ID_BUTTON6 = wxNewId();
 const long ProjectConfigurationPanel::ID_CHECKBOX2 = wxNewId();
 const long ProjectConfigurationPanel::ID_BUTTON4 = wxNewId();
 const long ProjectConfigurationPanel::ID_BUTTON1 = wxNewId();
@@ -49,6 +52,7 @@ const long ProjectConfigurationPanel::ID_TREECTRL1 = wxNewId();
 const long ProjectConfigurationPanel::ID_STATICTEXT1 = wxNewId();
 const long ProjectConfigurationPanel::ID_TEXTCTRL2 = wxNewId();
 const long ProjectConfigurationPanel::ID_CHECKBOX1 = wxNewId();
+const long ProjectConfigurationPanel::ID_BUTTON5 = wxNewId();
 const long ProjectConfigurationPanel::ID_TEXTCTRL1 = wxNewId();
 const long ProjectConfigurationPanel::ID_BUTTON3 = wxNewId();
 const long ProjectConfigurationPanel::ID_STATICTEXT2 = wxNewId();
@@ -95,6 +99,7 @@ ProjectConfigurationPanel::ProjectConfigurationPanel(wxWindow* parent,ProjectCon
 	wxStaticBoxSizer* StaticBoxSizer2;
 	wxBoxSizer* BoxSizer6;
 	wxBoxSizer* BoxSizer5;
+	wxBoxSizer* BoxSizer7;
 	wxBoxSizer* BoxSizer2;
 	wxStaticBoxSizer* StaticBoxSizer3;
 	wxBoxSizer* BoxSizer1;
@@ -109,6 +114,8 @@ ProjectConfigurationPanel::ProjectConfigurationPanel(wxWindow* parent,ProjectCon
 	StaticBoxSizer1 = new wxStaticBoxSizer(wxVERTICAL, this, _("Libraries used in project"));
 	m_UsedLibraries = new wxListBox(this, ID_LISTBOX1, wxDefaultPosition, wxSize(147,123), 0, 0, 0, wxDefaultValidator, _T("ID_LISTBOX1"));
 	StaticBoxSizer1->Add(m_UsedLibraries, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	Button2 = new wxButton(this, ID_BUTTON6, _("Try to detect missing ones"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON6"));
+	StaticBoxSizer1->Add(Button2, 0, wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	BoxSizer5->Add(StaticBoxSizer1, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_DisableAuto = new wxStaticBoxSizer(wxVERTICAL, this, _("Extra settings"));
 	m_NoAuto = new wxCheckBox(this, ID_CHECKBOX2, _("Don\'t setup automatically"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX2"));
@@ -140,9 +147,14 @@ ProjectConfigurationPanel::ProjectConfigurationPanel(wxWindow* parent,ProjectCon
 	m_Filter = new wxTextCtrl(this, ID_TEXTCTRL2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL2"));
 	BoxSizer4->Add(m_Filter, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	StaticBoxSizer2->Add(BoxSizer4, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	BoxSizer7 = new wxBoxSizer(wxHORIZONTAL);
 	m_Tree = new wxCheckBox(this, ID_CHECKBOX1, _("Show as tree"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX1"));
 	m_Tree->SetValue(true);
-	StaticBoxSizer2->Add(m_Tree, 0, wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	BoxSizer7->Add(m_Tree, 1, wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	Button1 = new wxButton(this, ID_BUTTON5, _("Edit"), wxDefaultPosition, wxDefaultSize, wxBU_EXACTFIT, wxDefaultValidator, _T("ID_BUTTON5"));
+	Button1->Hide();
+	BoxSizer7->Add(Button1, 0, wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	StaticBoxSizer2->Add(BoxSizer7, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	BoxSizer3->Add(StaticBoxSizer2, 1, wxBOTTOM|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	StaticBoxSizer3 = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Unknown library"));
 	m_UnknownLibrary = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
@@ -162,6 +174,7 @@ ProjectConfigurationPanel::ProjectConfigurationPanel(wxWindow* parent,ProjectCon
 	BoxSizer1->SetSizeHints(this);
 
 	Connect(ID_LISTBOX1,wxEVT_COMMAND_LISTBOX_SELECTED,(wxObjectEventFunction)&ProjectConfigurationPanel::Onm_UsedLibrariesSelect);
+	Connect(ID_BUTTON6,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProjectConfigurationPanel::OnButton2Click);
 	Connect(ID_BUTTON4,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProjectConfigurationPanel::Onm_AddScriptClick);
 	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProjectConfigurationPanel::Onm_AddClick);
 	Connect(ID_BUTTON2,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProjectConfigurationPanel::Onm_RemoveClick);
@@ -177,10 +190,7 @@ ProjectConfigurationPanel::ProjectConfigurationPanel(wxWindow* parent,ProjectCon
 	m_EventText->Show(!lib_finder::IsExtraEvent());
 
 	if ( m_Project->GetBuildScripts().Index(_T("lib_finder.script")) != wxNOT_FOUND )
-	{
-	    // There's a build script yet
-	    m_AddScript->Disable();
-	}
+	    m_AddScript->Disable(); // There's a build script yet
 
 	m_ConfCopy = *m_Configuration;
 	FillKnownLibraries();
@@ -195,7 +205,7 @@ ProjectConfigurationPanel::~ProjectConfigurationPanel()
 
 wxString ProjectConfigurationPanel::GetTitle() const
 {
-    return _T("Libraries");
+    return _("Libraries");
 }
 
 wxString ProjectConfigurationPanel::GetBitmapBaseName() const
@@ -267,23 +277,21 @@ void ProjectConfigurationPanel::FillKnownLibraries()
     // Collecting list of all global variable names,
     // currently without pkg-config entries (will be used later)
     wxArrayString Vars;
-    for ( int i=0; i<rtCount; i++ )
+    for ( int i = 0; i < rtCount; ++i )
     {
         if ( i==rtPkgConfig ) continue;
         m_KnownLibs[i].GetShortCodes(Vars);
     }
 
-    for ( size_t i=0; i<Vars.Count(); i++ )
+    for ( size_t i = 0; i < Vars.Count(); ++i )
     {
         ResultArray* Array = 0;
-        for ( int j=0; j<rtCount; j++ )
+        for ( int j = 0; j < rtCount; ++j )
         {
             if ( j!=rtPkgConfig )
             {
                 if ( m_KnownLibs[j].IsShortCode(Vars[i]) )
-                {
                     Array = &m_KnownLibs[j].GetShortCode(Vars[i]);
-                }
             }
         }
 
@@ -303,21 +311,15 @@ void ProjectConfigurationPanel::FillKnownLibraries()
         {
             wxArrayString& Categories = (*Array)[0]->Categories;
             if ( Categories.IsEmpty() )
-            {
                 BuildEntry(OtherCategoryId(),*Array);
-            }
             else
             {
-                for ( size_t i=0; i<Categories.Count(); i++ )
-                {
-                    BuildEntry(CategoryId(Categories[i]),*Array);
-                }
+                for ( size_t cat = 0; cat < Categories.Count(); ++cat )
+                    BuildEntry(CategoryId(Categories[cat]), *Array);
             }
         }
         else
-        {
-            BuildEntry(m_KnownLibrariesTree->GetRootItem(),*Array);
-        }
+            BuildEntry(m_KnownLibrariesTree->GetRootItem(), *Array);
     }
 
     // Now add pkg-config entries in separate category at the end
@@ -346,7 +348,7 @@ void ProjectConfigurationPanel::FillKnownLibraries()
     }
 
     // Ok, let's present all results
-    m_KnownLibrariesTree->ExpandAll();
+//    m_KnownLibrariesTree->ExpandAll();
     m_KnownLibrariesTree->Thaw();
 }
 
@@ -354,18 +356,14 @@ void ProjectConfigurationPanel::BuildEntry(const wxTreeItemId& Id,ResultArray& A
 {
     wxString Name = Array[0]->ShortCode;
     if ( !Array[0]->LibraryName.IsEmpty() )
-    {
         Name = Name + _T(": ") + Array[0]->LibraryName;
-    }
     m_KnownLibrariesTree->AppendItem(Id,Name,0,0,new TreeItemData(Array[0]->ShortCode));
 }
 
 wxTreeItemId ProjectConfigurationPanel::OtherCategoryId()
 {
     if ( m_IsOtherCategory )
-    {
         return m_CategoryMap[_T(".other")];
-    }
 
     m_IsOtherCategory = true;
     return m_CategoryMap[_T(".other")] = m_KnownLibrariesTree->AppendItem(m_KnownLibrariesTree->GetRootItem(),_("Other"));
@@ -374,9 +372,7 @@ wxTreeItemId ProjectConfigurationPanel::OtherCategoryId()
 wxTreeItemId ProjectConfigurationPanel::PkgConfigId()
 {
     if ( m_IsPkgConfig )
-    {
         return m_CategoryMap[_T(".pkg-config")];
-    }
     m_IsPkgConfig = true;
     return m_CategoryMap[_T(".pkg-config")] = m_KnownLibrariesTree->AppendItem(m_KnownLibrariesTree->GetRootItem(),_("Available in pkg-config"));
 }
@@ -384,9 +380,7 @@ wxTreeItemId ProjectConfigurationPanel::PkgConfigId()
 wxTreeItemId ProjectConfigurationPanel::CategoryId(const wxString& Category)
 {
     if ( m_CategoryMap.find(Category.Lower()) != m_CategoryMap.end() )
-    {
         return m_CategoryMap[Category.Lower()];
-    }
 
     wxStringTokenizer Tokens(Category,_T("."),wxTOKEN_STRTOK);
     wxString PathSoFar = _T("");
@@ -442,27 +436,27 @@ wxTreeItemId ProjectConfigurationPanel::CategoryId(const wxString& Category)
     return IdSoFar;
 }
 
-void ProjectConfigurationPanel::Onm_TreeClick(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_TreeClick(wxCommandEvent& /*event*/)
 {
     FillKnownLibraries();
 }
 
-void ProjectConfigurationPanel::OnTimer1Trigger(wxTimerEvent& event)
+void ProjectConfigurationPanel::OnTimer1Trigger(wxTimerEvent& /*event*/)
 {
     FillKnownLibraries();
 }
 
-void ProjectConfigurationPanel::Onm_FilterText(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_FilterText(wxCommandEvent& /*event*/)
 {
     Timer1.Start(500,true);
 }
 
-void ProjectConfigurationPanel::Onm_FilterTextEnter(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_FilterTextEnter(wxCommandEvent& /*event*/)
 {
     FillKnownLibraries();
 }
 
-void ProjectConfigurationPanel::Onm_KnownLibrariesTreeSelectionChanged(wxTreeEvent& event)
+void ProjectConfigurationPanel::Onm_KnownLibrariesTreeSelectionChanged(wxTreeEvent& /*event*/)
 {
     if ( m_KnownLibrariesTree->GetSelection().IsOk() )
     {
@@ -480,12 +474,12 @@ void ProjectConfigurationPanel::Onm_KnownLibrariesTreeSelectionChanged(wxTreeEve
     m_Add->Disable();
 }
 
-void ProjectConfigurationPanel::Onm_UsedLibrariesSelect(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_UsedLibrariesSelect(wxCommandEvent& /*event*/)
 {
     m_Remove->Enable( m_UsedLibraries->GetSelection() != wxNOT_FOUND );
 }
 
-void ProjectConfigurationPanel::Onm_RemoveClick(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_RemoveClick(wxCommandEvent& /*event*/)
 {
     if ( m_UsedLibraries->GetSelection() != wxNOT_FOUND )
     {
@@ -500,7 +494,7 @@ void ProjectConfigurationPanel::Onm_RemoveClick(wxCommandEvent& event)
     }
 }
 
-void ProjectConfigurationPanel::Onm_AddClick(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_AddClick(wxCommandEvent& /*event*/)
 {
     if ( m_KnownLibrariesTree->GetSelection().IsOk() )
     {
@@ -519,12 +513,12 @@ void ProjectConfigurationPanel::Onm_AddClick(wxCommandEvent& event)
     }
 }
 
-void ProjectConfigurationPanel::Onm_UnknownLibraryText(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_UnknownLibraryText(wxCommandEvent& /*event*/)
 {
     m_AddUnknown->Enable(m_UnknownLibrary->GetLastPosition()!=0);
 }
 
-void ProjectConfigurationPanel::Onm_AddUnknownClick(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_AddUnknownClick(wxCommandEvent& /*event*/)
 {
     wxString Library = m_UnknownLibrary->GetValue();
     if ( !Library.IsEmpty() )
@@ -539,7 +533,7 @@ void ProjectConfigurationPanel::Onm_AddUnknownClick(wxCommandEvent& event)
     }
 }
 
-void ProjectConfigurationPanel::Onm_AddScriptClick(wxCommandEvent& event)
+void ProjectConfigurationPanel::Onm_AddScriptClick(wxCommandEvent& /*event*/)
 {
     wxFile Fl(m_Project->GetBasePath() + wxFileName::GetPathSeparator() + _T("lib_finder.script"),wxFile::write);
     if ( !Fl.IsOpened() )
@@ -569,3 +563,111 @@ void ProjectConfigurationPanel::Onm_AddScriptClick(wxCommandEvent& event)
 
     wxMessageBox(_("Script \"lib_finder.script\" successfully added."),_("lib_finder.script Success"),wxOK|wxICON_INFORMATION,this);
 }
+
+void ProjectConfigurationPanel::OnButton2Click(wxCommandEvent& /*event*/)
+{
+    wxArrayString HeadersBase;
+    if ( HeadersDetectorDlg(this,m_Project,HeadersBase).ShowModal() != wxID_OK )
+    {
+        cbMessageBox( _("Cancelled the search"), _("Cancelled"), wxOK | wxICON_WARNING, this );
+        return;
+    }
+
+    if ( HeadersBase.IsEmpty() )
+    {
+        cbMessageBox( _("Didn't found any #include directive."), _("Error"), wxOK | wxICON_ERROR, this );
+        return;
+    }
+
+    // Getting array of all known libraries
+    ResultArray AllArray;
+    for ( int i=0; i<rtCount; i++ )
+        m_KnownLibs[i].GetAllResults(AllArray);
+    wxArrayString NewLibs;
+
+    // Sorting and removing duplicates and processing results
+    HeadersBase.Sort();
+    wxString Previous;
+    for ( size_t i=0; i<HeadersBase.Count(); i++ )
+    {
+        if ( Previous != HeadersBase[i] )
+        {
+            Previous = HeadersBase[i];
+            DetectNewLibs( Previous, AllArray, NewLibs );
+        }
+    }
+
+    // Filtering detected results
+    wxArrayString NewLibsFiltered;
+    NewLibs.Sort();
+    Previous.Clear();
+    for ( size_t i=0; i<NewLibs.Count(); i++ )
+    {
+        if ( Previous != NewLibs[i] )
+        {
+            Previous = NewLibs[i];
+            if ( m_ConfCopy.m_GlobalUsedLibs.Index(Previous) == wxNOT_FOUND )
+                NewLibsFiltered.Add( Previous );
+        }
+    }
+
+    if ( NewLibsFiltered.IsEmpty() )
+    {
+        cbMessageBox(
+            _("Didn't found any missing library for your project.\n"
+              "\n"
+              "This may mean that you project is fully configured\n"
+              "or that missing libraries are not yet recognized\n"
+              "or fully supported in lib_finder plugin"),
+            _("No libraries found"),
+            wxOK | wxICON_ASTERISK,
+            this );
+        return;
+    }
+
+    wxArrayInt Choices;
+#if wxCHECK_VERSION(2, 9, 0)
+    wxGetSelectedChoices(
+#else
+    wxGetMultipleChoices(
+#endif
+        Choices,
+        _("Select libraries to include in your project"),
+        _("Adding new libraries"),
+        NewLibsFiltered,
+        this);
+
+    if ( Choices.IsEmpty() )
+        return;
+
+    for ( size_t i=0; i<Choices.Count(); i++ )
+    {
+        wxString Library = NewLibsFiltered[ Choices[i] ];
+        m_ConfCopy.m_GlobalUsedLibs.Add(Library);
+        m_UsedLibraries->Append(GetUserListName(Library),new ListItemData(Library));
+    }
+
+    // Make sure that after the scan, used won't be able to manually
+    // add currently selected "known" library (through '<' button)
+    // which has just been added automatically
+    wxTreeEvent ev;
+    Onm_KnownLibrariesTreeSelectionChanged(ev);
+}
+
+void ProjectConfigurationPanel::DetectNewLibs( const wxString& IncludeName, ResultArray& known, wxArrayString& LibsList )
+{
+    wxString FixedInclude = IncludeName;
+    FixedInclude.MakeLower();
+    FixedInclude.Replace(_T("\\"),_T("/"),true);
+    for ( size_t i=0; i<known.Count(); i++ )
+    {
+        for ( size_t j=0; j<known[i]->Headers.Count(); j++ )
+        {
+            if ( FixedInclude.Matches( known[i]->Headers[j].Lower() ) )
+            {
+                LibsList.Add( known[i]->ShortCode );
+                break;
+            }
+        }
+    }
+}
