@@ -7,14 +7,14 @@
     #pragma hdrstop
 #endif
 
-//(*Headers(regex_dialog)
+#include <set>
+
+//(*Headers(RegExDlg)
 #include <wx/checkbox.h>
-#include <wx/choice.h>
-#include <wx/dialog.h>
-#include <wx/html/htmlwin.h>
-#include <wx/sizer.h>
-#include <wx/stattext.h>
+#include "scrollingdialog.h"
 #include <wx/textctrl.h>
+#include <wx/choice.h>
+#include <wx/html/htmlwin.h>
 //*)
 
 #include <wx/html/htmlwin.h>
@@ -26,25 +26,28 @@
   #include <wx/regex.h>
 #endif
 
-class RegExDlg: public wxDialog
+class RegExDlg: public wxScrollingDialog
 {
 	public:
 
 		RegExDlg(wxWindow* parent,wxWindowID id = -1);
 		virtual ~RegExDlg();
 
-		//(*Identifiers(regex_dialog)
+		//(*Identifiers(RegExDlg)
 		//*)
 
 		void EndModal(int retCode);
 
+		static void ReleaseAll();
+
 	protected:
 
-		//(*Handlers(regex_dialog)
+		//(*Handlers(RegExDlg)
 		void RunBenchmark(wxCommandEvent& event);
 		void OnInit(wxInitDialogEvent& event);
 		void OnRegExItemActivated(wxListEvent& event);
         void OnUpdateUI(wxUpdateUIEvent& event);
+		void OnClose(wxCloseEvent& event);
 		//*)
 
 	private:
@@ -53,18 +56,21 @@ class RegExDlg: public wxDialog
         wxArrayString GetBuiltinMatches(const wxString& text);
         wxArrayString GetPregMatches(const wxString& text);
 
-        //(*Declarations(regex_dialog)
-        wxTextCtrl* m_regex;
-        wxTextCtrl* m_quoted;
-        wxChoice* m_library;
+        //(*Declarations(RegExDlg)
         wxCheckBox* m_nocase;
-        wxCheckBox* m_newlines;
-        wxTextCtrl* m_text;
         wxHtmlWindow* m_output;
+        wxTextCtrl* m_text;
+        wxTextCtrl* m_quoted;
+        wxTextCtrl* m_regex;
+        wxCheckBox* m_newlines;
+        wxChoice* m_library;
         //*)
 
         wxRegEx m_wxre;
 
+        typedef std::set<RegExDlg*> VisibleDialogs;
+        static VisibleDialogs m_visible_dialogs;
+
 		DECLARE_EVENT_TABLE()
 };
 
