@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsmith.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxsmith.cpp $
+* $Revision: 9190 $
+* $Id: wxsmith.cpp 9190 2013-07-08 23:06:07Z fuscated $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxsmith.cpp $
 */
 
 #include "wxsmith.h"
@@ -28,12 +28,15 @@
 #include "wxsresourcefactory.h"
 #include "properties/wxsproperties.h"
 
-#include <wx/wxFlatNotebook/wxFlatNotebook.h>
+#include <prep.h>
+#include <cbauibook.h>
 #include <projectloader_hooks.h>
-#include "manager.h"
-#include "configmanager.h"
+#include <manager.h>
+#include <configmanager.h>
 #include <projectmanager.h>
 #include <logmanager.h>
+#include <sqplus.h>
+#include <sc_base_types.h>
 
 namespace
 {
@@ -42,12 +45,11 @@ namespace
     const int ViewWxSmithResourceId = wxNewId();
     const int ViewWxSmithPropertyId = wxNewId();
 
-
     /* XPM */
     static const char * Events_xpm[] = {
     "16 16 2 1",
-    " 	c None",
-    ".	c #000000",
+    "     c None",
+    ".    c #000000",
     "                ",
     "    ..    ..    ",
     "   .        .   ",
@@ -70,7 +72,6 @@ namespace
     const int placementTwoPanes = 2;
 
     inline int GetBrowserPlacements() { return Manager::Get()->GetConfigManager(_T("wxsmith"))->ReadInt(_T("/browserplacements"),0); }
-
 }
 
 wxSmith* wxSmith::m_Singleton = 0;
@@ -79,11 +80,11 @@ BEGIN_EVENT_TABLE(wxSmith, cbPlugin)
     EVT_UPDATE_UI(ViewWxSmithId,wxSmith::OnUpdateUI)
     EVT_UPDATE_UI(ViewWxSmithResourceId,wxSmith::OnUpdateUI)
     EVT_UPDATE_UI(ViewWxSmithPropertyId,wxSmith::OnUpdateUI)
-	EVT_MENU(ConfigureId,wxSmith::OnConfigure)
-	EVT_MENU(ViewWxSmithId,wxSmith::OnViewBrowsers)
-	EVT_MENU(ViewWxSmithResourceId,wxSmith::OnViewResourceBrowser)
-	EVT_MENU(ViewWxSmithPropertyId,wxSmith::OnViewPropertyBrowser)
-	EVT_MENU(-1,wxSmith::OnMenu)
+    EVT_MENU(ConfigureId,wxSmith::OnConfigure)
+    EVT_MENU(ViewWxSmithId,wxSmith::OnViewBrowsers)
+    EVT_MENU(ViewWxSmithResourceId,wxSmith::OnViewResourceBrowser)
+    EVT_MENU(ViewWxSmithPropertyId,wxSmith::OnViewPropertyBrowser)
+    EVT_MENU(-1,wxSmith::OnMenu)
 END_EVENT_TABLE()
 
 wxSmith::wxSmith()
@@ -112,10 +113,13 @@ void wxSmith::OnAttach()
 
     wxsResourceFactory::OnAttachAll();
 
-	// register event sink
+    // register event sink
     Manager::Get()->RegisterEventSink(cbEVT_PROJECT_OPEN, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectOpened));
-	Manager::Get()->RegisterEventSink(cbEVT_PROJECT_CLOSE, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectClose));
-	Manager::Get()->RegisterEventSink(cbEVT_PROJECT_RENAMED, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectRenamed));
+    Manager::Get()->RegisterEventSink(cbEVT_PROJECT_CLOSE, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectClose));
+    Manager::Get()->RegisterEventSink(cbEVT_PROJECT_RENAMED, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectRenamed));
+
+    // register scripting stuff
+    RegisterScripting();
 }
 
 void wxSmith::BuildBrowserParents()
@@ -171,7 +175,7 @@ void wxSmith::BuildBrowserParents()
 
         default:
         {
-            wxFlatNotebook* Notebook = Manager::Get()->GetProjectManager()->GetNotebook();
+            cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetUI().GetNotebook();
             wxASSERT(Notebook!=0);
 
             // Creating main splitting object
@@ -199,7 +203,7 @@ void wxSmith::BuildBrowsers()
 
     // Adding properties / events browser
     Sizer = new wxGridSizer(1);
-    wxsPropertyGridManager* PGManager = new wxsPropertyGridManager(m_PropertyBrowserParent,-1,wxDefaultPosition,wxDefaultSize,wxPG_TOOLBAR|wxTAB_TRAVERSAL);
+    wxsPropertyGridManager* PGManager = new wxsPropertyGridManager(m_PropertyBrowserParent,-1,wxDefaultPosition,wxDefaultSize,wxPG_TOOLBAR|wxTAB_TRAVERSAL|wxPG_SPLITTER_AUTO_CENTER);
     PGManager->AddPage(_("Properties"));
     PGManager->AddPage(_("Events"),wxBitmap(Events_xpm));
     PGManager->SelectPage(0);
@@ -207,8 +211,10 @@ void wxSmith::BuildBrowsers()
     m_PropertyBrowserParent->SetSizer(Sizer);
 }
 
-void wxSmith::OnRelease(bool appShutDown)
+void wxSmith::OnRelease(cb_unused bool appShutDown)
 {
+    UnregisterScripting();
+
     ProjectLoaderHooks::UnregisterHook(m_HookId,true);
     for ( ProjectMapI i = m_ProjectMap.begin(); i!=m_ProjectMap.end(); ++i )
     {
@@ -232,7 +238,7 @@ void wxSmith::OnRelease(bool appShutDown)
 
 cbConfigurationPanel* wxSmith::GetConfigurationPanel(wxWindow* parent)
 {
-	return new wxsSettings(parent);
+    return new wxsSettings(parent);
 }
 
 cbConfigurationPanel* wxSmith::GetProjectConfigurationPanel(wxWindow* parent, cbProject* project)
@@ -244,26 +250,26 @@ cbConfigurationPanel* wxSmith::GetProjectConfigurationPanel(wxWindow* parent, cb
 
 void wxSmith::BuildMenu(wxMenuBar* menuBar)
 {
-    // Genearating separate wxSmith menu entry
-	wxMenu* SmithMenu = new wxMenu;
+    // Generating separate wxSmith menu entry
+    wxMenu* SmithMenu = new wxMenu;
 
-	wxsResourceFactory::BuildSmithMenu(SmithMenu);
+    wxsResourceFactory::BuildSmithMenu(SmithMenu);
 
-	SmithMenu->AppendSeparator();
-	SmithMenu->Append(ConfigureId,_("&Configure wxSmith for current project"));
+    SmithMenu->AppendSeparator();
+    SmithMenu->Append(ConfigureId,_("&Configure wxSmith for current project"));
 
-	int ToolsPos = menuBar->FindMenu(_("&Tools"));
-	if  ( ToolsPos == wxNOT_FOUND )
-	{
+    int ToolsPos = menuBar->FindMenu(_("&Tools"));
+    if  ( ToolsPos == wxNOT_FOUND )
+    {
         menuBar->Append(SmithMenu,_("&wxSmith"));
-	}
-	else
-	{
+    }
+    else
+    {
         menuBar->Insert(ToolsPos,SmithMenu,_("&wxSmith"));
-	}
+    }
 
-	// Generate entries in "view" menu
-    int idx = menuBar->FindMenu(_("View"));
+    // Generate entries in "view" menu
+    int idx = menuBar->FindMenu(_("&View"));
     if (idx != wxNOT_FOUND)
     {
         wxMenu* view = menuBar->GetMenu(idx);
@@ -283,6 +289,9 @@ void wxSmith::BuildMenu(wxMenuBar* menuBar)
                         view->InsertCheckItem(i,ViewWxSmithResourceId, _("wxSmith resource browser"), _("Toggle displaying the wxSmith resource browser"));
                         view->InsertCheckItem(i,ViewWxSmithPropertyId, _("wxSmith property browser"), _("Toggle displaying the wxSmith property browser"));
                         break;
+
+                    default:
+                        break;
                 }
                 return;
             }
@@ -299,18 +308,21 @@ void wxSmith::BuildMenu(wxMenuBar* menuBar)
                 view->AppendCheckItem(ViewWxSmithResourceId, _("wxSmith resource browser"), _("Toggle displaying the wxSmith resource browser"));
                 view->AppendCheckItem(ViewWxSmithPropertyId, _("wxSmith property browser"), _("Toggle displaying the wxSmith property browser"));
                 break;
+
+            default:
+                break;
         }
         return;
     }
 }
 
-void wxSmith::BuildModuleMenu(const ModuleType type, wxMenu* menu, const FileTreeData* data)
+void wxSmith::BuildModuleMenu(cb_unused const ModuleType type, cb_unused wxMenu* menu, const FileTreeData* /*data*/)
 {
 }
 
-bool wxSmith::BuildToolBar(wxToolBar* toolBar)
+bool wxSmith::BuildToolBar(cb_unused wxToolBar* toolBar)
 {
-	return false;
+    return false;
 }
 
 void wxSmith::OnProjectHook(cbProject* project,TiXmlElement* elem,bool loading)
@@ -322,33 +334,33 @@ void wxSmith::OnProjectHook(cbProject* project,TiXmlElement* elem,bool loading)
 
 void wxSmith::OnProjectOpened(CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
     wxsProject* wxsProj = GetSmithProject(Proj);
     wxsProj->UpdateName();
     Proj->SetModified(wxsProj->GetWasModifiedDuringLoad());
+    event.Skip();
 }
 
 void wxSmith::OnProjectClose(CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
     ProjectMapI i = m_ProjectMap.find(Proj);
     if ( i == m_ProjectMap.end() ) return;
     delete i->second;
     m_ProjectMap.erase(i);
+    event.Skip();
 }
 
-void wxSmith::OnProjectRenamed(CodeBlocksEvent& event)
+void wxSmith::OnProjectRenamed(cb_unused CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
     ProjectMapI i = m_ProjectMap.find(Proj);
     if ( i == m_ProjectMap.end() ) return;
     i->second->UpdateName();
+    event.Skip();
 }
 
-void wxSmith::OnConfigure(wxCommandEvent& event)
+void wxSmith::OnConfigure(cb_unused wxCommandEvent& event)
 {
     cbProject* Proj = Manager::Get()->GetProjectManager()->GetActiveProject();
     if ( Proj )
@@ -384,14 +396,14 @@ void wxSmith::OnViewPropertyBrowser(wxCommandEvent& event)
     Manager::Get()->ProcessEvent(evt);
 }
 
-void wxSmith::OnViewResourceBrowser(wxCommandEvent& event)
+void wxSmith::OnViewResourceBrowser(cb_unused wxCommandEvent& event)
 {
     CodeBlocksDockEvent evt(event.IsChecked() ? cbEVT_SHOW_DOCK_WINDOW : cbEVT_HIDE_DOCK_WINDOW);
     evt.pWindow = m_ResourceBrowserParent;
     Manager::Get()->ProcessEvent(evt);
 }
 
-void wxSmith::OnUpdateUI(wxUpdateUIEvent& event)
+void wxSmith::OnUpdateUI(cb_unused wxUpdateUIEvent& event)
 {
     wxMenuBar* Bar = Manager::Get()->GetAppFrame()->GetMenuBar();
 
@@ -419,10 +431,44 @@ wxsProject* wxSmith::GetSmithProject(cbProject* Proj)
 
 void wxSmith::ShowResourcesTab()
 {
-    wxFlatNotebook* Notebook = Manager::Get()->GetProjectManager()->GetNotebook();
+    cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetUI().GetNotebook();
     Notebook->SetSelection( Notebook->GetPageIndex(m_Splitter) );
 }
 
+void wxSmith::RegisterScripting()
+{
+    Manager::Get()->GetScriptingManager();
+    if ( SquirrelVM::GetVMPtr() )
+    {
+        SqPlus::RegisterGlobal( &wxSmith::RecoverWxsFile, "WxsRecoverWxsFile" );
+    }
+}
+
+void wxSmith::UnregisterScripting()
+{
+    Manager::Get()->GetScriptingManager();
+    HSQUIRRELVM v = SquirrelVM::GetVMPtr();
+    if ( v )
+    {
+        sq_pushroottable(v);
+        sq_pushstring(v,"WxsRecoverWxsFile",-1);
+        sq_deleteslot(v,-2,false);
+        sq_poptop(v);
+    }
+}
+
+bool wxSmith::RecoverWxsFile( const wxString& WxsResourceSettings )
+{
+    wxSmith* This = wxSmith::Get();
+    if ( !This ) return false;
+    if ( !ProjectManager::Get()->GetActiveProject() ) return false;
+
+    wxsProject* project = This->GetSmithProject( ProjectManager::Get()->GetActiveProject() );
+    if ( !project ) return false;
+
+    return project->RecoverWxsFile( WxsResourceSettings );
+}
+
 // TODO: Move to resources\wxwidgets
 /*
 
@@ -430,7 +476,7 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 {
     if ( !CheckIntegration() ) return;
 
-	wxString FileName = ::wxFileSelector(
+    wxString FileName = ::wxFileSelector(
         _("Select XRC file"),
         _T(""),
         _T(""),
@@ -446,7 +492,7 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     TiXmlElement* Resource;
     if ( !Doc.LoadFile() || !(Resource = Doc.FirstChildElement("resource")) )
     {
-    	wxMessageBox(_("Couldn't load XRC file."));
+        wxMessageBox(_("Couldn't load XRC file."));
         return;
     }
 
@@ -455,15 +501,15 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     TiXmlElement* Element = Resource->FirstChildElement("object");
     while ( Element )
     {
-    	const char* Class = Element->Attribute("class");
-    	const char* Name = Element->Attribute("name");
-    	if ( !Class || !Name ) continue;
+        const char* Class = Element->Attribute("class");
+        const char* Name = Element->Attribute("name");
+        if ( !Class || !Name ) continue;
 
-    	if ( !strcmp(Class,"wxDialog") ||
-    	     !strcmp(Class,"wxPanel") ||
-    	     !strcmp(Class,"wxFrame") )
+        if ( !strcmp(Class,"wxDialog") ||
+             !strcmp(Class,"wxPanel") ||
+             !strcmp(Class,"wxFrame") )
         {
-        	Resources.Add(cbC2U(Name));
+            Resources.Add(cbC2U(Name));
         }
 
         Element = Element->NextSiblingElement("object");
@@ -471,8 +517,8 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 
     if ( Resources.Count() == 0 )
     {
-    	wxMessageBox(_("Didn't find any editable resources"));
-    	return;
+        wxMessageBox(_("Didn't find any editable resources"));
+        return;
     }
 
     // Selecting resource to edit
@@ -480,7 +526,7 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 
     if ( Resources.Count() == 1 )
     {
-    	Name = Resources[0];
+        Name = Resources[0];
     }
     else
     {
@@ -507,20 +553,20 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     wxsItem* Test = wxsGEN(cbC2U(Element->Attribute("class")),0);
     if ( !Test )
     {
-    	// Something went wrong - default factory is not working ?
-    	Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Internal error - did not found one of base items when importing XRC")));
-    	return;
+        // Something went wrong - default factory is not working ?
+        Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Internal error - did not found one of base items when importing XRC")));
+        return;
     }
 
     if ( !Test->XmlRead(Element,true,false) )
     {
-		if ( wxMessageBox(_("Resource was not loaded properly. Some widgets may be\n"
+        if ( wxMessageBox(_("Resource was not loaded properly. Some widgets may be\n"
                             "damaged or will be removed. Continue ?"),
                           _("XRC Load error"),
                           wxYES_NO|wxICON_QUESTION) == wxNO )
         {
-        	delete Test;
-        	return;
+            delete Test;
+            return;
         }
     }
     delete Test;
