@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxschoice.h 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxschoice.h $
+* $Revision: 7109 $
+* $Id: wxschoice.h 7109 2011-04-15 11:53:16Z mortenmacfly $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxschoice.h $
 */
 
 #ifndef WXSCHOICE_H
@@ -39,7 +39,7 @@ class wxsChoice: public wxsWidget
         virtual void OnEnumWidgetProperties(long Flags);
 
         wxArrayString ArrayChoices;
-        int DefaultSelection;
+        long DefaultSelection;
 };
 
 #endif
