@@ -1,4 +1,5 @@
-/*
+/** \file wxstreectrl.h
+*
 * This file is part of wxSmith plugin for Code::Blocks Studio
 * Copyright (C) 2006-2007  Bartlomiej Swiecki
 *
@@ -15,9 +16,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxstreectrl.h 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxstreectrl.h $
+* $Revision: 8148 $
+* $Id: wxstreectrl.h 8148 2012-07-19 19:50:28Z mortenmacfly $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/defitems/wxstreectrl.h $
 */
 
 #ifndef WXSTREECTRL_H
@@ -37,6 +38,14 @@ class wxsTreeCtrl: public wxsWidget
         virtual void OnBuildCreatingCode();
         virtual wxObject* OnBuildPreview(wxWindow* Parent,long Flags);
         virtual void OnEnumWidgetProperties(long Flags);
+        void FindAllImageLists(wxArrayString &aNames);
+        void UpdateTreeItemList(void);
+
+        wxArrayString    m_arrItems;            //!< Individual items for the tree control.
+        wxString            m_sImageList;    //!< The name of the image list to use for images.
+        wxImageList        m_imageList;        //!< The image list.
+        bool                    m_bExpand;            //!< Start with everything expanded?
+
 };
 
 #endif
