@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsfontproperty.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsfontproperty.cpp $
+* $Revision: 8338 $
+* $Id: wxsfontproperty.cpp 8338 2012-09-03 11:03:28Z jenslody $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsfontproperty.cpp $
 */
 
 #include "wxsfontproperty.h"
@@ -32,6 +32,22 @@
 
 using namespace wxsFlags;
 
+namespace
+{
+    wxString wxsDoubleToString( double value )
+    {
+        // Because GCC uses locale settings to determine
+        // whether to use dot or comma as floating point separator
+        // we can not use standard printf-like methods because
+        // the code becomes non cross-platform
+
+        wxString res;
+        res.Printf( _T("%f"), value );
+        res.Replace( _T(","), _T(".") );
+        return res;
+    }
+}
+
 wxFont wxsFontData::BuildFont()
 {
     if ( IsDefault )
@@ -64,13 +80,14 @@ wxFont wxsFontData::BuildFont()
     if ( !SysFont.empty() && HasSysFont )
     {
         wxFont Base;
-        if ( SysFont == _T("wxSYS_OEM_FIXED_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_OEM_FIXED_FONT);
-        if ( SysFont == _T("wxSYS_ANSI_FIXED_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_ANSI_FIXED_FONT);
-        if ( SysFont == _T("wxSYS_ANSI_VAR_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_ANSI_VAR_FONT);
-        if ( SysFont == _T("wxSYS_SYSTEM_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_SYSTEM_FONT);
-        if ( SysFont == _T("wxSYS_DEVICE_DEFAULT_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_DEVICE_DEFAULT_FONT);
-        if ( SysFont == _T("wxSYS_DEFAULT_GUI_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-        if ( !Base.Ok() ) Base = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
+        if      ( SysFont == _T("wxSYS_OEM_FIXED_FONT") )      Base = wxSystemSettings::GetFont(wxSYS_OEM_FIXED_FONT);
+        else if ( SysFont == _T("wxSYS_ANSI_FIXED_FONT") )     Base = wxSystemSettings::GetFont(wxSYS_ANSI_FIXED_FONT);
+        else if ( SysFont == _T("wxSYS_ANSI_VAR_FONT") )       Base = wxSystemSettings::GetFont(wxSYS_ANSI_VAR_FONT);
+        else if ( SysFont == _T("wxSYS_SYSTEM_FONT") )         Base = wxSystemSettings::GetFont(wxSYS_SYSTEM_FONT);
+        else if ( SysFont == _T("wxSYS_DEVICE_DEFAULT_FONT") ) Base = wxSystemSettings::GetFont(wxSYS_DEVICE_DEFAULT_FONT);
+        else if ( SysFont == _T("wxSYS_DEFAULT_GUI_FONT") )    Base = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
+
+        if ( !Base.Ok() )                                      Base = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
 
         if ( HasSize ) Base.SetPointSize(Size);
         else if ( HasRelativeSize ) Base.SetPointSize((int)(Base.GetPointSize() * RelativeSize));
@@ -207,7 +224,7 @@ wxString wxsFontData::BuildFontCode(const wxString& FontName,wxsCoderContext* Co
                 {
                     Code << FontName
                          << _T(".SetPointSize(")
-                         << wxString::Format(_T("%d"),Size)
+                         << wxString::Format(_T("%ld"),Size)
                          << _T(");\n");
                 }
                 else if ( HasRelativeSize )
@@ -216,7 +233,7 @@ wxString wxsFontData::BuildFontCode(const wxString& FontName,wxsCoderContext* Co
                          << _T(".SetPointSize((int)(")
                          << FontName
                          << _T(".GetPointSize() * ")
-                         << wxString::Format(_T("%f"),RelativeSize)
+                         << wxsDoubleToString(RelativeSize)
                          << _T("));\n");
                 }
                 if ( HasStyle )
@@ -248,7 +265,7 @@ wxString wxsFontData::BuildFontCode(const wxString& FontName,wxsCoderContext* Co
             }
 
             Code << _T("wxFont ") << FontName << _T("(")
-                 << (HasSize ? wxString::Format(_T("%d,"),Size) : _T("wxDEFAULT,"))
+                 << (HasSize ? wxString::Format(_T("%ld,"),Size) : _T("wxDEFAULT,"))
                  << FamilyStr << _T(",")
                  << StyleStr << _T(",")
                  << WeightStr << _T(",")
@@ -281,6 +298,16 @@ bool wxsFontProperty::ShowEditor(wxsPropertyContainer* Object)
     return Dlg.ShowModal() == wxID_OK;
 }
 
+wxString wxsFontProperty::GetStr(wxsPropertyContainer* Object)
+{
+    wxFont fnt = VALUE.BuildFont();
+    wxString res = wxEmptyString;
+    if (fnt.IsOk())
+        res = fnt.GetNativeFontInfoUserDesc();
+    return res.IsEmpty()?wxsCustomEditorProperty::GetStr(Object):res;
+}
+
+
 bool wxsFontProperty::XmlRead(wxsPropertyContainer* Object,TiXmlElement* Element)
 {
     if ( !Element )
@@ -301,32 +328,32 @@ bool wxsFontProperty::XmlRead(wxsPropertyContainer* Object,TiXmlElement* Element
     wxString Val;
 
     // Fetching size
-    if ( VALUE.HasSize = XmlGetString(Element,Val,_T("size")) )
+    if ( (VALUE.HasSize = XmlGetString(Element,Val,_T("size")) ))
     {
         Val.ToLong(&VALUE.Size);
     }
 
-    if ( VALUE.HasStyle = XmlGetString(Element,Val,_T("style")) )
+    if ( (VALUE.HasStyle = XmlGetString(Element,Val,_T("style")) ))
     {
         if ( Val == _T("italic") ) VALUE.Style = wxFONTSTYLE_ITALIC; else
         if ( Val == _T("slant") )  VALUE.Style = wxFONTSTYLE_SLANT;  else
                                    VALUE.Style = wxFONTSTYLE_NORMAL;
     }
 
-    if ( VALUE.HasWeight = XmlGetString(Element,Val,_T("weight")) )
+    if ( (VALUE.HasWeight = XmlGetString(Element,Val,_T("weight")) ))
     {
         if ( Val == _T("bold") )  VALUE.Weight = wxBOLD;   else
         if ( Val == _T("light") ) VALUE.Weight = wxLIGHT;  else
                                   VALUE.Weight = wxNORMAL;
     }
 
-    if ( VALUE.HasUnderlined = XmlGetString(Element,Val,_T("underlined")) )
+    if ( (VALUE.HasUnderlined = XmlGetString(Element,Val,_T("underlined")) ))
     {
         if ( Val == _T("1" ) ) VALUE.Underlined = true;
         else                   VALUE.Underlined = false;
     }
 
-    if ( VALUE.HasFamily = XmlGetString(Element,Val,_T("family")) )
+    if ( (VALUE.HasFamily = XmlGetString(Element,Val,_T("family")) ))
     {
         if ( Val == _T("decorative") ) VALUE.Family = wxDECORATIVE; else
         if ( Val == _T("roman") )      VALUE.Family = wxROMAN;      else
@@ -351,7 +378,7 @@ bool wxsFontProperty::XmlRead(wxsPropertyContainer* Object,TiXmlElement* Element
     VALUE.HasEncoding = XmlGetString(Element,VALUE.Encoding,_T("encoding"));
     VALUE.HasSysFont = XmlGetString(Element,VALUE.SysFont,_T("sysfont"));
 
-    if ( VALUE.HasRelativeSize = XmlGetString(Element,Val,_T("relativesize")) )
+    if ( (VALUE.HasRelativeSize = XmlGetString(Element,Val,_T("relativesize")) ))
     {
         Val.ToDouble(&VALUE.RelativeSize);
     }
@@ -370,7 +397,7 @@ bool wxsFontProperty::XmlWrite(wxsPropertyContainer* Object,TiXmlElement* Elemen
 
     if ( VALUE.HasSize )
     {
-        XmlSetString(Element,wxString::Format(_T("%d"),VALUE.Size),_T("size"));
+        XmlSetString(Element,wxString::Format(_T("%ld"),VALUE.Size),_T("size"));
     }
 
     if ( VALUE.HasStyle )
@@ -431,7 +458,7 @@ bool wxsFontProperty::XmlWrite(wxsPropertyContainer* Object,TiXmlElement* Elemen
 
     if ( VALUE.HasRelativeSize )
     {
-        XmlSetString(Element,wxString::Format(_T("%f"),VALUE.RelativeSize),_T("relativesize"));
+        XmlSetString(Element, wxsDoubleToString(VALUE.RelativeSize), _T("relativesize"));
     }
 
     return true;
