@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsexproperties.h 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsexproperties.h $
+* $Revision: 7835 $
+* $Id: wxsexproperties.h 7835 2012-02-22 14:40:26Z mortenmacfly $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsexproperties.h $
 */
 
 #ifndef WXSEXPROPERTIES_H
@@ -31,5 +31,9 @@
 #include "properties/wxspositionsizeproperty.h"
 #include "properties/wxssizerflagsproperty.h"
 #include "properties/wxsstyleproperty.h"
+#include "properties/wxsimageproperty.h"
+#include "properties/wxsimagelistproperty.h"
+#include "properties/wxsimagecomboproperty.h"
+#include "properties/wxsimagetreeproperty.h"
 
 #endif
