@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsitem.h 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.h $
+* $Revision: 8704 $
+* $Id: wxsitem.h 8704 2012-12-23 20:32:03Z mortenmacfly $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.h $
 */
 
 #ifndef WXSITEM_H
@@ -36,6 +36,7 @@
 
 #include <stdarg.h>
 
+#include <prep.h>
 
 class wxsItemResData;
 class wxsParent;
@@ -49,7 +50,7 @@ class wxWindow;
  * \li \link wxsWidget Standard widgets which can not have child items \endlink
  * \li \link wxsContainer Widgets \ window which can have items inside \endlink
  * \li \link wxsSizer All sizers \endlink
- * \li \link wxsSpacer Spacer \endlink (although this is only one item, it must be threated especially)
+ * \li \link wxsSpacer Spacer \endlink (although this is only one item, it must be treated especially)
  * \li \link wxsTool Tools - items not visible like wxTimer \endlink
  *
  * Each item has two base properties - identifier and variable name. These properties
@@ -58,10 +59,10 @@ class wxWindow;
  * Due to some problems with calling virtual functions in constructor, Item
  * is initialized in two steps. First, constructor and than Create function are
  * called. Create is virtual so it could be overridden to use additional
- * setup, but it usually won't be necessarry. In default implementation, it
+ * setup, but it usually won't be necessary. In default implementation, it
  * initializes components which are using virtual functions of wxsItem class.
  *
- * Create Function is automatically called inside wxsWidgetFactory class
+ * Create function is automatically called inside wxsWidgetFactory class
  * (not wxsWidgetManager !!!), so there's no need to remember about calling that
  * manually.
  *
@@ -73,7 +74,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
     public:
 
         /** \brief Ctor
-         * \param Resource resource containingthis widget, must not be 0
+         * \param Resource resource containing this widget, must not be 0
          * \param Events array of events used by this object (may be 0 if item doesn't use events)
          */
         wxsItem(wxsItemResData* Data,const wxsItemInfo* Info,long PropertiesFlags,const wxsEventDesc* Events,const wxsStyleSet* StyleSet);
@@ -87,7 +88,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          */
         inline const wxsItemInfo& GetInfo() { return *m_Info; }
 
-        /** \brief Getting event managment object used by this item
+        /** \brief Getting event management object used by this item
          *  \note This function is wrapper to OnGetInfo() protected function
          */
         inline wxsEvents& GetEvents() { return m_Events; }
@@ -113,7 +114,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          */
         inline wxString GetVarName() { return IsRootItem() ? _T("this") : m_BaseProperties.m_VarName; }
 
-        /** \brief Setting variabne name */
+        /** \brief Setting variable name */
         void SetVarName(const wxString& NewName);
 
         /** \brief Getting create prefix for item
@@ -180,7 +181,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *
          * This function instead of EnumProperties must be declared in
          * items to provide set of it's properties. Content of this function
-         * should be exackly the same as content of
+         * should be exactly the same as content of
          * wxsPropertyContainer::EnumProperties function.
          *
          * \note This function registers properties of parent item and should
@@ -215,7 +216,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          */
         void BuildItemTree(wxsResourceTree* Tree,wxsResourceItemId Parent,int Position=-1);
 
-        /** \brief Function getting lastest tree item id generated in tree
+        /** \brief Function getting latest tree item id generated in tree
          *
          * \warning returned if may be outdated an may cause some seg faults
          *          when using it.
@@ -234,7 +235,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          */
         virtual wxsTool* ConvertToTool() { return 0; }
 
-        /** \brief Function returinng pointer to wxsBaseProperties class if item uses it. */
+        /** \brief Function returning pointer to wxsBaseProperties class if item uses it. */
         virtual wxsBaseProperties* GetBaseProps() { return &m_BaseProperties; }
 
         /** \brief Getting current preview object */
@@ -243,7 +244,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
         /** \brief Checking if item is selected inside editor */
         inline bool GetIsSelected() { return m_IsSelected; }
 
-        /** \brief Changking current selection state */
+        /** \brief Checking current selection state */
         inline void SetIsSelected(bool NewSelected) { m_IsSelected = NewSelected; }
 
         /** \brief Checking if node of this item in resource tree is expanded */
@@ -292,7 +293,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
         /** \brief Helpful printf-like function used when creating source code.
          *
          * This function works like simplified printf function producing string
-         * with few differences: most of %x formating sequences doesn't need
+         * with few differences: most of %x formatting sequences doesn't need
          * argument because default value is taken. Argument-requiring sequences
          * are: %V %t %n %s %b.
          *
@@ -307,13 +308,13 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *  - %V - Validator (currently wxDefaultValidator only)
          *  - %N - Name (usually last parameter in constructor)
          *  - %v - Variable (require argument: wxChar*)
-         *  - %t - wx-converted string with translation in _("...") form (reguire argument: wxChar*)
+         *  - %t - wx-converted string with translation in _("...") form (require argument: wxChar*)
          *  - %n - wx-converted string without translation in _T("...") form (require argument: wxChar*)
          *  - %s - string value (require argument: wxChar*)
          *  - %d - decimal value (require argument: integer)
          *  - %b - boolean value ("true"/"false") (require argument: bool)
          *  .
-         * More formating strings may be added through OnCodefExtension function
+         * More formatting strings may be added through OnCodefExtension function
          */
         wxString Codef(wxsCoderContext* Context,const wxChar* Fmt,...);
 
@@ -327,7 +328,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
         /** \brief Default procedure generating declarations code */
         virtual void OnBuildDeclarationsCode();
 
-        /** \brief Default procedure generating events connectiong code */
+        /** \brief Default procedure generating events connecting code */
         virtual void OnBuildEventsConnectingCode();
 
         /** \brief Default procedure generating identifiers code */
@@ -358,7 +359,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *
          * \param QPP wxsAdvQPP class, root Quick properties panel
          */
-        virtual void OnAddItemQPP(wxsAdvQPP* QPP) {}
+        virtual void OnAddItemQPP(cb_unused wxsAdvQPP* QPP) {}
 
         /** \brief Function building preview for this item
          *
@@ -368,12 +369,12 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *  \li Preview in editor
          *  \li Exact preview used after "Show preview" button is pressed.
          *
-         * In most cases both previews should be exackly the same, only in case
+         * In most cases both previews should be exactly the same, only in case
          * of sizers there are some additional borders around to visually show
          * placement of sizers.
          *
-         * Exact preview should look exackly like it will be shown in real
-         * application, and the code creating preview should be simillar to
+         * Exact preview should look exactly like it will be shown in real
+         * application, and the code creating preview should be similar to
          * code generated in BuildCreatingCode function.
          *
          * \param Parent wxWidgets object for this one
@@ -388,12 +389,12 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *
          * Default implementation loads base properties using
          * wxsPropertyContainer::XmlRead() function and loads extra data from
-         * node passed as argument using defautl scheme.
+         * node passed as argument using default scheme.
          *
          * \param Element element containing configuration for this item
          * \param IsXRC if true, this function should load XRC structure from
          *        this node and if it's parent, it should load all children.
-         * \param IsExtra if true, this function should load Extra informations
+         * \param IsExtra if true, this function should load Extra information
          *        not conforming to XRC standard from given Xml element.
 
          * \note This function will be called twice when loading resource which
@@ -408,10 +409,10 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          * \param Element here all item configuration should be stored
          * \param IsXRC if true, this function should write XRC structure to
          *        this node and if it's parent, it should write all children.
-         * \param IsExtra if true, this function should write Extra informations
+         * \param IsExtra if true, this function should write Extra information
          *        not conforming to XRC standard to given Xml element.
 
-         * \note This function will be called twice when saving Sresource which
+         * \note This function will be called twice when saving resource which
          *       uses additional XRC file because XRC structure data and extra
          *       data are in separate files.
          */
@@ -419,14 +420,14 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
 
         /** \brief Function for adding extra properties - used to add events,
          *
-         * This funcion may be overridden to add custom extra properties
+         * This function may be overridden to add custom extra properties
          * but wxsItem::OnAddExtraProperties should be called from it.
          */
         virtual void OnAddExtraProperties(wxsPropertyGridManager* Grid);
 
         /** \brief Reading content of extra properties
          *
-         * This functoin may be overridden to read custom extra properties.
+         * This function may be overridden to read custom extra properties.
          * Overridden function must call wxsItem::OnExtraPropertyChanged
          * if Id didn't match any of added properties.
          */
@@ -434,8 +435,8 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
 
         /** \brief Function processing mouse-click event
          *
-         * This funciton may be used by item to do some action when
-         * used clicks on preview. It may be usefull for containers
+         * This function may be used by item to do some action when
+         * used clicks on preview. It may be useful for containers
          * like notebook when only one child is visible to change
          * child shown in editor
          * \param Preview preview item
@@ -443,12 +444,12 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          * \param PosY Y position of mouse relative to item's position
          * \return false if nothing has changed, true if preview must be refreshed
          */
-        virtual bool OnMouseClick(wxWindow* Preview,int PosX,int PosY) { return false; }
+        virtual bool OnMouseClick(cb_unused wxWindow* Preview,cb_unused int PosX,cb_unused int PosY) { return false; }
 
         /** \brief Function processing double-click event
          *
-         * This funciton may be used by item to do some action when
-         * used clicks on preview. It may be usefull to do some special action
+         * This function may be used by item to do some action when
+         * used clicks on preview. It may be useful to do some special action
          * when item is double-clicked. By default it will try to find
          * or create event handler.
          *
@@ -461,7 +462,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
 
         /** \brief Function processing right-click event
          *
-         * This funciton may be used by item to do some action when
+         * This function may be used by item to do some action when
          * used right-clicks on preview. It may be used to show some
          * extra menu specific for given item only.
          *
@@ -472,7 +473,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          */
         virtual bool OnMouseRightClick(wxWindow* Preview,int PosX,int PosY);
 
-        /** \brief Function used to udpate content of popup menu
+        /** \brief Function used to update content of popup menu
          *
          * This function is called by default OnMouseRightClick implementation.
          * It's called just before showing popup menu so one can add it's own entries
@@ -493,16 +494,17 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *       in all default wxSmith classes even when not used)
          * \param Result result string, new data should be appended to it
          * \param FmtChar pointer to char right after %, function should shift this pointer
-         *        after all detected formating chars
+         *        after all detected formatting chars
          * \param ap pointer to arguments, get arguments through va_arg
          */
-        virtual bool OnCodefExtension(wxsCodingLang Language,wxString& Result,const wxChar* &FmtChar,va_list ap) { return false; }
+        virtual bool OnCodefExtension(cb_unused wxsCodingLang Language,cb_unused wxString& Result,
+                                      cb_unused const wxChar* &FmtChar,cb_unused va_list ap) { return false; }
 
         /** \brief Function checking if this item is represented as pointer */
         virtual bool OnIsPointer();
 
         /** \brief Checking if this item can be added to given parent */
-        virtual bool OnCanAddToParent(wxsParent* Parent,bool ShowMessage) { return true; }
+        virtual bool OnCanAddToParent(cb_unused wxsParent* Parent,cb_unused bool ShowMessage) { return true; }
 
         /** \brief Getting name of entry in resource browser
          *
@@ -514,7 +516,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
         inline wxPoint Pos(wxWindow* Parent) { return GetBaseProps()->m_Position.GetPosition(Parent); }
 
         /** \brief Easy access to size */
-        inline wxSize Size(wxWindow* Parent) { return GetBaseProps()->m_Size.GetSize(Parent); }
+        wxSize Size(wxWindow* Parent);
 
         /** \brief Easy access to style (can be used directly when generating preview) */
         inline long Style() { return m_BaseProperties.m_StyleSet ? m_BaseProperties.m_StyleSet->GetWxStyle(m_BaseProperties.m_StyleBits,false) : 0; }
@@ -534,13 +536,13 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
          *
          * \param Preview window for which properties must be applied
          * \param Flags Flags passed to OnBuildPreview
-         * \return window after settig up properties (value of Preview is returned)
+         * \return window after setting up properties (value of Preview is returned)
          */
         wxWindow* SetupWindow(wxWindow* Window,long Flags);
 
     private:
 
-        /** \brief Function enumerating proeprties
+        /** \brief Function enumerating properties
          *
          * This function changes a little bit the convention of creating
          * properties in wxsPropertyContainer. If item has parent, parent is
@@ -577,7 +579,7 @@ class wxsItem: public wxsPropertyContainer, public wxsCodeGenerator
         const wxsItemInfo* m_Info;              ///< \brief Pointer to item's info structure
         wxsEvents m_Events;                     ///< \brief Object managing events
         wxsParent* m_Parent;                    ///< \brief Parent class of this one
-        wxsItemResData* m_ResourceData;         ///< \brief Data managment object containing this item
+        wxsItemResData* m_ResourceData;         ///< \brief Data management object containing this item
         wxsBaseProperties m_BaseProperties;     ///< \brief Pointer to base properties if item uses it
         long m_PropertiesFlags;                 ///< \brief Properties flags
         wxObject* m_LastPreview;                ///< \brief Current preview object
