@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsitemeditor.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsitemeditor.cpp $
+* $Revision: 9305 $
+* $Id: wxsitemeditor.cpp 9305 2013-09-10 21:53:07Z jenslody $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsitemeditor.cpp $
 */
 
 #include <wx/dcmemory.h>
@@ -77,7 +77,7 @@ wxsItemEditor::wxsItemEditor(wxWindow* parent,wxsItemRes* Resource):
 wxsItemEditor::~wxsItemEditor()
 {
     delete m_Data;
-	m_AllEditors.erase(this);
+    m_AllEditors.erase(this);
 }
 
 void wxsItemEditor::InitializeResourceData()
@@ -120,7 +120,7 @@ void wxsItemEditor::InitializeVisualStuff()
     m_Content = new wxsItemEditorContent(this,m_Data,this);
     m_HorizSizer->Add(m_Content,1,wxEXPAND);
 
-    m_QPArea = new wxScrolledWindow(this,-1,wxDefaultPosition,wxDefaultSize,wxVSCROLL|wxSUNKEN_BORDER|wxALWAYS_SHOW_SB);
+    m_QPArea = new wxScrolledWindow(this,-1,wxDefaultPosition,wxDefaultSize,wxVSCROLL|wxHSCROLL|wxSUNKEN_BORDER/*|wxALWAYS_SHOW_SB*/);
     m_QPArea->SetScrollbars(0,5,0,0);
     m_HorizSizer->Add(m_QPArea,0,wxEXPAND);
     m_QPSizer = new wxBoxSizer(wxVERTICAL);
@@ -216,15 +216,18 @@ void wxsItemEditor::RebuildPreview()
         BackgroundSizer->Fit(m_PreviewBackground);
         wxSizer* NewSizer = new wxGridSizer(1);
         NewSizer->Add(m_PreviewBackground,0,wxALL,10);
+#if !wxCHECK_VERSION(2, 9, 0)
         m_Content->SetVirtualSizeHints(1,1);
+#endif
         m_Content->SetSizer(NewSizer);
-        NewSizer->SetVirtualSizeHints(m_Content);
+#if wxCHECK_VERSION(2, 9, 0)
         NewSizer->FitInside(m_Content);
+#else
+        NewSizer->SetVirtualSizeHints(m_Content);
+#endif
         m_PreviewBackground->Layout();
         m_Content->Layout();
         m_HorizSizer->Layout();
-        m_VertSizer->Layout();
-        Layout();
     }
 
     m_ToolSpace->AfterPreviewChanged();
@@ -238,8 +241,9 @@ void wxsItemEditor::RebuildPreview()
     }
     m_VertSizer->Layout();
 
+    Layout();
     Thaw();
-    Update();
+    Refresh();
 
     // Updating all informations in Content
     m_Content->AfterPreviewChanged();
@@ -293,12 +297,12 @@ bool wxsItemEditor::Save()
         // TODO: Some message here please
     }
     UpdateModified();
-	return true;
+    return true;
 }
 
 bool wxsItemEditor::GetModified() const
 {
-	return m_Data ? m_Data->GetModified() : false;
+    return m_Data ? m_Data->GetModified() : false;
 }
 
 void wxsItemEditor::UpdateModified()
@@ -315,12 +319,12 @@ void wxsItemEditor::UpdateModified()
 
 bool wxsItemEditor::CanUndo() const
 {
-	return m_Data ? m_Data->CanUndo() : false;
+    return m_Data ? m_Data->CanUndo() : false;
 }
 
 bool wxsItemEditor::CanRedo() const
 {
-	return m_Data ? m_Data->CanRedo() : false;
+    return m_Data ? m_Data->CanRedo() : false;
 }
 
 void wxsItemEditor::Undo()
@@ -641,7 +645,20 @@ namespace
     }
 
     WX_DEFINE_ARRAY(const wxsItemInfo*,ItemsT);
+
+    int CategorySort(ItemsT* it1, ItemsT* it2)
+    {
+        if (it1->Item(0)->Category.IsSameAs(_T("Standard")))
+            return -1;
+
+        if (it2->Item(0)->Category.IsSameAs(_T("Standard")))
+            return 1;
+
+        return wxStrcmp(it1->Item(0)->Category, it2->Item(0)->Category);
+    }
+
     WX_DECLARE_STRING_HASH_MAP(ItemsT,MapT);
+    WX_DEFINE_SORTED_ARRAY(ItemsT*,ArrayOfItemsT);
 }
 
 void wxsItemEditor::BuildPalette(wxNotebook* Palette)
@@ -653,6 +670,7 @@ void wxsItemEditor::BuildPalette(wxNotebook* Palette)
     // it will be done using multimap (map of arrays)
 
     MapT Map;
+    ArrayOfItemsT aoi(CategorySort);
 
     for ( const wxsItemInfo* Info = wxsItemFactory::GetFirstInfo(); Info; Info = wxsItemFactory::GetNextInfo() )
     {
@@ -664,17 +682,20 @@ void wxsItemEditor::BuildPalette(wxNotebook* Palette)
 
     for ( MapT::iterator i = Map.begin(); i!=Map.end(); ++i )
     {
+        aoi.Add(&(i->second));
+    }
+    for (size_t i = 0; i < aoi.Count(); ++i)
+    {
+        ItemsT* Items = aoi.Item(i);
+        Items->Sort(PrioritySort);
         wxScrolledWindow* CurrentPanel = new wxScrolledWindow(Palette,-1,wxDefaultPosition,wxDefaultSize,0/*wxALWAYS_SHOW_SB|wxHSCROLL*/);
         CurrentPanel->SetScrollRate(1,0);
-        Palette->AddPage(CurrentPanel,i->first);
+        Palette->AddPage(CurrentPanel,Items->Item(0)->Category);
         wxSizer* RowSizer = new wxBoxSizer(wxHORIZONTAL);
 
-        ItemsT& Items = i->second;
-        Items.Sort(PrioritySort);
-
-        for ( size_t j=Items.Count(); j-->0; )
+        for ( size_t j=Items->Count(); j-->0; )
         {
-            const wxsItemInfo* Info = Items[j];
+            const wxsItemInfo* Info = Items->Item(j);
             const wxBitmap& Icon = ( PalIconSize() == 16L ) ? Info->Icon16 : Info->Icon32;
 
             if ( AllowNonXRCItems || Info->AllowInXRC )
@@ -698,7 +719,11 @@ void wxsItemEditor::BuildPalette(wxNotebook* Palette)
             }
         }
         CurrentPanel->SetSizer(RowSizer);
+#if wxCHECK_VERSION(2, 9, 0)
+        RowSizer->FitInside(CurrentPanel);
+#else
         RowSizer->SetVirtualSizeHints(CurrentPanel);
+#endif
     }
 }
 
