@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsitemres.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsitemres.cpp $
+* $Revision: 9190 $
+* $Id: wxsitemres.cpp 9190 2013-07-08 23:06:07Z fuscated $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsitemres.cpp $
 */
 
 #include "wxsitemres.h"
@@ -39,10 +39,10 @@ namespace
         _T("#include \"$(Include)\"\n")
         _T("\n")
         _T("$(InternalHeadersPch)")
-        + wxsCodeMarks::Beg(wxsCPP,_T("InternalHeaders"),_T("$(ClassName)")) + _T("\n") +
+        + wxsCodeMarks::Beg(wxsCPP,_T("InternalHeaders"),_T("$(ClassName)")) + _T("\n")
         + wxsCodeMarks::End(wxsCPP) + _T("\n")
         _T("\n")
-        + wxsCodeMarks::Beg(wxsCPP,_T("IdInit"),_T("$(ClassName)")) + _T("\n") +
+        + wxsCodeMarks::Beg(wxsCPP,_T("IdInit"),_T("$(ClassName)")) + _T("\n")
         + wxsCodeMarks::End(wxsCPP) + _T("\n")
         _T("\n")
         _T("BEGIN_EVENT_TABLE($(ClassName),$(BaseClassName))\n")
@@ -120,6 +120,7 @@ wxsItemRes::wxsItemRes(wxsProject* Owner,const wxString& Type,bool CanBeMain):
     m_HdrFileName(wxEmptyString),
     m_XrcFileName(wxEmptyString),
     m_UseForwardDeclarations(false),
+    m_UseI18n(true),
     m_CanBeMain(CanBeMain)
 {
 }
@@ -131,7 +132,8 @@ wxsItemRes::wxsItemRes(const wxString& FileName,const TiXmlElement* XrcElem,cons
     m_SrcFileName(wxEmptyString),
     m_HdrFileName(wxEmptyString),
     m_XrcFileName(FileName),
-    m_UseForwardDeclarations(false)
+    m_UseForwardDeclarations(false),
+    m_UseI18n(true)
 {
     SetResourceName(cbC2U(XrcElem->Attribute("name")));
 }
@@ -151,7 +153,12 @@ bool wxsItemRes::OnReadConfig(const TiXmlElement* Node)
     m_SrcFileName = cbC2U(Node->Attribute("src"));
     m_HdrFileName = cbC2U(Node->Attribute("hdr"));
     m_XrcFileName = cbC2U(Node->Attribute("xrc"));
-    m_UseForwardDeclarations = (cbC2U(Node->Attribute("fwddecl")) == _T("1"));
+    const wxString fwddecl = cbC2U(Node->Attribute("fwddecl"));
+    if (!fwddecl.IsEmpty())
+        m_UseForwardDeclarations = (fwddecl == _T("1") || fwddecl == _T("true"));
+    const wxString i18n = cbC2U(Node->Attribute("i18n"));
+    if (!i18n.IsEmpty())
+        m_UseI18n = (i18n == _T("1") || i18n == _T("true"));
 
     // m_XrcFileName may be empty because it's not used when generating full source code
     return !m_WxsFileName.empty() &&
@@ -168,10 +175,10 @@ bool wxsItemRes::OnWriteConfig(TiXmlElement* Node)
     {
         Node->SetAttribute("xrc",cbU2C(m_XrcFileName));
     }
-    if ( m_UseForwardDeclarations )
-    {
-        Node->SetAttribute("fwddecl","1");
-    }
+
+    Node->SetAttribute("fwddecl", m_UseForwardDeclarations ? "1" : "0");
+    Node->SetAttribute("i18n", m_UseI18n ? "1" : "0");
+
     return true;
 }
 
@@ -450,7 +457,7 @@ bool wxsItemRes::CreateNewResource(NewResourceParams& Params)
                         break;
                     }
                     Cnt++;
-                    WxsName = wxString::Format(_T("%s%d.wxs"),WxsNameBase.c_str(),Cnt);
+                    WxsName = wxString::Format(_T("%s%d.wxs"),WxsNameBase.wx_str(),Cnt);
                 }
 
                 m_WxsFileName = WxsName;
@@ -472,6 +479,7 @@ bool wxsItemRes::CreateNewResource(NewResourceParams& Params)
                 m_WxsFileName = Params.Wxs;
             }
             m_UseForwardDeclarations = Params.UseFwdDecl;
+            m_UseI18n = Params.UseI18n;
             return true;
         }
 
@@ -509,6 +517,7 @@ wxsItemResData* wxsItemRes::BuildResData(wxsItemEditor* Editor)
         GetResourceType(),
         GetLanguage(),
         m_UseForwardDeclarations,
+        m_UseI18n,
         GetTreeItemId(),
         Editor,
         this);
@@ -516,9 +525,9 @@ wxsItemResData* wxsItemRes::BuildResData(wxsItemEditor* Editor)
 
 bool wxsItemRes::OnDeleteCleanup(bool ShowDialog)
 {
-    bool PhisDeleteWXS = true;
+    bool PhysDeleteWXS = true;
     bool DeleteSources = false;
-    bool PhisDeleteSources = false;
+    bool PhysDeleteSources = false;
 
     if ( ShowDialog )
     {
@@ -527,9 +536,9 @@ bool wxsItemRes::OnDeleteCleanup(bool ShowDialog)
         {
             return false;
         }
-        PhisDeleteWXS = Dlg.m_PhisDeleteWXS->GetValue();
+        PhysDeleteWXS = Dlg.m_PhysDeleteWXS->GetValue();
         DeleteSources = Dlg.m_DeleteSources->GetValue();
-        PhisDeleteSources = Dlg.m_PhisDeleteSources->GetValue();
+        PhysDeleteSources = Dlg.m_PhysDeleteSources->GetValue();
     }
 
     ProjectFile* Wxs = GetProject()->GetCBProject()->GetFileByFilename(m_WxsFileName,true);
@@ -538,7 +547,7 @@ bool wxsItemRes::OnDeleteCleanup(bool ShowDialog)
         GetProject()->GetCBProject()->RemoveFile(Wxs);
     }
 
-    if ( PhisDeleteWXS )
+    if ( PhysDeleteWXS )
     {
         wxRemoveFile(GetProjectPath() + m_WxsFileName);
     }
@@ -556,14 +565,14 @@ bool wxsItemRes::OnDeleteCleanup(bool ShowDialog)
             GetProject()->GetCBProject()->RemoveFile(Pf);
         }
 
-        if ( PhisDeleteSources )
+        if ( PhysDeleteSources )
         {
             wxRemoveFile(GetProjectPath() + m_SrcFileName);
             wxRemoveFile(GetProjectPath() + m_HdrFileName);
         }
     }
 
-    Manager::Get()->GetProjectManager()->RebuildTree();
+    Manager::Get()->GetProjectManager()->GetUI().RebuildTree();
 
     // TODO: Check if we've deleted main resource of this app
 
