@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsitemresdata.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsitemresdata.cpp $
+* $Revision: 7109 $
+* $Id: wxsitemresdata.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsitemresdata.cpp $
 */
 
 #include "wxsitemresdata.h"
@@ -33,6 +33,12 @@
 #include <wx/clipbrd.h>
 #include <tinyxml/tinywxuni.h>
 
+#if defined(__WXMSW__) && defined(LoadImage)
+    // Fix Windows winuser.h Header define of LoadImage.
+    #undef LoadImage
+#endif
+
+
 using namespace wxsFlags;
 
 namespace
@@ -49,6 +55,7 @@ wxsItemResData::wxsItemResData(
     const wxString& ClassType,
     wxsCodingLang Language,
     bool UseForwardDeclarations,
+    bool WithTranslation,
     wxsResourceItemId TreeId,
     wxsItemEditor* Editor,
     wxsItemResFunctions* Functions):
@@ -56,6 +63,7 @@ wxsItemResData::wxsItemResData(
         m_SrcFileName(SrcFileName),
         m_HdrFileName(HdrFileName),
         m_XrcFileName(XrcFileName),
+        m_Translation(WithTranslation),
         m_ClassName(ClassName),
         m_ClassType(ClassType),
         m_Language(Language),
@@ -585,7 +593,8 @@ void wxsItemResData::RebuildSourceCode()
             }
 
             // Add some initial headers
-            Context.AddHeader(_T("<wx/intl.h>"),_T(""),hfLocal|hfInPCH);
+            if (m_Translation)
+                Context.AddHeader(_T("<wx/intl.h>"),_T(""),hfLocal|hfInPCH);
             Context.AddHeader(_T("<wx/string.h>"),_T(""),hfLocal|hfInPCH);
             if ( m_PropertiesFilter & flMixed )
             {
