@@ -15,14 +15,15 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxsnewwindowdlg.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/contrib/wxSmith/wxwidgets/wxsnewwindowdlg.cpp $
+* $Revision: 9190 $
+* $Id: wxsnewwindowdlg.cpp 9190 2013-07-08 23:06:07Z fuscated $
+* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsnewwindowdlg.cpp $
 */
 
 #include "wxsnewwindowdlg.h"
 #include "wxwidgetsres.h"
 #include "wxsdialogres.h"
+#include "wxsscrollingdialogres.h"
 #include "wxsframeres.h"
 #include "wxspanelres.h"
 #include "wxwidgetsgui.h"
@@ -48,12 +49,8 @@ namespace
     {
         for ( size_t i=FileName.Length(); i-->0; )
         {
-            switch ( FileName[i] )
-            {
-                case _T('/'):
-                case _T('\\'):
-                    return FileName.Mid(0,i+1);
-            }
+            if ( FileName[i] == _T('/') || FileName[i] == _T('\\') )
+                return FileName.Mid(0,i+1);
         }
 
         return wxEmptyString;
@@ -63,26 +60,19 @@ namespace
     {
         for ( size_t i=FileName.Length(); i-->0; )
         {
-            switch ( FileName[i] )
-            {
-                case _T('/'):
-                case _T('\\'):
-                    return FileName;
+            if ( FileName[i] == _T('/') || FileName[i] == _T('\\') )
+                return FileName;
 
-                case _T('.'):
-                    return FileName.Mid(0,i);
-            }
+            if ( FileName[i] == _T('.') )
+                return FileName.Mid(0,i);
         }
         return FileName;
     }
 }
 
 //(*IdInit(wxsNewWindowDlg)
-const long wxsNewWindowDlg::ID_STATICTEXT1 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL1 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT2 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL2 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT3 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL3 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX1 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL4 = wxNewId();
@@ -90,20 +80,13 @@ const long wxsNewWindowDlg::ID_CHECKBOX3 = wxNewId();
 const long wxsNewWindowDlg::ID_BUTTON1 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX2 = wxNewId();
 const long wxsNewWindowDlg::ID_COMBOBOX1 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT11 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL8 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX4 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL5 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT4 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL6 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT7 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT8 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT9 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT10 = wxNewId();
 const long wxsNewWindowDlg::ID_BUTTON2 = wxNewId();
 const long wxsNewWindowDlg::ID_BUTTON3 = wxNewId();
 const long wxsNewWindowDlg::ID_BUTTON4 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT5 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX5 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX9 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX6 = wxNewId();
@@ -112,13 +95,13 @@ const long wxsNewWindowDlg::ID_CHECKBOX7 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX11 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX8 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX12 = wxNewId();
-const long wxsNewWindowDlg::ID_STATICTEXT6 = wxNewId();
 const long wxsNewWindowDlg::ID_TEXTCTRL7 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX14 = wxNewId();
+const long wxsNewWindowDlg::ID_CHECKBOX15 = wxNewId();
 const long wxsNewWindowDlg::ID_CHECKBOX13 = wxNewId();
 //*)
 
-BEGIN_EVENT_TABLE(wxsNewWindowDlg,wxDialog)
+BEGIN_EVENT_TABLE(wxsNewWindowDlg,wxScrollingDialog)
     //(*EventTable(wxsNewWindowDlg)
     //*)
     EVT_BUTTON(wxID_OK,wxsNewWindowDlg::OnCreate)
@@ -135,24 +118,38 @@ wxsNewWindowDlg::wxsNewWindowDlg(wxWindow* parent,const wxString& ResType,wxsPro
     m_Project(Project)
 {
     //(*Initialize(wxsNewWindowDlg)
+    wxStaticText* StaticText10;
+    wxStaticText* StaticText9;
+    wxFlexGridSizer* FlexGridSizer4;
     wxStaticText* StaticText2;
+    wxFlexGridSizer* FlexGridSizer3;
+    wxStaticText* StaticText6;
+    wxStaticText* StaticText8;
+    wxStaticText* StaticText11;
+    wxFlexGridSizer* FlexGridSizer2;
     wxStaticText* StaticText1;
     wxStaticText* StaticText3;
+    wxStaticBoxSizer* StaticBoxSizer3;
+    wxStaticText* StaticText5;
+    wxStaticText* StaticText7;
+    wxFlexGridSizer* FlexGridSizer1;
+    wxStaticText* StaticText4;
+    wxStdDialogButtonSizer* StdDialogButtonSizer1;
 
     Create(parent, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE, _T("wxID_ANY"));
     m_RootSizer = new wxBoxSizer(wxVERTICAL);
     StaticBoxSizer3 = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Options"));
     FlexGridSizer1 = new wxFlexGridSizer(0, 2, 5, 5);
     FlexGridSizer1->AddGrowableCol(1);
-    StaticText1 = new wxStaticText(this, ID_STATICTEXT1, _("Class Name:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
+    StaticText1 = new wxStaticText(this, wxID_ANY, _("Class Name:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer1->Add(StaticText1, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     m_Class = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxSize(80,-1), 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
     FlexGridSizer1->Add(m_Class, 0, wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP, 5);
-    StaticText2 = new wxStaticText(this, ID_STATICTEXT2, _("Header file:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
+    StaticText2 = new wxStaticText(this, wxID_ANY, _("Header file:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer1->Add(StaticText2, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     m_Header = new wxTextCtrl(this, ID_TEXTCTRL2, wxEmptyString, wxDefaultPosition, wxSize(80,-1), 0, wxDefaultValidator, _T("ID_TEXTCTRL2"));
     FlexGridSizer1->Add(m_Header, 0, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText3 = new wxStaticText(this, ID_STATICTEXT3, _("Source file:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
+    StaticText3 = new wxStaticText(this, wxID_ANY, _("Source file:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer1->Add(StaticText3, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     m_Source = new wxTextCtrl(this, ID_TEXTCTRL3, wxEmptyString, wxDefaultPosition, wxSize(80,-1), 0, wxDefaultValidator, _T("ID_TEXTCTRL3"));
     FlexGridSizer1->Add(m_Source, 0, wxEXPAND|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
@@ -180,7 +177,7 @@ wxsNewWindowDlg::wxsNewWindowDlg(wxWindow* parent,const wxString& ResType,wxsPro
     FlexGridSizer2->Add(m_Pch, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
     BoxSizer1->Add(21,16,0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-    StaticText11 = new wxStaticText(this, ID_STATICTEXT11, _("PCH guard define:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT11"));
+    StaticText11 = new wxStaticText(this, wxID_ANY, _("PCH guard define:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     BoxSizer1->Add(StaticText11, 1, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
     FlexGridSizer2->Add(BoxSizer1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
     m_PchGuard = new wxTextCtrl(this, ID_TEXTCTRL8, _("WX_PRECOMP"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL8"));
@@ -191,21 +188,21 @@ wxsNewWindowDlg::wxsNewWindowDlg(wxWindow* parent,const wxString& ResType,wxsPro
     m_InitFunc = new wxTextCtrl(this, ID_TEXTCTRL5, _("BuildContent"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL5"));
     m_InitFunc->Disable();
     FlexGridSizer2->Add(m_InitFunc, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText4 = new wxStaticText(this, ID_STATICTEXT4, _("Base class name:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT4"));
+    StaticText4 = new wxStaticText(this, wxID_ANY, _("Base class name:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer2->Add(StaticText4, 1, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     m_BaseClass = new wxTextCtrl(this, ID_TEXTCTRL6, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL6"));
     FlexGridSizer2->Add(m_BaseClass, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText7 = new wxStaticText(this, ID_STATICTEXT7, _("Scopes:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT7"));
+    StaticText7 = new wxStaticText(this, wxID_ANY, _("Scopes:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer2->Add(StaticText7, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 0);
     FlexGridSizer4 = new wxFlexGridSizer(0, 3, 0, 5);
     FlexGridSizer4->AddGrowableCol(0);
     FlexGridSizer4->AddGrowableCol(1);
     FlexGridSizer4->AddGrowableCol(2);
-    StaticText8 = new wxStaticText(this, ID_STATICTEXT8, _("IDs:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT8"));
+    StaticText8 = new wxStaticText(this, wxID_ANY, _("IDs:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer4->Add(StaticText8, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText9 = new wxStaticText(this, ID_STATICTEXT9, _("Members:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT9"));
+    StaticText9 = new wxStaticText(this, wxID_ANY, _("Members:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer4->Add(StaticText9, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText10 = new wxStaticText(this, ID_STATICTEXT10, _("Handlers:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT10"));
+    StaticText10 = new wxStaticText(this, wxID_ANY, _("Handlers:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer4->Add(StaticText10, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_ScopeIds = new wxButton(this, ID_BUTTON2, _("Public"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON2"));
     FlexGridSizer4->Add(m_ScopeIds, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
@@ -214,58 +211,62 @@ wxsNewWindowDlg::wxsNewWindowDlg(wxWindow* parent,const wxString& ResType,wxsPro
     m_ScopeHandlers = new wxButton(this, ID_BUTTON4, _("Public"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON4"));
     FlexGridSizer4->Add(m_ScopeHandlers, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     FlexGridSizer2->Add(FlexGridSizer4, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
-    StaticText5 = new wxStaticText(this, ID_STATICTEXT5, _("Constructor arguments:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT5"));
+    StaticText5 = new wxStaticText(this, wxID_ANY, _("Constructor arguments:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer2->Add(StaticText5, 1, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     FlexGridSizer3 = new wxFlexGridSizer(0, 2, 0, 10);
     FlexGridSizer3->AddGrowableCol(0);
+    FlexGridSizer3->AddGrowableCol(1);
     m_CtorParent = new wxCheckBox(this, ID_CHECKBOX5, _("Parent"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX5"));
     m_CtorParent->SetValue(true);
-    FlexGridSizer3->Add(m_CtorParent, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorParent, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorParentDef = new wxCheckBox(this, ID_CHECKBOX9, _("Def. value"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX9"));
     m_CtorParentDef->SetValue(false);
-    FlexGridSizer3->Add(m_CtorParentDef, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorParentDef, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorId = new wxCheckBox(this, ID_CHECKBOX6, _("Id"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX6"));
     m_CtorId->SetValue(true);
-    FlexGridSizer3->Add(m_CtorId, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorId, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorIdDef = new wxCheckBox(this, ID_CHECKBOX10, _("Def. value"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX10"));
     m_CtorIdDef->SetValue(true);
-    FlexGridSizer3->Add(m_CtorIdDef, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorIdDef, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorPos = new wxCheckBox(this, ID_CHECKBOX7, _("Position"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX7"));
     m_CtorPos->SetValue(false);
     FlexGridSizer3->Add(m_CtorPos, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorPosDef = new wxCheckBox(this, ID_CHECKBOX11, _("Def. value"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX11"));
     m_CtorPosDef->SetValue(true);
     m_CtorPosDef->Disable();
-    FlexGridSizer3->Add(m_CtorPosDef, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorPosDef, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorSize = new wxCheckBox(this, ID_CHECKBOX8, _("Size"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX8"));
     m_CtorSize->SetValue(false);
     FlexGridSizer3->Add(m_CtorSize, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorSizeDef = new wxCheckBox(this, ID_CHECKBOX12, _("Def. value"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX12"));
     m_CtorSizeDef->SetValue(true);
     m_CtorSizeDef->Disable();
-    FlexGridSizer3->Add(m_CtorSizeDef, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    FlexGridSizer3->Add(m_CtorSizeDef, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     FlexGridSizer2->Add(FlexGridSizer3, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    StaticText6 = new wxStaticText(this, ID_STATICTEXT6, _("Custom arguments:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT6"));
+    StaticText6 = new wxStaticText(this, wxID_ANY, _("Custom arguments:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
     FlexGridSizer2->Add(StaticText6, 1, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
     m_CtorCustom = new wxTextCtrl(this, ID_TEXTCTRL7, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL7"));
     FlexGridSizer2->Add(m_CtorCustom, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    m_AdvancedOptionsSizer->Add(FlexGridSizer2, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    m_AdvancedOptionsSizer->Add(FlexGridSizer2, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_UseFwdDecl = new wxCheckBox(this, ID_CHECKBOX14, _("Use forward declarations"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX14"));
     m_UseFwdDecl->SetValue(false);
-    m_AdvancedOptionsSizer->Add(m_UseFwdDecl, 0, wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    m_AdvancedOptionsSizer->Add(m_UseFwdDecl, 0, wxTOP|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    m_UseI18n = new wxCheckBox(this, ID_CHECKBOX15, _("Use internationalisation (translatable applications)"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX15"));
+    m_UseI18n->SetValue(true);
+    m_AdvancedOptionsSizer->Add(m_UseI18n, 0, wxTOP|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_AddWxs = new wxCheckBox(this, ID_CHECKBOX13, _("Add wxs file to project"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX13"));
-    m_AddWxs->SetValue(false);
-    m_AdvancedOptionsSizer->Add(m_AddWxs, 0, wxBOTTOM|wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    m_AddWxs->SetValue(true);
+    m_AdvancedOptionsSizer->Add(m_AddWxs, 0, wxTOP|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     m_RootSizer->Add(m_AdvancedOptionsSizer, 0, wxLEFT|wxRIGHT|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    m_RootSizer->Add(300,5,0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     StdDialogButtonSizer1 = new wxStdDialogButtonSizer();
     StdDialogButtonSizer1->AddButton(new wxButton(this, wxID_OK, wxEmptyString));
     StdDialogButtonSizer1->AddButton(new wxButton(this, wxID_CANCEL, wxEmptyString));
     StdDialogButtonSizer1->Realize();
-    m_RootSizer->Add(StdDialogButtonSizer1, 0, wxBOTTOM|wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    m_RootSizer->Add(StdDialogButtonSizer1, 0, wxTOP|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     SetSizer(m_RootSizer);
     m_RootSizer->Fit(this);
     m_RootSizer->SetSizeHints(this);
+    Center();
 
     Connect(ID_TEXTCTRL1,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&wxsNewWindowDlg::OnClassChanged);
     Connect(ID_TEXTCTRL2,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&wxsNewWindowDlg::OnHeaderChanged);
@@ -335,6 +336,7 @@ wxsNewWindowDlg::wxsNewWindowDlg(wxWindow* parent,const wxString& ResType,wxsPro
     m_ScopeMembersVal = (wxsItemRes::NewResourceParams::Scope)Cfg->ReadInt(_T("/newresource/scopemembers"),(int)wxsItemRes::NewResourceParams::Public);
     m_ScopeHandlersVal = (wxsItemRes::NewResourceParams::Scope)Cfg->ReadInt(_T("/newresource/scopehandlers"),(int)wxsItemRes::NewResourceParams::Private);
     m_UseFwdDecl->SetValue(Cfg->ReadBool(_T("/newresource/usefwddecl"),m_UseFwdDecl->GetValue()));
+    m_UseI18n->SetValue(Cfg->ReadBool(_T("/newresource/usei18n"),m_UseI18n->GetValue()));
     m_PchGuard->SetValue(Cfg->Read(_T("/newresource/pchguard"),m_PchGuard->GetValue()));
     UpdateScopeButtons();
     OnUseXrcChange(event);
@@ -356,7 +358,7 @@ void wxsNewWindowDlg::OnCancel(wxCommandEvent& event)
 
 void wxsNewWindowDlg::OnCreate(wxCommandEvent& event)
 {
-	bool CreateXrc = m_UseXrc->GetValue();
+    bool CreateXrc = m_UseXrc->GetValue();
     cbProject* cbProj = m_Project->GetCBProject();
 
     wxsItemRes::NewResourceParams Params;
@@ -383,6 +385,7 @@ void wxsNewWindowDlg::OnCreate(wxCommandEvent& event)
     Params.ScopeMembers   = m_ScopeMembersVal;
     Params.ScopeHandlers  = m_ScopeHandlersVal;
     Params.UseFwdDecl     = m_UseFwdDecl->GetValue();
+    Params.UseI18n        = m_UseI18n->GetValue();
     Params.PchGuard       = m_PchGuard->GetValue();
 
     // Need to do some checks
@@ -470,6 +473,10 @@ void wxsNewWindowDlg::OnCreate(wxCommandEvent& event)
     {
         NewResource = new wxsDialogRes(m_Project);
     }
+    else if ( m_Type == _T("wxScrollingDialog") )
+    {
+        NewResource = new wxsScrollingDialogRes(m_Project);
+    }
     else if ( m_Type == _T("wxFrame") )
     {
         NewResource = new wxsFrameRes(m_Project);
@@ -549,7 +556,7 @@ void wxsNewWindowDlg::OnCreate(wxCommandEvent& event)
             Manager::Get()->GetProjectManager()->AddFileToProject(Params.Wxs,cbProj,Targets);
         }
     }
-    Manager::Get()->GetProjectManager()->RebuildTree();
+    Manager::Get()->GetProjectManager()->GetUI().RebuildTree();
 
     // Opening editor for this resource
     NewResource->EditOpen();
@@ -575,6 +582,7 @@ void wxsNewWindowDlg::OnCreate(wxCommandEvent& event)
     Cfg->Write(_T("/newresource/scopehandlers"),(int)m_ScopeHandlersVal);
     Cfg->Write(_T("/newresource/sourcedirectory"),m_SourceDirectory);
     Cfg->Write(_T("/newresource/usefwddecl"),m_UseFwdDecl->GetValue());
+    Cfg->Write(_T("/newresource/usei18n"),m_UseI18n->GetValue());
     Cfg->Write(_T("/newresource/pchguard"),m_PchGuard->GetValue());
 
     EndModal(wxID_OK);
@@ -657,9 +665,9 @@ wxString wxsNewWindowDlg::DetectPchFile()
 {
     // Searching for files that are good candidates for pch files
     cbProject* Proj = m_Project->GetCBProject();
-    for ( int i=0; i<Proj->GetFilesCount(); i++ )
+    for (FilesList::iterator it = Proj->GetFilesList().begin(); it != Proj->GetFilesList().end(); ++it)
     {
-        ProjectFile* File = Proj->GetFile(i);
+        ProjectFile* File = *it;
         if ( File && File->file.GetExt()==_T("h") && File->compile )
         {
             int Index = m_Pch->Append(File->relativeFilename);
