@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: msvc7loader.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/projectsimporter/msvc7loader.cpp $
+ * $Revision: 9151 $
+ * $Id: msvc7loader.cpp 9151 2013-06-12 14:32:09Z biplab $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/projectsimporter/msvc7loader.cpp $
  */
 
 #include "sdk.h"
@@ -23,6 +23,8 @@
 
 #include <wx/choicdlg.h>
 
+#include <tinyxml/tinyxml.h>
+
 #include "prep.h"
 #include "msvc7loader.h"
 #include "multiselectdlg.h"
@@ -81,7 +83,7 @@ bool MSVC7Loader::Open(const wxString& filename)
     m_ConvertSwitches = m_pProject->GetCompilerID().IsSameAs(_T("gcc"));
     m_ProjectName = wxFileName(filename).GetName();
 
-    pMsg->DebugLog(F(_T("Importing MSVC 7.xx project: %s"), filename.c_str()));
+    pMsg->DebugLog(F(_T("Importing MSVC 7.xx project: %s"), filename.wx_str()));
 
     TiXmlDocument doc(filename.mb_str());
     if (!doc.LoadFile())
@@ -109,7 +111,7 @@ bool MSVC7Loader::Open(const wxString& filename)
     if ((m_Version!=70) && (m_Version!=71))
     {
         // seems to work with visual 8 too ;)
-        pMsg->DebugLog(F(_T("Project version is '%s'. Although this loader was designed for version 7.xx, will try to import..."), ver.c_str()));
+        pMsg->DebugLog(F(_T("Project version is '%s'. Although this loader was designed for version 7.xx, will try to import..."), ver.wx_str()));
     }
 
     m_pProject->ClearAllProperties();
@@ -123,7 +125,7 @@ bool MSVC7Loader::Open(const wxString& filename)
     return DoSelectConfiguration(root);
 }
 
-bool MSVC7Loader::Save(const wxString& filename)
+bool MSVC7Loader::Save(cb_unused const wxString& filename)
 {
     // no support to save MSVC7 projects
     return false;
@@ -239,7 +241,8 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
         bt->SetTargetType(ttNative);
     else if (conftype.IsSameAs(_T("10"))) // typeGeneric 10
         bt->SetTargetType(ttCommandsOnly);
-    else { // typeUnknown 0
+    else // typeUnknown 0
+    {
         bt->SetTargetType(ttCommandsOnly);
         Manager::Get()->GetLogManager()->DebugLog(_T("unrecognized project type"));
     }
@@ -259,33 +262,38 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
             // linker
             wxString tmp;
 
-            if ((bt->GetTargetType()==ttExecutable) || (bt->GetTargetType()==ttNative)) {
+            if ((bt->GetTargetType()==ttExecutable) || (bt->GetTargetType()==ttNative))
+            {
                 tmp = cbC2U(tool->Attribute("SubSystem"));
                 //subSystemNotSet 0
                 //subSystemConsole 1
                 //subSystemWindows 2
-                if (tmp.IsSameAs(_T("1"))) {
+                if (tmp.IsSameAs(_T("1")))
+                {
                     bt->SetTargetType(ttConsoleOnly);
                     //bt->AddLinkerOption("/SUBSYSTEM:CONSOLE"); // don't know if it is necessary
                 }
-                else if (tmp.IsSameAs(_T("3"))) {
+                else if (tmp.IsSameAs(_T("3")))
                     bt->SetTargetType(ttNative);
-                }
             } // else we keep executable
 
             tmp = ReplaceMSVCMacros(cbC2U(tool->Attribute("OutputFile")));
             tmp = UnixFilename(tmp);
             if (tmp.Last() == _T('.')) tmp.RemoveLast();
-            if (bt->GetTargetType() == ttStaticLib) {
+            if (bt->GetTargetType() == ttStaticLib)
+            {
                 // convert the lib name
                 Compiler* compiler = CompilerFactory::GetCompiler(m_pProject->GetCompilerID());
-                wxString prefix = compiler->GetSwitches().libPrefix;
-                wxString suffix = compiler->GetSwitches().libExtension;
-                wxFileName fname = tmp;
-                if (!fname.GetName().StartsWith(prefix))
-                    fname.SetName(prefix + fname.GetName());
-                fname.SetExt(suffix);
-                tmp = fname.GetFullPath();
+                if (compiler)
+                {
+                    wxString prefix = compiler->GetSwitches().libPrefix;
+                    wxString suffix = compiler->GetSwitches().libExtension;
+                    wxFileName fname = tmp;
+                    if (!fname.GetName().StartsWith(prefix))
+                        fname.SetName(prefix + fname.GetName());
+                    fname.SetExt(suffix);
+                    tmp = fname.GetFullPath();
+                }
             }
             bt->SetOutputFilename(tmp);
             m_TargetPath = wxFileName(tmp).GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
@@ -329,7 +337,8 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
             }
 
             // other options: /MACHINE:I386, /INCREMENTAL:YES, /STACK:10000000
-            if (!m_ConvertSwitches) {
+            if (!m_ConvertSwitches)
+            {
                 arr = GetArrayFromString(ReplaceMSVCMacros(cbC2U(tool->Attribute("AdditionalOptions"))), _T(" "));
                 for (unsigned int i = 0; i < arr.GetCount(); ++i) bt->AddLinkerOption(arr[i]);
             }
@@ -342,7 +351,10 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
                 tmp = arr[i];
                 if (tmp.Right(4).CmpNoCase(_T(".lib")) == 0)
                     tmp.Remove(tmp.Length() - 4);
-                bt->AddLinkLib(tmp);
+                if ((tmp == _T("/dll")) || (tmp == _T("/DLL")))
+                    bt->AddLinkerOption(_T("--dll"));
+                else
+                    bt->AddLinkLib(tmp);
             }
 
             if (!m_ConvertSwitches)
@@ -388,12 +400,12 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
             arr = GetArrayFromString(tmp, _T(","));
             if (arr.GetCount() == 1) // if it fails, try with semicolon
                 arr = GetArrayFromString(tmp, _T(";"));
-            for (unsigned int i = 0; i < arr.GetCount(); ++i)
+            for (unsigned int j = 0; j < arr.GetCount(); ++j)
             {
                 if (m_ConvertSwitches)
-                    bt->AddCompilerOption(wxString(_T("-D")) + arr[i]);
+                    bt->AddCompilerOption(wxString(_T("-D")) + arr[j]);
                 else
-                    bt->AddCompilerOption(wxString(_T("/D")) + arr[i]);
+                    bt->AddCompilerOption(wxString(_T("/D")) + arr[j]);
             }
 
             tmp = cbC2U(tool->Attribute("WarningLevel"));
@@ -526,9 +538,9 @@ bool MSVC7Loader::DoImport(TiXmlElement* conf)
             {
                 wxArrayString FIfiles;
                 ParseInputString(tmp, FIfiles);
-                for (size_t i = 0; i < FIfiles.GetCount(); ++i)
-                    bt->AddCompilerOption(m_ConvertSwitches? _T("-include ") + ReplaceMSVCMacros(FIfiles[i])
-                                          : _T("/FI ") + ReplaceMSVCMacros(FIfiles[i]));
+                for (size_t j = 0; j < FIfiles.GetCount(); ++j)
+                    bt->AddCompilerOption(m_ConvertSwitches? _T("-include ") + ReplaceMSVCMacros(FIfiles[j])
+                                          : _T("/FI ") + ReplaceMSVCMacros(FIfiles[j]));
             }
 
         }
@@ -565,6 +577,58 @@ bool MSVC7Loader::DoImportFiles(TiXmlElement* root, int numConfigurations)
         while (file)
         {
             wxString fname = ReplaceMSVCMacros(cbC2U(file->Attribute("RelativePath")));
+
+            TiXmlElement* conf = file->FirstChildElement("FileConfiguration");
+            while (conf)
+            {
+                // find the target to which it applies
+                wxString sTargetName = cbC2U(conf->Attribute("Name"));
+                sTargetName.Replace(_T("|"), _T(" "), true);
+                ProjectBuildTarget* bt = m_pProject->GetBuildTarget(sTargetName);
+
+                TiXmlElement* tool = conf->FirstChildElement("Tool");
+                while (tool)
+                {
+                    // get additional include directories
+                    wxString sAdditionalInclude;
+                    sAdditionalInclude = cbC2U(tool->Attribute("AdditionalIncludeDirectories"));
+
+                    if (sAdditionalInclude.Len() > 0)
+                    {
+                        // we have to add the additionnal include directories.
+                        // parse the different include directories (comma separated)
+                        int iStart;
+                        int iCommaPosition;
+                        iStart = 0;
+                        iCommaPosition = sAdditionalInclude.Find(_T(","));
+                        do
+                        {
+                            int iEnd;
+                            if (iCommaPosition != wxNOT_FOUND)
+                            {
+                                iEnd = iCommaPosition - 1;
+                                if (iEnd < iStart) iEnd = iStart;
+                            }
+                            else
+                                iEnd = sAdditionalInclude.Len() - 1;
+
+                            wxString sInclude = sAdditionalInclude.Mid(iStart, iEnd - iStart + 1);
+                            if (bt)
+                                bt->AddIncludeDir(sInclude);
+
+                            // remove the directory from the include list
+                            sAdditionalInclude = sAdditionalInclude.Mid(iEnd + 2);
+                            iCommaPosition = sAdditionalInclude.Find(_T(","));
+                        }
+                        while (sAdditionalInclude.Len() > 0);
+                    }
+
+                    tool = tool->NextSiblingElement();
+                }
+
+                conf = conf->NextSiblingElement("FileConfiguration");
+            }
+
             if ((!fname.IsEmpty()) && (fname != _T(".\\")))
             {
                 if (fname.StartsWith(_T(".\\")))
@@ -625,8 +689,7 @@ void MSVC7Loader::HandleFileConfiguration(TiXmlElement* file, ProjectFile* pf)
                 name.Replace(_T("|"), _T(" "), true); // Replace '|' to ensure proper check
                 pf->RemoveBuildTarget(name);
                 Manager::Get()->GetLogManager()->DebugLog(
-                    F(_("removed %s from %s"),
-                    pf->file.GetFullPath().c_str(), name.c_str()));
+                    F(_("removed %s from %s"), pf->file.GetFullPath().wx_str(), name.wx_str()));
             }
         }
         fconf = fconf->NextSiblingElement("FileConfiguration");
