@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: msvcloader.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/plugins/projectsimporter/msvcloader.cpp $
+ * $Revision: 8680 $
+ * $Id: msvcloader.cpp 8680 2012-12-16 14:58:35Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/projectsimporter/msvcloader.cpp $
  */
 
 #include "sdk.h"
@@ -29,6 +29,7 @@
 #endif
 
 #include <wx/stream.h>
+#include <wx/tokenzr.h>
 
 #include "prep.h"
 #include "importers_globals.h"
@@ -40,8 +41,8 @@
  * compatibility function in wxWidgets-2.8. So in future it will be dropped.
  */
 
-MSVCLoader::MSVCLoader(cbProject* project)
-    : m_pProject(project),
+MSVCLoader::MSVCLoader(cbProject* project) :
+    m_pProject(project),
     m_ConvertSwitches(true)
 {
     //ctor
@@ -99,7 +100,7 @@ bool MSVCLoader::Open(const wxString& filename)
     return ParseSourceFiles();
 }
 
-bool MSVCLoader::Save(const wxString& filename)
+bool MSVCLoader::Save(cb_unused const wxString& filename)
 {
     // no support to save MSVC projects
     return false;
@@ -123,8 +124,8 @@ bool MSVCLoader::ReadConfigurations()
     {
         wxString line = input.ReadLine();
         ++currentLine;
-        line.Trim(true);
-        line.Trim(false);
+        line.Trim(true).Trim(false);
+
         int size = -1;
         if (line.StartsWith(_T("# TARGTYPE")))
         {
@@ -196,8 +197,8 @@ bool MSVCLoader::ReadConfigurations()
         {
             // read configuration name
             line = line.Mid(size);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
+
             wxString tmp = RemoveQuotes(line);
             // remove the project name part, i.e "anothertest - "
             int idx = tmp.Find('-');
@@ -210,7 +211,7 @@ bool MSVCLoader::ReadConfigurations()
             {
                 m_Configurations.Add(tmp);
                 m_ConfigurationsLineIndex.Add(currentLine);
-                Manager::Get()->GetLogManager()->DebugLog(F(_T("Detected configuration '%s' at line %d"), tmp.c_str(), currentLine));
+                Manager::Get()->GetLogManager()->DebugLog(F(_T("Detected configuration '%s' at line %d"), tmp.wx_str(), currentLine));
             }
         }
     }
@@ -249,22 +250,44 @@ bool MSVCLoader::ParseConfiguration(int index)
     while (!file.Eof())
     {
         wxString line = input.ReadLine();
-        line.Trim(true);
-        line.Trim(false);
+        line.Trim(true).Trim(false);
 
         // we want empty lines (skipped) or lines starting with #
         // if we encounter a line starting with !, we break out of here
         if (line.GetChar(0) == '!')
+        {
             break;
+        }
+
         if (line.IsEmpty() || line.GetChar(0) != '#')
-            continue;
+        {
+            // Unhandled, but for this exception:
+            if (line.StartsWith(_T("PostBuild_Cmds=")))
+            {
+                line = line.Mid(15);
+
+                while (!line.StartsWith(_T("# End Special Build Tool")))
+                {
+                    bool next_line = line.EndsWith(_T("\\"));
+                    ProcessPostBuildCommand(bt, line);
+
+                    if (!next_line)
+                        break; // exit while-loop
+
+                    // next line (iteration) as post build commands are usually multiple lines
+                    line = input.ReadLine();
+                    line.Trim(true).Trim(false);
+                }
+            }
+            else
+                continue;
+        }
 
 //        if (line.StartsWith("# PROP BASE Output_Dir "))
         if (line.StartsWith(_T("# PROP Output_Dir ")))
         {
             line = line.Mid(18);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             wxString tmp = RemoveQuotes(line);
             if (!line.IsEmpty())
             {
@@ -279,8 +302,7 @@ bool MSVCLoader::ParseConfiguration(int index)
         else if (line.StartsWith(_T("# PROP Intermediate_Dir ")))
         {
             line = line.Mid(24);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             wxString tmp = RemoveQuotes(line);
             if (!line.IsEmpty())
             {
@@ -290,43 +312,37 @@ bool MSVCLoader::ParseConfiguration(int index)
         else if (line.StartsWith(_T("# ADD BASE CPP ")))
         {
             line = line.Mid(15);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessCompilerOptions(bt, line);
         }
         else if (line.StartsWith(_T("# ADD CPP ")))
         {
             line = line.Mid(10);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessCompilerOptions(bt, line);
         }
         else if (line.StartsWith(_T("# ADD BASE LINK32 ")))
         {
             line = line.Mid(18);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessLinkerOptions(bt, line);
         }
         else if (line.StartsWith(_T("# ADD LINK32 ")))
         {
             line = line.Mid(13);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessLinkerOptions(bt, line);
         }
         else if (line.StartsWith(_T("# ADD BASE RSC "))) // To import resource compiler options
         {
             line = line.Mid(16);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessResourceCompilerOptions(bt, line);
         }
         else if (line.StartsWith(_T("# ADD RSC ")))
         {
             line = line.Mid(11);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
             ProcessResourceCompilerOptions(bt, line);
         }
     }
@@ -356,14 +372,12 @@ bool MSVCLoader::ParseSourceFiles()
     while (!file.Eof())
     {
         wxString line = input.ReadLine();
-        line.Trim(true);
-        line.Trim(false);
+        line.Trim(true).Trim(false);
 
         if (line.StartsWith(_T("SOURCE=")))
         {
             line = line.Mid(7);
-            line.Trim(true);
-            line.Trim(false);
+            line.Trim(true).Trim(false);
 
             wxString fname (RemoveQuotes(line));
 
@@ -506,8 +520,8 @@ void MSVCLoader::ProcessCompilerOptions(ProjectBuildTarget* target, const wxStri
                 wxArrayString options;
                 if (ParseResponseFile(m_pProject->GetBasePath() + opt.Mid(1), options))
                 {
-                    for (size_t i = 0; i < options.GetCount(); ++i)
-                        ProcessCompilerOptions(target, options[i]);
+                    for (size_t j = 0; j < options.GetCount(); ++j)
+                        ProcessCompilerOptions(target, options[j]);
                 }
                 else
                 { // Fallback: Remember GCC will process Pre-processor macros only
@@ -574,6 +588,11 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
             {
                 // do nothing (ignore silently)
             }
+            else if (opt.Matches(_T("/dll")))
+            {
+                opt = opt.Mid(4);
+                target->AddLinkerOption(_T("--dll ") + RemoveQuotes(opt));
+            }
             else if (opt.StartsWith(_T("/out:")))
             {
                 // do nothing; it is handled below, in common options
@@ -583,8 +602,8 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
                 wxArrayString options;
                 if (ParseResponseFile(m_pProject->GetBasePath() + opt.Mid(1), options))
                 {
-                    for (size_t i = 0; i < options.GetCount(); ++i)
-                        ProcessLinkerOptions(target, options[i]);
+                    for (size_t j = 0; j < options.GetCount(); ++j)
+                        ProcessLinkerOptions(target, options[j]);
                 } // else ignore
             }
             else if (opt.Find(_T(".lib")) == -1) // don't add linking lib (added below, in common options)
@@ -634,11 +653,14 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
                 if (newf.IsRelative())
                     newf.MakeAbsolute(m_pProject->GetBasePath());
                 Compiler* compiler = CompilerFactory::GetCompiler(m_pProject->GetCompilerID());
-                newf.SetExt(compiler->GetSwitches().libExtension);
-                wxString name = newf.GetName();
-                wxString prefix = compiler->GetSwitches().libPrefix;
-                if (!prefix.IsEmpty() && !name.StartsWith(prefix))
-                    newf.SetName(prefix + name);
+                if (compiler)
+                {
+                    newf.SetExt(compiler->GetSwitches().libExtension);
+                    wxString name = newf.GetName();
+                    wxString prefix = compiler->GetSwitches().libPrefix;
+                    if (!prefix.IsEmpty() && !name.StartsWith(prefix))
+                        newf.SetName(prefix + name);
+                }
                 target->SetOutputFilename(newf.GetFullPath());
             }
             else
@@ -665,6 +687,33 @@ void MSVCLoader::ProcessResourceCompilerOptions(ProjectBuildTarget* target, cons
     }
 }
 
+void MSVCLoader::ProcessPostBuildCommand(ProjectBuildTarget* target, const wxString& cmd)
+{
+    wxString post_build_cmd = cmd;
+
+/*
+     remove "line continues", like in:
+     PostBuild_Cmds=if NOT exist ..\binary\*.* mkdir ..\binary	\
+     copy $(OutDir)\NetHackW.exe ..\binary
+*/
+    if (post_build_cmd.EndsWith(_T("\\")))
+        post_build_cmd.RemoveLast(1).Trim(true).Trim(false);
+
+    if (!post_build_cmd.IsEmpty())
+    {
+        // Some weirdness: VC6 separates commands by a linefeed OR a TAB (?!)
+        // Linefeeds are handled by the caller, we do handle tabs here only.
+        wxStringTokenizer tkz(post_build_cmd, wxT("\t"));
+        while (tkz.HasMoreTokens())
+        {
+            // process token
+            wxString current_post_build_cmd = tkz.GetNextToken().Trim(true).Trim(false);
+            if (!current_post_build_cmd.IsEmpty())
+                target->AddCommandsAfterBuild(current_post_build_cmd);
+        }
+    }
+}
+
 wxArrayString MSVCLoader::OptStringTokeniser(const wxString& opts)
 {
     // tokenise string like:
