@@ -2,15 +2,11 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9418 $
+ * $Id: wiz.cpp 9418 2013-10-23 20:45:12Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/scriptedwizard/wiz.cpp $
  */
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-    #pragma implementation "wiz.h"
-#endif
-
 #include "wiz.h"
 #include <wx/dir.h>
 #include <wx/intl.h>
@@ -21,6 +17,8 @@
 #include <wx/panel.h>
 #include <wx/checkbox.h>
 #include <wx/combobox.h>
+#include <wx/spinctrl.h>
+#include <wx/wxscintilla.h>
 
 #include <globals.h>
 #include <cbexception.h>
@@ -32,6 +30,7 @@
 #include <compiler.h>
 #include <cbproject.h>
 #include <projectbuildtarget.h>
+#include <prep.h>
 #include <filefilters.h>
 #include <infowindow.h>
 
@@ -40,7 +39,7 @@
 #include "wizpage.h"
 
 #include <wx/arrimpl.cpp>
-WX_DEFINE_OBJARRAY(Wizards);
+WX_DEFINE_OBJARRAY(Wizards); // TODO: find out why this causes a shadow warning for 'Item'
 
 namespace
 {
@@ -55,7 +54,8 @@ Wiz::Wiz()
     m_pWizProjectPathPanel(0),
     m_pWizFilePathPanel(0),
     m_pWizCompilerPanel(0),
-    m_pWizBuildTargetPanel(0)
+    m_pWizBuildTargetPanel(0),
+    m_LaunchIndex(0)
 {
     //ctor
 }
@@ -345,7 +345,13 @@ CompileTargetBase* Wiz::RunProjectWizard(wxString* pFilename)
     }
 
     // now create the project
+    // make sure to respect the compiler chosen by the user for the project, too
+    wxString defCompilerID = CompilerFactory::GetDefaultCompilerID();
+    CompilerFactory::SetDefaultCompiler(GetCompilerID());
+    // create the project with the (probably) updated compiler
     theproject = Manager::Get()->GetProjectManager()->NewProject(prjname);
+    // setup the old default compiler again
+    CompilerFactory::SetDefaultCompiler(defCompilerID);
     if (!theproject)
     {
         cbMessageBox(_("Couldn't create the new project:\n") + prjdir, _("Error"), wxICON_ERROR);
@@ -445,6 +451,13 @@ CompileTargetBase* Wiz::RunProjectWizard(wxString* pFilename)
 
             if (files.GetCount() != 0 && contents.GetCount() == files.GetCount())
             {
+                // prepare the list of targets to add this file to (i.e. all of them)
+                wxArrayInt targetIndices;
+                for (int x = 0; x < theproject->GetBuildTargetsCount(); ++x)
+                    targetIndices.Add(x);
+
+                theproject->BeginAddFiles();
+
                 // ok, we have to generate some files here
                 size_t count = files.GetCount();
                 for (size_t i = 0; i < count; ++i)
@@ -459,19 +472,16 @@ CompileTargetBase* Wiz::RunProjectWizard(wxString* pFilename)
                         {
                             Manager::Get()->GetLogManager()->DebugLog(_T("Generated file ") + actual);
                             // add it to the project
-                            ProjectFile* pf = theproject->AddFile(0, actual);
-                            // to all targets...
-                            for (int x = 1; x < theproject->GetBuildTargetsCount(); ++x)
-                            {
-                                pf->AddBuildTarget(theproject->GetBuildTarget(x)->GetTitle());
-                            }
+                            Manager::Get()->GetProjectManager()->AddFileToProject(actual, theproject, targetIndices);
                         }
                         else
                         {
-                            Manager::Get()->GetLogManager()->DebugLog(F(_T("File %s exists"), actual.c_str()));
+                            Manager::Get()->GetLogManager()->DebugLog(F(_T("File %s exists"), actual.wx_str()));
                         }
                     }
                 }
+
+                theproject->EndAddFiles();
             }
         }
     }
@@ -513,12 +523,12 @@ CompileTargetBase* Wiz::RunProjectWizard(wxString* pFilename)
         *pFilename = theproject->GetFilename();
 
     // finally, make sure everything looks ok
-    Manager::Get()->GetProjectManager()->RebuildTree();
-    Manager::Get()->GetProjectManager()->GetTree()->Expand(theproject->GetProjectNode());
+    Manager::Get()->GetProjectManager()->GetUI().RebuildTree();
+    Manager::Get()->GetProjectManager()->GetUI().GetTree()->Expand(theproject->GetProjectNode());
     return theproject;
 }
 
-CompileTargetBase* Wiz::RunTargetWizard(wxString* pFilename)
+CompileTargetBase* Wiz::RunTargetWizard(cb_unused wxString* pFilename)
 {
     cbProject* theproject = Manager::Get()->GetProjectManager()->GetActiveProject(); // can't fail; if no project, the wizard didn't even run
     ProjectBuildTarget* target = theproject->AddBuildTarget(GetTargetName());
@@ -558,9 +568,9 @@ CompileTargetBase* Wiz::RunTargetWizard(wxString* pFilename)
     target->SetObjectOutput(GetTargetObjectOutputDir());
     target->SetWorkingDir(GetTargetOutputDir());
     // Assign this target to all project files
-    for (int i = 0; i < theproject->GetFilesCount(); ++i)
+    for (FilesList::iterator it = theproject->GetFilesList().begin(); it != theproject->GetFilesList().end(); ++it)
     {
-        ProjectFile* pf = theproject->GetFile(i);
+        ProjectFile* pf = *it;
         if (pf)
             pf->AddBuildTarget(GetTargetName());
     }
@@ -632,7 +642,7 @@ CompileTargetBase* Wiz::RunFilesWizard(wxString* pFilename)
     return 0;
 }
 
-CompileTargetBase* Wiz::RunCustomWizard(wxString* pFilename)
+CompileTargetBase* Wiz::RunCustomWizard(cb_unused wxString* pFilename)
 {
     try
     {
@@ -685,23 +695,38 @@ wxString Wiz::GenerateFile(const wxString& basePath, const wxString& filename, c
                 // attempt to create file outside the project dir
                 // remove any path info from the filename
                 fname = fname.GetFullName();
-                Manager::Get()->GetLogManager()->DebugLog(F(_T("Attempt to generate a file outside the project base dir:\nOriginal: %s\nConverted to:%s"), filename.c_str(), fname.GetFullPath().c_str()));
+                Manager::Get()->GetLogManager()->DebugLog(F(_T("Attempt to generate a file outside the project base dir:\nOriginal: %s\nConverted to:%s"), filename.wx_str(), fname.GetFullPath().wx_str()));
                 break;
             }
         }
         else if ( Dirs[i] != _T(".") )
-        {
             IntDirCount++;
-        }
     }
 
     fname = basePath + wxFILE_SEP_PATH + fname.GetFullPath();
+    if ( fname.FileExists() )
+    {
+        wxString query_overwrite;
+        query_overwrite.Printf(
+          _T("Warning:\n")
+          _T("The wizard is about OVERWRITE the following existing file:\n")+
+          fname.GetFullPath()+_T("\n\n") +
+          _T("Are you sure that you want to OVERWRITE the file?\n\n")+
+          _T("(If you answer 'No' the existing file will be kept.)"));
+        if (cbMessageBox(query_overwrite, _T("Confirmation"),
+                         wxICON_QUESTION | wxYES_NO | wxNO_DEFAULT) == wxID_NO)
+        {
+            return fname.GetFullPath();
+        }
+    }
 
     // create the file with the passed contents
     wxFileName::Mkdir(fname.GetPath(),0777,wxPATH_MKDIR_FULL);
     wxFile f(fname.GetFullPath(), wxFile::write);
-    if (cbWrite(f, contents + _T('\n')))
+
+    if ( cbWrite(f, contents + GetEOLStr(), wxFONTENCODING_UTF8) )
         return fname.GetFullPath(); // success
+
     return wxEmptyString; // failed
 }
 
@@ -710,12 +735,22 @@ void Wiz::CopyFiles(cbProject* theproject, const wxString&  prjdir, const wxStri
     // first get the dir with the files
     wxArrayString filesList;
     wxString enumdirs = ConfigManager::GetFolder(sdDataUser) + _T("/templates/wizard/") + srcdir;
-    if (!wxDirExists(enumdirs + _T("/")))
+    if ( !wxDirExists(enumdirs + _T("/")) )
         enumdirs = ConfigManager::GetFolder(sdDataGlobal) + _T("/templates/wizard/") + srcdir;
     wxString basepath = wxFileName(enumdirs).GetFullPath();
 
-    // recursively enumerate all files under srcdir
-    wxDir::GetAllFiles(enumdirs, &filesList);
+    if ( wxDirExists(enumdirs + _T("/")) )
+    {
+        // recursively enumerate all files under srcdir
+        wxDir::GetAllFiles(enumdirs, &filesList);
+    }
+
+    // prepare the list of targets to add this file to (i.e. all of them)
+    wxArrayInt targetIndices;
+    for (int x = 0; x < theproject->GetBuildTargetsCount(); ++x)
+        targetIndices.Add(x);
+
+    theproject->BeginAddFiles();
 
     // now get each file and copy it to the destination directory,
     // adding it to all targets in the project
@@ -744,7 +779,7 @@ void Wiz::CopyFiles(cbProject* theproject, const wxString&  prjdir, const wxStri
               _T("Are you sure that you want to OVERWRITE the file?\n\n")+
               _T("(If you answer 'No' the existing file will be kept.)"));
             if (cbMessageBox(query_overwrite, _T("Confirmation"),
-                             wxICON_QUESTION | wxYES_NO) != wxID_YES)
+                             wxICON_QUESTION | wxYES_NO | wxNO_DEFAULT) != wxID_YES)
             {
                 do_copy = false; // keep the old (existing) file
             }
@@ -753,13 +788,10 @@ void Wiz::CopyFiles(cbProject* theproject, const wxString&  prjdir, const wxStri
 
         // and add it to the project
         fname.MakeRelativeTo(prjdir);
-        ProjectFile* pf = theproject->AddFile(0, fname.GetFullPath());
-        // to all targets...
-        for (int x = 1; x < theproject->GetBuildTargetsCount(); ++x)
-        {
-            pf->AddBuildTarget(theproject->GetBuildTarget(x)->GetTitle());
-        }
+        Manager::Get()->GetProjectManager()->AddFileToProject(fname.GetFullPath(), theproject, targetIndices);
     }
+
+    theproject->EndAddFiles();
 }
 
 ////////////////////////
@@ -790,9 +822,13 @@ void Wiz::FillComboboxWithCompilers(const wxString& name)
         {
             for (size_t i = 0; i < CompilerFactory::GetCompilersCount(); ++i)
             {
-                win->Append(CompilerFactory::GetCompiler(i)->GetName());
+                Compiler* compiler = CompilerFactory::GetCompiler(i);
+                if (compiler)
+                    win->Append(compiler->GetName());
             }
-            win->SetSelection(win->FindString(CompilerFactory::GetDefaultCompiler()->GetName()));
+            Compiler* compiler = CompilerFactory::GetDefaultCompiler();
+            if (compiler)
+                win->SetSelection(win->FindString(compiler->GetName()));
         }
     }
 }
@@ -941,6 +977,71 @@ void Wiz::SetListboxSelection(const wxString& name, int sel)
     }
 }
 
+wxString Wiz::GetCheckListboxChecked(const wxString& name)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxCheckListBox* clb = dynamic_cast<wxCheckListBox*>(page->FindWindowByName(name, page));
+        if (clb)
+        {
+            wxString result;
+            unsigned int i;
+            for (i = 0; i < clb->GetCount(); ++i)
+            {
+                if (clb->IsChecked(i))
+                    result.Append(wxString::Format(_T("%u;"), i));
+            }
+            return result;
+        }
+    }
+    return wxEmptyString;
+}
+
+wxString Wiz::GetCheckListboxStringChecked(const wxString& name)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxCheckListBox* clb = dynamic_cast<wxCheckListBox*>(page->FindWindowByName(name, page));
+        if (clb)
+        {
+            wxString result;
+            unsigned int i;
+            for (i = 0; i < clb->GetCount(); ++i)
+            {
+                if (clb->IsChecked(i))
+                    result.Append(wxString::Format(_T("%s;"), clb->GetString(i).wx_str()));
+            }
+            return result;
+        }
+    }
+    return wxEmptyString;
+}
+
+bool Wiz::IsCheckListboxItemChecked(const wxString& name, unsigned int item)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxCheckListBox* clb = dynamic_cast<wxCheckListBox*>(page->FindWindowByName(name, page));
+        if (clb)
+            return clb->IsChecked(item);
+    }
+    return false;
+}
+
+void Wiz::CheckCheckListboxItem(const wxString& name, unsigned int item, bool check)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxCheckListBox* clb = dynamic_cast<wxCheckListBox*>(page->FindWindowByName(name, page));
+        if (clb)
+            clb->Check(item, check);
+    }
+}
+
 void Wiz::CheckCheckbox(const wxString& name, bool check)
 {
     wxWizardPage* page = m_pWizard->GetCurrentPage();
@@ -987,6 +1088,29 @@ wxString Wiz::GetTextControlValue(const wxString& name)
     return wxEmptyString;
 }
 
+void Wiz::SetSpinControlValue(const wxString& name, int value)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxSpinCtrl* win = dynamic_cast<wxSpinCtrl*>(page->FindWindowByName(name, page));
+        if (win)
+            win->SetValue(value);
+    }
+}
+
+int Wiz::GetSpinControlValue(const wxString& name)
+{
+    wxWizardPage* page = m_pWizard->GetCurrentPage();
+    if (page)
+    {
+        wxSpinCtrl* win = dynamic_cast<wxSpinCtrl*>(page->FindWindowByName(name, page));
+        if (win)
+            return win->GetValue();
+    }
+    return -1;
+}
+
 void Wiz::AddInfoPage(const wxString& pageId, const wxString& intro_msg)
 {
     // we don't track this; can add more than one
@@ -1110,7 +1234,7 @@ void Wiz::AddWizard(TemplateOutputType otype,
         WizardInfo& info = m_Wizards[i];
         if (info.output_type == otype && info.title == title)
         {
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Wizard already registered. Skipping... (%s)"), title.c_str()));
+            Manager::Get()->GetLogManager()->DebugLog(F(_T("Wizard already registered. Skipping... (%s)"), title.wx_str()));
             return;
         }
     }
@@ -1139,14 +1263,15 @@ void Wiz::AddWizard(TemplateOutputType otype,
     wxString typS;
     switch (otype)
     {
-        case totProject: typS = _T("Project"); break;
-        case totTarget: typS = _T("Build-target"); break;
-        case totFiles: typS = _T("File(s)"); break;
-        case totCustom: typS = _T("Custom"); break;
+        case totProject: typS = _T("Project");      break;
+        case totTarget:  typS = _T("Build-target"); break;
+        case totFiles:   typS = _T("File(s)");      break;
+        case totUser:    typS = _T("User");         break;
+        case totCustom:  typS = _T("Custom");       break;
         default: break;
     }
 
-    Manager::Get()->GetLogManager()->DebugLog(F(typS + _T(" wizard added for '%s'"), title.c_str()));
+    Manager::Get()->GetLogManager()->DebugLog(F(typS + _T(" wizard added for '%s'"), title.wx_str()));
 }
 
 wxString Wiz::GetProjectPath()
@@ -1311,7 +1436,7 @@ void Wiz::SetFilePathSelectionFilter(const wxString& filter)
         m_pWizFilePathPanel->SetFilePathSelectionFilter(filter);
 }
 
-void Wiz::SetCompilerDefault(const wxString& defCompilerID)
+void Wiz::SetCompilerDefault(cb_unused const wxString& defCompilerID)
 {
     // default compiler settings (returned if no compiler page is added in the wizard)
     m_DefCompilerID = CompilerFactory::GetDefaultCompilerID();
@@ -1363,6 +1488,8 @@ void Wiz::RegisterWizard()
             func(&Wiz::EnableWindow, "EnableWindow").
             func(&Wiz::SetTextControlValue, "SetTextControlValue").
             func(&Wiz::GetTextControlValue, "GetTextControlValue").
+            func(&Wiz::SetSpinControlValue, "SetSpinControlValue").
+            func(&Wiz::GetSpinControlValue, "GetSpinControlValue").
             func(&Wiz::CheckCheckbox, "CheckCheckbox").
             func(&Wiz::IsCheckboxChecked, "IsCheckboxChecked").
             func(&Wiz::FillComboboxWithCompilers, "FillComboboxWithCompilers").
@@ -1376,6 +1503,10 @@ void Wiz::RegisterWizard()
             func(&Wiz::GetListboxSelections, "GetListboxSelections").
             func(&Wiz::GetListboxStringSelections, "GetListboxStringSelections").
             func(&Wiz::SetListboxSelection, "SetListboxSelection").
+            func(&Wiz::GetCheckListboxChecked, "GetCheckListboxChecked").
+            func(&Wiz::GetCheckListboxStringChecked, "GetCheckListboxStringChecked").
+            func(&Wiz::IsCheckListboxItemChecked, "IsCheckListboxItemChecked").
+            func(&Wiz::CheckCheckListboxItem, "CheckCheckListboxItem").
             // get various common info
             func(&Wiz::GetWizardType, "GetWizardType").
             func(&Wiz::FindTemplateFile, "FindTemplateFile").
