@@ -6,9 +6,12 @@
 #ifndef ADDTODODLG_H
 #define ADDTODODLG_H
 
-#include <wx/dialog.h>
+#include <bitset>
+
 #include <wx/string.h>
 
+#include "scrollingdialog.h"
+
 class wxArrayString;
 class wxWindow;
 class wxCommandEvent;
@@ -22,21 +25,23 @@ enum ToDoPosition
 
 enum ToDoCommentType
 {
-    tdctCpp = 0, // C++ style,
-    tdctC,       // C style
-    tdctDoxygen, // Doxygen style
-    tdctWarning, // compiler warning
-    tdctError    // compiler error
+    tdctLine = 0,      // line comments (for example C++ style)
+    tdctStream,        // Stream comments (for example C style)
+    tdctDoxygenLine,   // Doxygen line comment
+    tdctDoxygenStream, // Doxygen stream comment
+    tdctWarning,       // compiler warning
+    tdctError          // compiler error
 };
 
-class AddTodoDlg : public wxDialog
+class AddTodoDlg : public wxScrollingDialog
 {
     public:
-        AddTodoDlg(wxWindow* parent, wxArrayString& types); // make sure the types live as long (or longer) then this dialog
+        AddTodoDlg(wxWindow* parent, wxArrayString users, wxArrayString types, std::bitset<(int)tdctError+1> supportedTdcts);
         ~AddTodoDlg();
 
         wxString GetText() const;
         wxString GetUser() const;
+        bool DateRequested() const;
         int GetPriority() const;
         ToDoPosition GetPosition() const;
         wxString GetType() const;
@@ -44,13 +49,15 @@ class AddTodoDlg : public wxDialog
 
         void EndModal(int retVal);
     private:
-        void LoadUsers() const;
-        void SaveUsers() const;
         void OnAddUser(wxCommandEvent& event);
         void OnDelUser(wxCommandEvent& event);
-        wxArrayString& m_Types;
+        void OnAddType(wxCommandEvent& event);
+        void OnDelType(wxCommandEvent& event);
+
+        wxArrayString m_Users;
+        wxArrayString m_Types;
+        std::bitset<(int)tdctError+1> m_supportedTdcts;
         DECLARE_EVENT_TABLE()
 };
 
 #endif // ADDTODODLG_H
-
