@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9294 $
+ * $Id: genericmultilinenotesdlg.cpp 9294 2013-09-03 23:02:24Z fuscated $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/genericmultilinenotesdlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -16,7 +16,7 @@
 #include "genericmultilinenotesdlg.h"
 #include <wx/textctrl.h>
 
-BEGIN_EVENT_TABLE(GenericMultiLineNotesDlg, wxDialog)
+BEGIN_EVENT_TABLE(GenericMultiLineNotesDlg, wxScrollingDialog)
     //
 END_EVENT_TABLE()
 
@@ -25,17 +25,19 @@ GenericMultiLineNotesDlg::GenericMultiLineNotesDlg(wxWindow* parent, const wxStr
     m_ReadOnly(readOnly)
 {
     //ctor
-    wxXmlResource::Get()->LoadDialog(this, parent, _T("dlgGenericMultiLineNotes"));
+    wxXmlResource::Get()->LoadObject(this, parent, _T("dlgGenericMultiLineNotes"),_T("wxScrollingDialog"));
     SetTitle(caption);
 
-    XRCCTRL(*this, "txtNotes", wxTextCtrl)->SetValue(m_Notes);
-    XRCCTRL(*this, "txtNotes", wxTextCtrl)->SetEditable(!m_ReadOnly);
+    wxTextCtrl *notesCtrl = XRCCTRL(*this, "txtNotes", wxTextCtrl);
 
+    notesCtrl->SetValue(m_Notes);
     if (m_ReadOnly)
     {
-        wxWindow* win = FindWindowById(wxID_OK, this);
-        if (win)
+        notesCtrl->SetEditable(false);
+        if (wxWindow* win = FindWindowById(wxID_CANCEL, this))
+        {
             win->Enable(false);
+        }
     }
 }
 
@@ -46,7 +48,9 @@ GenericMultiLineNotesDlg::~GenericMultiLineNotesDlg()
 
 void GenericMultiLineNotesDlg::EndModal(int retCode)
 {
-    if (retCode == wxID_OK)
+    if (retCode == wxID_OK && !m_ReadOnly)
+    {
         m_Notes = XRCCTRL(*this, "txtNotes", wxTextCtrl)->GetValue();
-    wxDialog::EndModal(retCode);
+    }
+    wxScrollingDialog::EndModal(retCode);
 }
