@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: personalitymanager.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/sdk/personalitymanager.cpp $
+ * $Revision: 9441 $
+ * $Id: personalitymanager.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/personalitymanager.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -20,7 +20,7 @@
 
 #include <wx/arrstr.h>
 
-template<> PersonalityManager* Mgr<PersonalityManager>::instance = 0;
+template<> PersonalityManager* Mgr<PersonalityManager>::instance = nullptr;
 template<> bool  Mgr<PersonalityManager>::isShutdown = false;
 
 PersonalityManager::PersonalityManager()
@@ -28,9 +28,9 @@ PersonalityManager::PersonalityManager()
     PersonalityManager::pers = _T("default");
 }
 
-void PersonalityManager::SetPersonality(const wxString& personality, bool createIfNotExist)
+void PersonalityManager::SetPersonality(const wxString& personality, cb_unused bool createIfNotExist)
 {
-	pers = personality;
+    pers = personality;
 }
 
 const wxString PersonalityManager::GetPersonality()
@@ -40,13 +40,13 @@ const wxString PersonalityManager::GetPersonality()
 
 const wxArrayString PersonalityManager::GetPersonalitiesList()
 {
-	wxArrayString list;
-	wxDir::GetAllFiles(ConfigManager::GetFolder(sdConfig), &list, _T("*.conf"), wxDIR_FILES);
+    wxArrayString list;
+    wxDir::GetAllFiles(ConfigManager::GetFolder(sdConfig), &list, _T("*.conf"), wxDIR_FILES);
 
-	for(size_t i = 0; i < list.GetCount(); ++i)
+    for(size_t i = 0; i < list.GetCount(); ++i)
         list[i] = wxFileName(list[i]).GetName();
 
-	return list;
+    return list;
 }
 
 wxString PersonalityManager::pers;
