@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: pluginmanager.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/sdk/pluginmanager.cpp $
+ * $Revision: 9441 $
+ * $Id: pluginmanager.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/pluginmanager.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -49,10 +49,10 @@
 
 #include "scripting/bindings/sc_plugin.h"
 
-template<> PluginManager* Mgr<PluginManager>::instance = 0;
+template<> PluginManager* Mgr<PluginManager>::instance = nullptr;
 template<> bool  Mgr<PluginManager>::isShutdown = false;
 
-void VersionStringToNumbers(const wxString& version, long* major, long* minor, long* release)
+inline void VersionStringToNumbers(const wxString& version, long* major, long* minor, long* release)
 {
     wxString majorS = version.BeforeFirst(_T('.')); // 6.3.2 -> 6
     wxString minorS = version.AfterFirst(_T('.')); // 6.3.2 -> 3.2
@@ -67,7 +67,7 @@ void VersionStringToNumbers(const wxString& version, long* major, long* minor, l
 }
 
 // returns -1 if new is less then old, 0 if equal and 1 if new is greater than old
-int CompareVersions(const wxString& new_version, const wxString& old_version)
+inline int CompareVersions(const wxString& new_version, const wxString& old_version)
 {
     long new_major, new_minor, new_release;
     long old_major, old_minor, old_release;
@@ -91,19 +91,19 @@ namespace LibLoader
 {
     struct RefCountedLib
     {
-        RefCountedLib() : lib(0), ref(0) {}
+        RefCountedLib() : lib(nullptr), ref(0) {}
         wxDynamicLibrary* lib;
         int ref;
     };
     typedef std::map<wxString, RefCountedLib> Libs;
     Libs s_Libs;
 
-    wxDynamicLibrary* LoadLibrary(const wxString& filename)
+    inline wxDynamicLibrary* LoadLibrary(const wxString& filename)
     {
         Libs::iterator it = s_Libs.find(filename);
         if (it != s_Libs.end())
         {
-            // existing lib
+            // existing lib./codeblocks
             it->second.ref++;
             return it->second.lib;
         }
@@ -115,7 +115,7 @@ namespace LibLoader
         return it->second.lib;
     }
 
-    void RemoveLibrary(wxDynamicLibrary* lib)
+    inline void RemoveLibrary(wxDynamicLibrary* lib)
     {
         Libs::iterator it;
         for (it = s_Libs.begin(); it != s_Libs.end(); ++it)
@@ -140,7 +140,7 @@ namespace LibLoader
         // (or had wrong refcounting)
     }
 
-    void Cleanup()
+    inline void Cleanup()
     {
         Libs::iterator it;
         for (it = s_Libs.begin(); it != s_Libs.end(); ++it)
@@ -164,8 +164,8 @@ END_EVENT_TABLE()
 
 // class constructor
 PluginManager::PluginManager()
-    : m_pCurrentlyLoadingLib(0),
-    m_pCurrentlyLoadingManifestDoc(0)
+    : m_pCurrentlyLoadingLib(nullptr),
+    m_pCurrentlyLoadingManifestDoc(nullptr)
 {
     Manager::Get()->GetAppWindow()->PushEventHandler(this);
 }
@@ -176,11 +176,11 @@ PluginManager::~PluginManager()
     UnloadAllPlugins();
 }
 
-void PluginManager::CreateMenu(wxMenuBar* menuBar)
+void PluginManager::CreateMenu(cb_unused wxMenuBar* menuBar)
 {
 }
 
-void PluginManager::ReleaseMenu(wxMenuBar* menuBar)
+void PluginManager::ReleaseMenu(cb_unused wxMenuBar* menuBar)
 {
 }
 
@@ -191,8 +191,8 @@ bool PluginManager::AttachPlugin(cbPlugin* plugin, bool ignoreSafeMode)
     if (plugin->IsAttached())
         return true;
 
-	if (!s_SafeMode || ignoreSafeMode)
-		plugin->Attach();
+    if (!s_SafeMode || ignoreSafeMode)
+        plugin->Attach();
     return true;
 }
 
@@ -767,16 +767,25 @@ bool PluginManager::ReadManifestFile(const wxString& pluginFilename,
         // actually load XML document
         m_pCurrentlyLoadingManifestDoc = new TiXmlDocument;
         if (!m_pCurrentlyLoadingManifestDoc->Parse(cbU2C(contents)))
+        {
+            Manager::Get()->GetLogManager()->LogError(_T("Plugin manifest could not be parsed: ") + actual);
             return false;
+        }
     }
 
     TiXmlElement* root = m_pCurrentlyLoadingManifestDoc->FirstChildElement("CodeBlocks_plugin_manifest_file");
     if (!root)
+    {
+        Manager::Get()->GetLogManager()->LogError(_T("Plugin resource file not valid (no root element found) for: ") + pluginFilename);
         return false;
+    }
 
     TiXmlElement* version = root->FirstChildElement("SdkVersion");
     if (!version)
+    {
+        Manager::Get()->GetLogManager()->LogError(_T("Plugin resource file not valid (no SdkVersion element found) for: ") + pluginFilename);
         return false;
+    }
 
     // check version
 //    int major;
@@ -807,7 +816,7 @@ bool PluginManager::ReadManifestFile(const wxString& pluginFilename,
 //        return false;
 //    }
 
-    // if no plugin name specified, we 're done here (succesfully)
+    // if no plugin name specified, we 're done here (successfully)
     if (pluginName.IsEmpty() || !infoOut)
         return true;
 
@@ -889,7 +898,7 @@ void PluginManager::ReadExtraFilesFromManifestFile(const wxString& pluginFilenam
     }
     else
     {
-        Manager::Get()->GetLogManager()->LogError(_T("No plugin manifest file in resource: %s") + actual);
+        Manager::Get()->GetLogManager()->LogError(_T("No plugin manifest file in resource: ") + actual);
         delete fs;
         return;
     }
@@ -919,9 +928,11 @@ void PluginManager::ReadExtraFilesFromManifestFile(const wxString& pluginFilenam
 
 int PluginManager::ScanForPlugins(const wxString& path)
 {
-    static const wxString PluginsMask = platform::windows ? _T("*.dll") : _T("*.so");
+    static const wxString PluginsMask = platform::windows                      ? _T("*.dll")
+                                      : (platform::darwin || platform::macosx) ? _T("*.dylib")
+                                      :                                          _T("*.so");
     int count = 0;
-    if(!wxDirExists(path))
+    if (!wxDirExists(path))
         return count;
     wxDir dir(path);
 
@@ -937,8 +948,10 @@ int PluginManager::ScanForPlugins(const wxString& path)
         if (!bbplugins.GetCount())
         {
             // defaults
-            if(platform::windows)
+            if      (platform::windows)
                 bbplugins.Add(_T("compiler.dll"));
+            else if (platform::darwin || platform::macosx)
+                bbplugins.Add(_T("libcompiler.dylib"));
             else
                 bbplugins.Add(_T("libcompiler.so"));
         }
@@ -970,16 +983,19 @@ int PluginManager::ScanForPlugins(const wxString& path)
         }
 
         // load manifest
-        m_pCurrentlyLoadingManifestDoc = 0;
+        m_pCurrentlyLoadingManifestDoc = nullptr;
         if (ReadManifestFile(filename))
         {
-            if (LoadPlugin(path + _T('/') + filename))
+            if (LoadPlugin(path + wxFILE_SEP_PATH + filename))
                 ++count;
             else
                 failed << _T('\n') << filename;
         }
-        delete m_pCurrentlyLoadingManifestDoc;
-        m_pCurrentlyLoadingManifestDoc = 0;
+        if (m_pCurrentlyLoadingManifestDoc)
+        {
+            delete m_pCurrentlyLoadingManifestDoc;
+            m_pCurrentlyLoadingManifestDoc = nullptr;
+        }
         ok = dir.GetNext(&filename);
     }
     Manager::Get()->GetLogManager()->Log(F(_("Loaded %d plugins"), count));
@@ -1006,9 +1022,9 @@ bool PluginManager::LoadPlugin(const wxString& pluginName)
     m_pCurrentlyLoadingLib = LibLoader::LoadLibrary(pluginName);
     if (!m_pCurrentlyLoadingLib->IsLoaded())
     {
-        Manager::Get()->GetLogManager()->LogError(F(_T("%s: not loaded (missing symbols?)"), pluginName.c_str()));
+        Manager::Get()->GetLogManager()->LogError(F(_T("%s: not loaded (missing symbols?)"), pluginName.wx_str()));
         LibLoader::RemoveLibrary(m_pCurrentlyLoadingLib);
-        m_pCurrentlyLoadingLib = 0;
+        m_pCurrentlyLoadingLib = nullptr;
         m_CurrentlyLoadingFilename.Clear();
         return false;
     }
@@ -1022,7 +1038,7 @@ bool PluginManager::LoadPlugin(const wxString& pluginName)
     for (it = m_RegisteredPlugins.begin(); it != m_RegisteredPlugins.end(); ++it)
     {
         PluginRegistration& pr = *it;
-        cbPlugin* plug = 0L;
+        cbPlugin* plug = nullptr;
         try
         {
             plug = pr.createProc();
@@ -1044,7 +1060,7 @@ bool PluginManager::LoadPlugin(const wxString& pluginName)
 
         SetupLocaleDomain(pr.name);
 
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("%s: loaded"), pr.name.c_str()));
+        Manager::Get()->GetLogManager()->DebugLog(F(_T("%s: loaded"), pr.name.wx_str()));
     }
 
     if (m_RegisteredPlugins.empty())
@@ -1052,7 +1068,7 @@ bool PluginManager::LoadPlugin(const wxString& pluginName)
         // no plugins loaded from this library, but it's not an error
         LibLoader::RemoveLibrary(m_pCurrentlyLoadingLib);
     }
-    m_pCurrentlyLoadingLib = 0;
+    m_pCurrentlyLoadingLib = nullptr;
     m_CurrentlyLoadingFilename.Clear();
     return true;
 }
@@ -1070,7 +1086,7 @@ void PluginManager::LoadAllPlugins()
             probPlugin = _T("");
     }
 
-    PluginElement* elem = 0;
+    PluginElement* elem = nullptr;
     for (unsigned int i = 0; i < m_Plugins.GetCount(); ++i)
     {
         elem = m_Plugins[i];
@@ -1169,7 +1185,7 @@ PluginElement* PluginManager::FindElementByName(const wxString& pluginName)
             return plugElem;
     }
 
-    return 0;
+    return nullptr;
 }
 
 cbPlugin* PluginManager::FindPluginByName(const wxString& pluginName)
@@ -1181,7 +1197,7 @@ cbPlugin* PluginManager::FindPluginByName(const wxString& pluginName)
             return plugElem->plugin;
     }
 
-    return 0;
+    return nullptr;
 }
 
 cbPlugin* PluginManager::FindPluginByFileName(const wxString& pluginFileName)
@@ -1193,7 +1209,7 @@ cbPlugin* PluginManager::FindPluginByFileName(const wxString& pluginFileName)
             return plugElem->plugin;
     }
 
-    return 0;
+    return nullptr;
 }
 
 const PluginInfo* PluginManager::GetPluginInfo(const wxString& pluginName)
@@ -1202,7 +1218,7 @@ const PluginInfo* PluginManager::GetPluginInfo(const wxString& pluginName)
     if (plugElem && plugElem->info.name == pluginName)
         return &plugElem->info;
 
-    return 0;
+    return nullptr;
 }
 
 const PluginInfo* PluginManager::GetPluginInfo(cbPlugin* plugin)
@@ -1214,18 +1230,18 @@ const PluginInfo* PluginManager::GetPluginInfo(cbPlugin* plugin)
             return &plugElem->info;
     }
 
-    return 0;
+    return nullptr;
 }
 
 int PluginManager::ExecutePlugin(const wxString& pluginName)
 {
     PluginElement* elem = FindElementByName(pluginName);
-    cbPlugin* plug = elem ? elem->plugin : 0;
+    cbPlugin* plug = elem ? elem->plugin : nullptr;
     if (plug)
     {
         if (plug->GetType() != ptTool)
         {
-            Manager::Get()->GetLogManager()->LogError(F(_T("Plugin %s is not a tool to have Execute() method!"), elem->info.name.c_str()));
+            Manager::Get()->GetLogManager()->LogError(F(_T("Plugin %s is not a tool to have Execute() method!"), elem->info.name.wx_str()));
         }
         else
         {
@@ -1239,27 +1255,14 @@ int PluginManager::ExecutePlugin(const wxString& pluginName)
             }
         }
     }
-    return 0;
-}
-
-int PluginManager::ConfigurePlugin(const wxString& pluginName)
-{
-    cbPlugin* plug = FindPluginByName(pluginName);
-    if (plug)
+    else
     {
-        try
-        {
-            return plug->Configure();
-        }
-        catch (cbException& exception)
-        {
-            exception.ShowErrorMessage(false);
-        }
+        Manager::Get()->GetLogManager()->LogError(F(_T("No plugin registered by this name: %s"), pluginName.wx_str()));
     }
     return 0;
 }
 
-int SortByConfigurationPriority(cbPlugin** first, cbPlugin** second)
+inline int SortByConfigurationPriority(cbPlugin** first, cbPlugin** second)
 {
     return (*first)->GetConfigurationPriority() - (*second)->GetConfigurationPriority();
 }
@@ -1335,7 +1338,7 @@ PluginsArray PluginManager::GetOffersFor(PluginType type)
 
     // special case for MIME plugins
     // we 'll add the default MIME handler, last in the returned array
-    cbPlugin* dflt = 0;
+    cbPlugin* dflt = nullptr;
 
     for (unsigned int i = 0; i < m_Plugins.GetCount(); ++i)
     {
@@ -1367,7 +1370,7 @@ void PluginManager::AskPluginsForModuleMenu(const ModuleType type, wxMenu* menu,
     for (unsigned int i = 0; i < m_Plugins.GetCount(); ++i)
     {
         cbPlugin* plug = m_Plugins[i]->plugin;
-        if (plug)
+        if (plug && plug->IsAttached())
         {
             try
             {
@@ -1409,7 +1412,7 @@ cbMimePlugin* PluginManager::GetMIMEHandlerForFile(const wxString& filename)
         if (plugin && plugin->CanHandleFile(filename))
             return plugin;
     }
-    return 0;
+    return nullptr;
 }
 
 int PluginManager::Configure()
