@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: pluginsconfigurationdlg.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/sdk/pluginsconfigurationdlg.cpp $
+ * $Revision: 9488 $
+ * $Id: pluginsconfigurationdlg.cpp 9488 2013-12-07 07:02:34Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-13.12/src/sdk/pluginsconfigurationdlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -18,6 +18,7 @@
     #include <wx/string.h>
     #include <wx/utils.h>
     #include <wx/xrc/xmlres.h>
+
     #include "manager.h"
     #include "configmanager.h"
     #include "pluginmanager.h"
@@ -25,16 +26,20 @@
 #endif
 
 #include "annoyingdialog.h"
-#include "prep.h"
-#include <wx/settings.h>
-#include <wx/filedlg.h>
 #include <wx/dirdlg.h>
-#include <wx/progdlg.h>
+#include <wx/filedlg.h>
 #include <wx/html/htmlwin.h>
+#include <wx/progdlg.h>
+#include <wx/settings.h>
+#include <wx/tooltip.h>
 
 #include "pluginsconfigurationdlg.h" // class's header file
 
-int wxCALLBACK sortByTitle(long item1, long item2, long sortData)
+#if wxCHECK_VERSION(2, 9, 1)
+inline int wxCALLBACK sortByTitle(wxIntPtr item1, wxIntPtr item2, cb_unused wxIntPtr sortData)
+#else
+inline int wxCALLBACK sortByTitle(long item1, long item2, cb_unused long sortData)
+#endif
 {
     const PluginElement* elem1 = (const PluginElement*)item1;
     const PluginElement* elem2 = (const PluginElement*)item2;
@@ -42,7 +47,7 @@ int wxCALLBACK sortByTitle(long item1, long item2, long sortData)
     return elem1->info.title.CompareTo(elem2->info.title);
 }
 
-BEGIN_EVENT_TABLE(PluginsConfigurationDlg, wxDialog)
+BEGIN_EVENT_TABLE(PluginsConfigurationDlg, wxScrollingDialog)
     EVT_BUTTON(XRCID("btnEnable"), PluginsConfigurationDlg::OnToggle)
     EVT_BUTTON(XRCID("btnDisable"), PluginsConfigurationDlg::OnToggle)
     EVT_BUTTON(XRCID("btnInstall"), PluginsConfigurationDlg::OnInstall)
@@ -51,12 +56,13 @@ BEGIN_EVENT_TABLE(PluginsConfigurationDlg, wxDialog)
     EVT_LIST_ITEM_SELECTED(XRCID("lstPlugins"), PluginsConfigurationDlg::OnSelect)
 
     EVT_UPDATE_UI(-1, PluginsConfigurationDlg::OnUpdateUI)
+    EVT_HTML_LINK_CLICKED(XRCID("htmlInfo"), PluginsConfigurationDlg::OnLinkClicked)
 END_EVENT_TABLE()
 
 // class constructor
 PluginsConfigurationDlg::PluginsConfigurationDlg(wxWindow* parent)
 {
-	wxXmlResource::Get()->LoadDialog(this, parent, _T("dlgConfigurePlugins"));
+    wxXmlResource::Get()->LoadObject(this, parent, _T("dlgConfigurePlugins"),_T("wxScrollingDialog"));
     FillList();
 
     // install options
@@ -82,11 +88,11 @@ PluginsConfigurationDlg::PluginsConfigurationDlg(wxWindow* parent)
     My tests (under linux at least) have showed that it actually
     expects real point sizes. */
 
-	wxFont systemFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-	int sizes[7] = {};
-	for (int i = 0; i < 7; ++i)
+    wxFont systemFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
+    int sizes[7] = {};
+    for (int i = 0; i < 7; ++i)
         sizes[i] = systemFont.GetPointSize();
-	XRCCTRL(*this, "htmlInfo", wxHtmlWindow)->SetFonts(wxEmptyString, wxEmptyString, &sizes[0]);
+    XRCCTRL(*this, "htmlInfo", wxHtmlWindow)->SetFonts(wxEmptyString, wxEmptyString, &sizes[0]);
 #endif
 
     wxString initialInfo;
@@ -96,20 +102,27 @@ PluginsConfigurationDlg::PluginsConfigurationDlg(wxWindow* parent)
     initialInfo << _("Have you saved your work first?");
     initialInfo << _T("</font></b><br /><i><font color=\"black\">\n");
     initialInfo << _("If a plugin is not well-written, it could cause Code::Blocks to crash ");
-    initialInfo << _T("when performing any operation on it...");
+    initialInfo << _("when performing any operation on it...");
+    initialInfo << _T("<br></font></b><br /><i><font color=\"green\">\n");
+    initialInfo << _("Some additional plugins can be found here:");
+    initialInfo << _T("</font></b><br /><i><font color=\"black\">\n");
+    initialInfo << _("<A href=\"http://wiki.codeblocks.org/index.php?title=Announcement_for_plugins/patches\">http://wiki.codeblocks.org/index.php?title=Announcement_for_plugins/patches\n </A>");
 
-	if (PluginManager::GetSafeMode())
-	{
-		initialInfo << _T("</font></i><br /><br /><b><font color=\"red\">");
-		initialInfo << _("Code::Blocks started up in \"safe-mode\"");
-		initialInfo << _T("</font></b><br /><i><font color=\"black\">\n");
-		initialInfo << _("All plugins were disabled on startup so that you can troubleshoot ");
-		initialInfo << _T("problematic plugins. Enable plugins at will now...");
-	}
+    if (PluginManager::GetSafeMode())
+    {
+        initialInfo << _T("</font></i><br /><br /><b><font color=\"red\">");
+        initialInfo << _("Code::Blocks started up in \"safe-mode\"");
+        initialInfo << _T("</font></b><br /><i><font color=\"black\">\n");
+        initialInfo << _("All plugins were disabled on startup so that you can troubleshoot ");
+        initialInfo << _("problematic plugins. Enable plugins at will now...");
+    }
 
     initialInfo << _T("</font></i><br /></body></html>\n");
 
     XRCCTRL(*this, "htmlInfo", wxHtmlWindow)->SetPage(initialInfo);
+
+    XRCCTRL(*this, "lstPlugins", wxListCtrl)->Connect(wxEVT_LEAVE_WINDOW, wxMouseEventHandler(PluginsConfigurationDlg::OnMouseMotion));
+    XRCCTRL(*this, "lstPlugins", wxListCtrl)->Connect(wxEVT_MOTION,       wxMouseEventHandler(PluginsConfigurationDlg::OnMouseMotion));
 }
 
 void PluginsConfigurationDlg::FillList()
@@ -135,8 +148,8 @@ void PluginsConfigurationDlg::FillList()
         long idx = list->InsertItem(i, elem->info.title);
         list->SetItem(idx, 1, elem->info.version);
         list->SetItem(idx, 2, elem->plugin->IsAttached() ? _("Yes") : _("No"));
-        list->SetItem(idx, 3, UnixFilename(elem->fileName));
-        list->SetItemData(idx, (long)elem);
+        list->SetItem(idx, 3, UnixFilename(elem->fileName).AfterLast(wxFILE_SEP_PATH));
+        list->SetItemData(idx, (wxIntPtr)elem);
 
         if (!elem->plugin->IsAttached())
             list->SetItemTextColour(idx, wxSystemSettings::GetColour(wxSYS_COLOUR_GRAYTEXT));
@@ -155,7 +168,8 @@ void PluginsConfigurationDlg::FillList()
 // class destructor
 PluginsConfigurationDlg::~PluginsConfigurationDlg()
 {
-	// insert your code here
+    XRCCTRL(*this, "lstPlugins", wxListCtrl)->Disconnect(wxEVT_LEAVE_WINDOW, wxMouseEventHandler(PluginsConfigurationDlg::OnMouseMotion));
+    XRCCTRL(*this, "lstPlugins", wxListCtrl)->Disconnect(wxEVT_MOTION,       wxMouseEventHandler(PluginsConfigurationDlg::OnMouseMotion));
 }
 
 void PluginsConfigurationDlg::OnToggle(wxCommandEvent& event)
@@ -218,13 +232,13 @@ void PluginsConfigurationDlg::OnToggle(wxCommandEvent& event)
     }
 }
 
-void PluginsConfigurationDlg::OnInstall(wxCommandEvent& event)
+void PluginsConfigurationDlg::OnInstall(cb_unused wxCommandEvent& event)
 {
     wxFileDialog fd(this,
                         _("Select plugin to install"),
                         wxEmptyString, wxEmptyString,
                         _T("Code::Blocks Plugins (*.cbplugin)|*.cbplugin"),
-                        wxOPEN | wxFILE_MUST_EXIST | wxMULTIPLE | compatibility::wxHideReadonly);
+                        wxFD_OPEN | wxFD_FILE_MUST_EXIST | wxFD_MULTIPLE | compatibility::wxHideReadonly);
     if (fd.ShowModal() != wxID_OK)
         return;
 
@@ -246,10 +260,10 @@ void PluginsConfigurationDlg::OnInstall(wxCommandEvent& event)
 
     FillList();
     if (!failure.IsEmpty())
-        cbMessageBox(_("One or more plugins were not installed succesfully:\n\n") + failure, _("Warning"), wxICON_WARNING);
+        cbMessageBox(_("One or more plugins were not installed successfully:\n\n") + failure, _("Warning"), wxICON_WARNING, this);
 }
 
-void PluginsConfigurationDlg::OnUninstall(wxCommandEvent& event)
+void PluginsConfigurationDlg::OnUninstall(cb_unused wxCommandEvent& event)
 {
     wxListCtrl* list = XRCCTRL(*this, "lstPlugins", wxListCtrl);
     if (list->GetSelectedItemCount() == 0)
@@ -275,10 +289,10 @@ void PluginsConfigurationDlg::OnUninstall(wxCommandEvent& event)
 
     FillList();
     if (!failure.IsEmpty())
-        cbMessageBox(_("One or more plugins were not uninstalled succesfully:\n\n") + failure, _("Warning"), wxICON_WARNING);
+        cbMessageBox(_("One or more plugins were not un-installed successfully:\n\n") + failure, _("Warning"), wxICON_WARNING, this);
 }
 
-void PluginsConfigurationDlg::OnExport(wxCommandEvent& event)
+void PluginsConfigurationDlg::OnExport(cb_unused wxCommandEvent& event)
 {
     wxListCtrl* list = XRCCTRL(*this, "lstPlugins", wxListCtrl);
     if (list->GetSelectedItemCount() == 0)
@@ -349,21 +363,20 @@ void PluginsConfigurationDlg::OnExport(wxCommandEvent& event)
 
         if (!confirmed && wxFileExists(filename))
         {
-            AnnoyingDialog dlg(_("Confirmation"),
+            AnnoyingDialog dlg(_("Overwrite confirmation"),
                                 wxString::Format(_("%s already exists.\n"
                                 "Are you sure you want to overwrite it?"), filename.c_str()),
                                 wxART_QUESTION,
                                 AnnoyingDialog::THREE_BUTTONS,
-                                1,
-                                true,
+                                AnnoyingDialog::rtONE,
                                 _("&Yes"), _("Yes to &all"), _("&No"));
             switch (dlg.ShowModal())
             {
-                case 3:
+                case AnnoyingDialog::rtTHREE:
                     continue;
                     break;
 
-                case 2:
+                case AnnoyingDialog::rtTWO:
                     confirmed = true;
                     break;
 
@@ -377,10 +390,10 @@ void PluginsConfigurationDlg::OnExport(wxCommandEvent& event)
     }
 
     if (!failure.IsEmpty())
-        cbMessageBox(_("Failed exporting one or more plugins:\n\n") + failure, _("Warning"), wxICON_WARNING);
+        cbMessageBox(_("Failed exporting one or more plugins:\n\n") + failure, _("Warning"), wxICON_WARNING, this);
 }
 
-void PluginsConfigurationDlg::OnSelect(wxListEvent& event)
+void PluginsConfigurationDlg::OnSelect(cb_unused wxListEvent& event)
 {
     wxListCtrl* list = XRCCTRL(*this, "lstPlugins", wxListCtrl);
     if (list->GetSelectedItemCount() != 1)
@@ -406,9 +419,39 @@ void PluginsConfigurationDlg::OnSelect(wxListEvent& event)
     XRCCTRL(*this, "htmlInfo", wxHtmlWindow)->SetPage(info);
 }
 
+void PluginsConfigurationDlg::OnMouseMotion(wxMouseEvent& event)
+{
+    event.Skip();
+    wxListCtrl* list = XRCCTRL(*this, "lstPlugins", wxListCtrl);
+    if (event.Leaving())
+    {
+        if (list->GetToolTip())
+            list->UnsetToolTip();
+        return;
+    }
+    int flags = 0;
+    long idx = list->HitTest(event.GetPosition(), flags);
+    wxString path;
+    if (flags & wxLIST_HITTEST_ONITEM)
+    {
+        const PluginElement* elem = (const PluginElement*)list->GetItemData(idx);
+        if (elem)
+            path = elem->fileName;
+    }
+    if (list->GetToolTip())
+    {
+        if (path.IsEmpty())
+            list->UnsetToolTip();
+        else if (path != list->GetToolTip()->GetTip())
+            list->SetToolTip(path);
+    }
+    else if (!path.IsEmpty())
+        list->SetToolTip(path);
+}
+
 void PluginsConfigurationDlg::OnUpdateUI(wxUpdateUIEvent& event)
 {
-    static bool lastSelection = -2;
+    static long lastSelection = -2;
     static bool lastSelectionMultiple = false;
     event.Skip();
 
@@ -422,7 +465,7 @@ void PluginsConfigurationDlg::OnUpdateUI(wxUpdateUIEvent& event)
     lastSelectionMultiple = list->GetSelectedItemCount() > 1;
 
     bool en = sel != -1;
-    const PluginElement* elem = en ? (const PluginElement*)list->GetItemData(sel) : 0;
+    const PluginElement* elem = en ? (const PluginElement*)list->GetItemData(sel) : nullptr;
     bool hasPlugin = elem && elem->plugin;
     bool isAttached = hasPlugin && elem->plugin->IsAttached();
 
@@ -439,5 +482,10 @@ void PluginsConfigurationDlg::EndModal(int retCode)
     cfg->Write(_T("/install_globally"), XRCCTRL(*this, "chkInstallGlobally", wxCheckBox)->GetValue());
     cfg->Write(_T("/install_confirmation"), XRCCTRL(*this, "chkInstallConfirmation", wxCheckBox)->GetValue());
 
-    wxDialog::EndModal(retCode);
+    wxScrollingDialog::EndModal(retCode);
+}
+
+void PluginsConfigurationDlg::OnLinkClicked(wxHtmlLinkEvent& event)
+{
+    wxLaunchDefaultBrowser(event.GetLinkInfo().GetHref());
 }
