@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: printing_types.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/sdk/printing_types.cpp $
+ * $Revision: 9441 $
+ * $Id: printing_types.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/printing_types.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -17,7 +17,7 @@
 
 // NOTE (Tiwag#1#): 061012 global wxPrinter, used in cbeditorprintout
 //                  to get correct settings if changed in printer dialog
-wxPrinter* g_printer = 0;
+wxPrinter* g_printer = nullptr;
 
 // TODO (Tiwag#1#): 061012 Page Setup not implemented
 // wxPageSetupData* g_pageSetupData = 0;
@@ -28,10 +28,21 @@ void InitPrinting()
     {
         g_printer = new wxPrinter;
         int paperid = Manager::Get()->GetConfigManager(_T("app"))->ReadInt(_T("/printerdialog/paperid"), wxPAPER_A4 );
+        #if wxCHECK_VERSION(2, 9, 1)
+        wxPrintOrientation paperorientation  = static_cast<wxPrintOrientation>( Manager::Get()->GetConfigManager(_T("app"))->ReadInt(_T("/printerdialog/paperorientation"), wxPORTRAIT ) );
+        #else
         int paperorientation  = Manager::Get()->GetConfigManager(_T("app"))->ReadInt(_T("/printerdialog/paperorientation"), wxPORTRAIT );
+        #endif
         wxPrintData* ppd = &(g_printer->GetPrintDialogData().GetPrintData());
         ppd->SetPaperId((wxPaperSize)paperid);
+        #if wxCHECK_VERSION(2, 9, 1)
+        if (paperorientation == wxPORTRAIT)
+            ppd->SetOrientation(wxPORTRAIT);
+        else
+            ppd->SetOrientation(wxLANDSCAPE);
+        #else
         ppd->SetOrientation(paperorientation);
+        #endif
     }
 
 //    if (!g_pageSetupData)
@@ -41,7 +52,7 @@ void InitPrinting()
 void DeInitPrinting()
 {
     delete g_printer;
-    g_printer = 0;
+    g_printer = nullptr;
 //    delete g_pageSetupData;
 //    g_pageSetupData = 0;
 }
