@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9441 $
+ * $Id: sc_progress.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/scripting/bindings/sc_progress.cpp $
  */
 
 #include <sdk_precomp.h>
@@ -25,7 +25,7 @@ class ProgressDialog : public wxProgressDialog
         ProgressDialog()
             : wxProgressDialog(_("Progress"),
                                 _("Please wait while operation is in progress..."),
-                                100, 0,
+                                100, nullptr,
                                 wxPD_AUTO_HIDE | wxPD_APP_MODAL | wxPD_CAN_ABORT)
         {
         }
@@ -39,9 +39,9 @@ class ProgressDialog : public wxProgressDialog
             cbThrow(_T("ProgressDialog copy constructor should never be called!"));
         }
 
-        bool Update(int val, const wxString& msg)
+        bool DoUpdate(int value, const wxString& newmsg)
         {
-            return wxProgressDialog::Update(val, msg, 0);
+            return wxProgressDialog::Update(value, newmsg, nullptr);
         }
 };
 
@@ -53,6 +53,6 @@ namespace ScriptBindings
     {
         SqPlus::SQClassDef<ProgressDialog>("ProgressDialog").
                 emptyCtor().
-                func(&ProgressDialog::Update, "Update");
+                func(&ProgressDialog::DoUpdate, "DoUpdate");
     }
 } // namespace ScriptBindings
