@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9441 $
+ * $Id: scriptbindings.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/scripting/bindings/scriptbindings.cpp $
  */
 
 #include <sdk_precomp.h>
@@ -106,7 +106,7 @@ namespace ScriptBindings
         int paramCount = sa.GetParamCount();
         if (paramCount == 2)
         {
-            cbEditor* ed = 0;
+            cbEditor* ed = nullptr;
             if (sa.GetType(2) == OT_INTEGER)
                 ed = Manager::Get()->GetEditorManager()->GetBuiltinEditor(sa.GetInt(2));
             else
@@ -162,7 +162,7 @@ namespace ScriptBindings
         {
             cbProject* prj = SqPlus::GetInstance<cbProject,false>(v, 1);
             if (sa.GetType(2) == OT_INTEGER)
-                return sa.Return(prj->RemoveFile(sa.GetInt(2)));
+                return sa.ThrowError("Invalid arguments to \"cbProject::RemoveFile\"");
             else
                 return sa.Return(prj->RemoveFile(SqPlus::GetInstance<ProjectFile,false>(v, 2)));
         }
@@ -179,7 +179,7 @@ namespace ScriptBindings
             bool b1 = paramCount >= 4 ? sa.GetBool(4) : true;
             bool b2 = paramCount >= 5 ? sa.GetBool(5) : true;
             int i = paramCount == 6 ? sa.GetInt(6) : 50;
-            ProjectFile* pf = 0;
+            ProjectFile* pf = nullptr;
             if (sa.GetType(2) == OT_INTEGER)
                 pf = prj->AddFile(sa.GetInt(2), str, b1, b2, i);
             else
@@ -196,7 +196,7 @@ namespace ScriptBindings
         if (paramCount == 2)
         {
             cbProject* prj = SqPlus::GetInstance<cbProject,false>(v, 1);
-            ProjectBuildTarget* bt = 0;
+            ProjectBuildTarget* bt = nullptr;
             if (sa.GetType(2) == OT_INTEGER)
                 bt = prj->GetBuildTarget(sa.GetInt(2));
             else
@@ -227,7 +227,7 @@ namespace ScriptBindings
         if (paramCount == 3)
         {
             cbProject* prj = SqPlus::GetInstance<cbProject,false>(v, 1);
-            ProjectBuildTarget* bt = 0;
+            ProjectBuildTarget* bt = nullptr;
             if (sa.GetType(2) == OT_INTEGER)
                 bt = prj->DuplicateBuildTarget(sa.GetInt(2), *SqPlus::GetInstance<wxString,false>(v, 3));
             else
@@ -281,6 +281,59 @@ namespace ScriptBindings
         }
         return sa.ThrowError("Invalid arguments to \"ProjectManager::AddFileToProject\"");
     }
+
+    SQInteger ProjectManager_GetProjectCount(HSQUIRRELVM v)
+    {
+        StackHandler sa(v);
+        int count = sa.GetParamCount();
+        if (count != 1)
+            return sa.ThrowError("Invalid arguments to \"ProjectManager::GetProjectCount\"");
+        else
+        {
+            ProjectManager *manager = SqPlus::GetInstance<ProjectManager, false>(v, 1);
+            int project_count = manager->GetProjects()->GetCount();
+            return sa.Return((SQInteger)project_count);
+        }
+    }
+
+    SQInteger ProjectManager_GetProject(HSQUIRRELVM v)
+    {
+        StackHandler sa(v);
+        int count = sa.GetParamCount();
+        if (count != 2)
+            return sa.ThrowError("Invalid arguments to \"ProjectManager::GetProject\"");
+        else
+        {
+            ProjectManager *manager = SqPlus::GetInstance<ProjectManager, false>(v, 1);
+            int index = sa.GetInt(2);
+            int project_count = manager->GetProjects()->GetCount();
+            if(index >= project_count)
+                return sa.ThrowError("Index out of bounds in \"ProjectManager::GetProject\"");
+            else
+            {
+                cbProject *project = (*manager->GetProjects())[index];
+                SqPlus::Push(v, project);
+                return 1;
+            }
+        }
+    }
+    SQInteger ProjectManager_RebuildTree(HSQUIRRELVM v)
+    {
+        StackHandler sa(v);
+        int paramCount = sa.GetParamCount();
+        if (paramCount == 1)
+        {
+            ProjectManager *manager = SqPlus::GetInstance<ProjectManager, false>(v, 1);
+            if (manager)
+            {
+                manager->GetUI().RebuildTree();
+                return sa.Return();
+            }
+            return sa.ThrowError("'this' is NULL!?! (type of ProjectManager*)");
+        }
+        return sa.ThrowError("Invalid arguments to \"ProjectManager::RebuildTree\"");
+    }
+
     SQInteger cbEditor_SetText(HSQUIRRELVM v)
     {
         StackHandler sa(v);
@@ -343,6 +396,7 @@ namespace ScriptBindings
                 func(&ProjectFile::AddBuildTarget, "AddBuildTarget").
                 func(&ProjectFile::RenameBuildTarget, "RenameBuildTarget").
                 func(&ProjectFile::RemoveBuildTarget, "RemoveBuildTarget").
+                func(&ProjectFile::GetbuildTargets, "GetbuildTargets").
                 func(&ProjectFile::GetBaseName, "GetBaseName").
                 func(&ProjectFile::GetObjName, "GetObjName").
                 func(&ProjectFile::SetObjName, "SetObjName").
@@ -357,7 +411,8 @@ namespace ScriptBindings
                 var(&ProjectFile::compile, "compile").
                 var(&ProjectFile::link, "link").
                 var(&ProjectFile::weight, "weight").
-                var(&ProjectFile::compilerVar, "compilerVar");
+                var(&ProjectFile::compilerVar, "compilerVar").
+                var(&ProjectFile::buildTargets, "buildTargets");
 
         SqPlus::SQClassDef<CompileOptionsBase>("CompileOptionsBase").
                 func(&CompileOptionsBase::AddPlatform, "AddPlatform").
@@ -458,7 +513,9 @@ namespace ScriptBindings
                 func(&ProjectBuildTarget::GetCreateStaticLib, "GetCreateStaticLib").
                 func(&ProjectBuildTarget::SetCreateStaticLib, "SetCreateStaticLib").
                 func(&ProjectBuildTarget::GetUseConsoleRunner, "GetUseConsoleRunner").
-                func(&ProjectBuildTarget::SetUseConsoleRunner, "SetUseConsoleRunner");
+                func(&ProjectBuildTarget::SetUseConsoleRunner, "SetUseConsoleRunner").
+                func(&ProjectBuildTarget::GetFilesCount, "GetFilesCount").
+                func(&ProjectBuildTarget::GetFile, "GetFile");
 
         SqPlus::SQClassDef<cbProject>("cbProject", "CompileTargetBase").
                 func(&cbProject::GetModified, "GetModified").
@@ -473,7 +530,7 @@ namespace ScriptBindings
 //                func(&cbProject::SaveAs, "SaveAs"). // *UNSAFE*
                 func(&cbProject::SaveLayout, "SaveLayout").
                 func(&cbProject::LoadLayout, "LoadLayout").
-                func(&cbProject::ShowOptions, "ShowOptions").
+//                func(&cbProject::ShowOptions, "ShowOptions").
                 func(&cbProject::GetCommonTopLevelPath, "GetCommonTopLevelPath").
                 func(&cbProject::GetFilesCount, "GetFilesCount").
                 func(&cbProject::GetFile, "GetFile").
@@ -520,6 +577,8 @@ namespace ScriptBindings
                 func(&ProjectManager::GetDefaultPath, "GetDefaultPath").
                 func(&ProjectManager::SetDefaultPath, "SetDefaultPath").
                 func(&ProjectManager::GetActiveProject, "GetActiveProject").
+                staticFuncVarArgs(&ProjectManager_GetProjectCount, "GetProjectCount", "*").
+                staticFuncVarArgs(&ProjectManager_GetProject, "GetProject", "*").
                 func(&ProjectManager::SetProject, "SetProject").
                 func(&ProjectManager::LoadWorkspace, "LoadWorkspace").
                 func(&ProjectManager::SaveWorkspace, "SaveWorkspace").
@@ -537,14 +596,14 @@ namespace ScriptBindings
                 func(&ProjectManager::CloseAllProjects, "CloseAllProjects").
                 func(&ProjectManager::NewProject, "NewProject").
                 staticFuncVarArgs(&ProjectManager_AddFileToProject, "AddFileToProject", "*").
-                func(&ProjectManager::AskForBuildTargetIndex, "AskForBuildTargetIndex").
-                func(&ProjectManager::RebuildTree, "RebuildTree").
+//                func(&ProjectManager::AskForBuildTargetIndex, "AskForBuildTargetIndex").
                 func(&ProjectManager::AddProjectDependency, "AddProjectDependency").
                 func(&ProjectManager::RemoveProjectDependency, "RemoveProjectDependency").
                 func(&ProjectManager::ClearProjectDependencies, "ClearProjectDependencies").
                 func(&ProjectManager::RemoveProjectFromAllDependencies, "RemoveProjectFromAllDependencies").
                 func(&ProjectManager::GetDependenciesForProject, "GetDependenciesForProject").
-                func(&ProjectManager::ConfigureProjectDependencies, "ConfigureProjectDependencies");
+//                func(&ProjectManager::ConfigureProjectDependencies, "ConfigureProjectDependencies");
+                staticFuncVarArgs(&ProjectManager_RebuildTree, "RebuildTree", "*");
 
         SqPlus::SQClassDef<EditorBase>("EditorBase").
                 func(&EditorBase::GetFilename, "GetFilename").
@@ -603,7 +662,6 @@ namespace ScriptBindings
                 staticFuncVarArgs(&cbEditor_GetText, "GetText", "*");
 
         SqPlus::SQClassDef<EditorManager>("EditorManager").
-                func(&EditorManager::Configure, "Configure").
                 func(&EditorManager::New, "New").
                 staticFuncVarArgs(&EditorManager_Open, "Open").
                 func(&EditorManager::IsBuiltinOpen, "IsBuiltinOpen").
@@ -620,8 +678,8 @@ namespace ScriptBindings
                 func(&EditorManager::SaveActive, "SaveActive").
                 func(&EditorManager::SaveAs, "SaveAs").
                 func(&EditorManager::SaveActiveAs, "SaveActiveAs").
-                func(&EditorManager::SaveAll, "SaveAll").
-                func(&EditorManager::ShowFindDialog, "ShowFindDialog");
+                func(&EditorManager::SaveAll, "SaveAll");
+        //        func(&EditorManager::ShowFindDialog, "ShowFindDialog");
 
         SqPlus::SQClassDef<UserVariableManager>("UserVariableManager").
                 func(&UserVariableManager::Exists, "Exists");
