@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 7443 $
+ * $Id: scriptsecuritywarningdlg.cpp 7443 2011-09-01 16:29:16Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/scriptsecuritywarningdlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -20,7 +20,7 @@
 ScriptSecurityWarningDlg::ScriptSecurityWarningDlg(wxWindow* parent, const wxString& operation, const wxString& command)
 {
     //ctor
-    wxXmlResource::Get()->LoadDialog(this, parent, _T("ScriptingSecurityDlg"));
+    wxXmlResource::Get()->LoadObject(this, parent, _T("ScriptingSecurityDlg"),_T("wxScrollingDialog"));
 
     wxColour c = wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE);
     XRCCTRL(*this, "txtCommand", wxTextCtrl)->SetBackgroundColour(c);
@@ -41,5 +41,5 @@ ScriptSecurityResponse ScriptSecurityWarningDlg::GetResponse()
 
 void ScriptSecurityWarningDlg::EndModal(int retCode)
 {
-    wxDialog::EndModal(retCode);
+    wxScrollingDialog::EndModal(retCode);
 }
