@@ -9,18 +9,49 @@
 // Author:      Robin Dunn
 //
 // Created:     13-Jan-2000
-// RCS-ID:      $Id: ScintillaWX.cpp 4043 2007-06-02 06:03:13Z rickg22 $
+// RCS-ID:      $Id: ScintillaWX.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
 // Copyright:   (c) 2000 by Total Control Software
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
 
-#include "ScintillaWX.h"
-//?#include "ExternalLexer.h"
-#include "PlatWX.h"
-#include "wx/wxscintilla.h"
+// For compilers that support precompilation, includes "wx.h".
+#include <wx/wxprec.h>
+
+#ifndef WX_PRECOMP
+    #include <wx/scrolbar.h>
+    #include <wx/menu.h>
+    #include <wx/timer.h>
+#endif // WX_PRECOMP
+
+#include <wx/clipbrd.h>
 #include <wx/textbuf.h>
+
+#include "wx/wxscintilla.h"
+#include "ScintillaWX.h"
+#include "PlatWX.h"
+#ifdef SCI_LEXER
+#include "LexerModule.h"
+#include "ExternalLexer.h"
+#endif
+
 #ifdef __WXMSW__
-#include <wx/msw/private.h> // GetHwndOf()
+    // GetHwndOf()
+    #include <wx/msw/private.h>
+#endif
+
+#if wxUSE_POPUPWIN
+#include <wx/popupwin.h>
+#define wxSCICallTipBase wxPopupWindow
+#else
+#include <wx/frame.h>
+#define wxSCICallTipBase wxFrame
+#endif
+
+#include "wx/panel.h"
+#include <wx/dcbuffer.h>
+
+#ifdef SCI_NAMESPACE
+using namespace Scintilla;
 #endif
 
 //----------------------------------------------------------------------
@@ -29,58 +60,115 @@
 class wxSCITimer : public wxTimer {
 public:
     wxSCITimer(ScintillaWX* swx) {
-        this->swx = swx;
+        m_swx = swx;
     }
 
     void Notify() {
-        swx->DoTick();
+        m_swx->DoTick();
     }
 
 private:
-    ScintillaWX* swx;
+    ScintillaWX* m_swx;
 };
 
 
 #if wxUSE_DRAG_AND_DROP
 bool wxSCIDropTarget::OnDropText(wxCoord x, wxCoord y, const wxString& data) {
-    return swx->DoDropText(x, y, data);
+    return m_swx->DoDropText(x, y, data);
 }
 
 wxDragResult  wxSCIDropTarget::OnEnter(wxCoord x, wxCoord y, wxDragResult def) {
-    return swx->DoDragEnter(x, y, def);
+    return m_swx->DoDragEnter(x, y, def);
 }
 
 wxDragResult  wxSCIDropTarget::OnDragOver(wxCoord x, wxCoord y, wxDragResult def) {
-    return swx->DoDragOver(x, y, def);
+    return m_swx->DoDragOver(x, y, def);
 }
 
 void  wxSCIDropTarget::OnLeave() {
-    swx->DoDragLeave();
+    m_swx->DoDragLeave();
 }
-#endif
+#endif // wxUSE_DRAG_AND_DROP
+
+//--------------------------------------------------------------------------
+
+/* C::B begin */
+class wxSCICallTipContent : public wxPanel {
+public:
+    wxSCICallTipContent(wxWindow* parent, CallTip* ct, ScintillaWX* swx)
+        : wxPanel(parent, -1),
+          m_ct(ct), m_swx(swx)
+    {
+        SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+    }
+
+    bool AcceptsFocus() const { return false; }
+
+    void OnPaint(wxPaintEvent& WXUNUSED(evt))
+    {
+        wxAutoBufferedPaintDC dc(this);
+/* C::B begin */
+        Surface* surfaceWindow = Surface::Allocate(SC_TECHNOLOGY_DEFAULT);
+/* C::B end */
+        surfaceWindow->Init(&dc, m_ct->wDraw.GetID());
+        m_ct->PaintCT(surfaceWindow);
+        surfaceWindow->Release();
+        delete surfaceWindow;
+    }
+
+    void OnFocus(wxFocusEvent& event)
+    {
+        GetGrandParent()->SetFocus();
+        event.Skip();
+    }
+
+    void OnLeftDown(wxMouseEvent& event)
+    {
+        wxPoint pt = event.GetPosition();
+        Point p(pt.x, pt.y);
+        m_ct->MouseClick(p);
+        m_swx->CallTipClick();
+    }
+
+private:
+    CallTip*     m_ct;
+    ScintillaWX* m_swx;
+    DECLARE_EVENT_TABLE()
+};
 
 
-#if wxUSE_POPUPWIN && wxSCI_USE_POPUP
-#include <wx/popupwin.h>
-#define wxSCICallTipBase wxPopupWindow
-#define param2  wxBORDER_NONE  // popup's 2nd param is flags
-#else
-#define wxSCICallTipBase wxWindow
-#define param2 -1 // wxWindow's 2nd param is ID
-#endif
+BEGIN_EVENT_TABLE(wxSCICallTipContent, wxPanel)
+    EVT_PAINT(wxSCICallTipContent::OnPaint)
+    EVT_SET_FOCUS(wxSCICallTipContent::OnFocus)
+    EVT_LEFT_DOWN(wxSCICallTipContent::OnLeftDown)
+END_EVENT_TABLE()
+/* C::B end */
+
 
-#include <wx/dcbuffer.h>
 
 class wxSCICallTip : public wxSCICallTipBase {
 public:
-    wxSCICallTip(wxWindow* parent, CallTip* ct, ScintillaWX* swx)
-        : wxSCICallTipBase(parent, param2),
-          m_ct(ct), m_swx(swx), m_cx(-1), m_cy(-1)
+    wxSCICallTip(wxWindow* parent, CallTip* ct, ScintillaWX* swx) :
+#if wxUSE_POPUPWIN
+        wxSCICallTipBase(parent, wxBORDER_NONE),
+#else
+        wxSCICallTipBase(parent, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+                         wxFRAME_NO_TASKBAR
+                         | wxFRAME_FLOAT_ON_PARENT
+                         | wxBORDER_NONE
+#ifdef __WXMAC__
+                         | wxPOPUP_WINDOW
+#endif
+            ),
+#endif
+        m_cx(wxDefaultCoord), m_cy(wxDefaultCoord)
         {
+            SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+            m_content = new wxSCICallTipContent(this, ct, swx);
         }
 
     ~wxSCICallTip() {
-#if wxUSE_POPUPWIN && wxSCI_USE_POPUP && defined(__WXGTK__)
+#if wxUSE_POPUPWIN && defined(__WXGTK__)
         wxRect rect = GetRect();
         rect.x = m_cx;
         rect.y = m_cy;
@@ -90,59 +178,55 @@ public:
 
     bool AcceptsFocus() const { return false; }
 
-    void OnPaint(wxPaintEvent& WXUNUSED(evt)) {
-        wxBufferedPaintDC dc(this);
-        Surface* surfaceWindow = Surface::Allocate();
-        surfaceWindow->Init(&dc, m_ct->wDraw.GetID());
-        m_ct->PaintCT(surfaceWindow);
-        surfaceWindow->Release();
-        delete surfaceWindow;
-    }
-
-    void OnFocus(wxFocusEvent& event) {
-        GetParent()->SetFocus();
-        event.Skip();
-    }
-
-    void OnLeftDown(wxMouseEvent& event) {
-        wxPoint pt = event.GetPosition();
-        Point p(pt.x, pt.y);
-        m_ct->MouseClick(p);
-        m_swx->CallTipClick();
-    }
-
-#if wxUSE_POPUPWIN && wxSCI_USE_POPUP
     virtual void DoSetSize(int x, int y,
                            int width, int height,
-                           int sizeFlags = wxSIZE_AUTO) {
-        if (x != -1) {
+                           int sizeFlags = wxSIZE_AUTO)
+    {
+        // convert coords to screen coords since we're a top-level window
+        if (x != wxDefaultCoord) {
             m_cx = x;
             GetParent()->ClientToScreen(&x, NULL);
         }
-        if (y != -1) {
+        if (y != wxDefaultCoord) {
             m_cy = y;
             GetParent()->ClientToScreen(NULL, &y);
         }
         wxSCICallTipBase::DoSetSize(x, y, width, height, sizeFlags);
+/* C::B begin */
+        m_content->SetSize(0, 0, width, height, sizeFlags);
+/* C::B end */
+    }
+
+#if wxUSE_POPUPWIN
+#else
+    virtual bool Show( bool show = true )
+    {
+        // Although we're a frame, we always want the parent to be active, so
+        // raise it whenever we get shown.
+        bool rv = wxSCICallTipBase::Show(show);
+        if (rv && show)
+        {
+            wxTopLevelWindow *frame = wxDynamicCast(
+                wxGetTopLevelParent(GetParent()), wxTopLevelWindow);
+            if (frame)
+                frame->Raise();
+        }
+        return rv;
     }
 #endif
 
-    wxPoint GetMyPosition() {
+    wxPoint GetMyPosition()
+    {
         return wxPoint(m_cx, m_cy);
     }
 
 private:
-    CallTip*      m_ct;
-    ScintillaWX*  m_swx;
     int           m_cx, m_cy;
-    DECLARE_EVENT_TABLE()
+/* C::B begin */
+    wxSCICallTipContent* m_content;
+/* C::B end */
 };
 
-BEGIN_EVENT_TABLE(wxSCICallTip, wxSCICallTipBase)
-    EVT_PAINT(wxSCICallTip::OnPaint)
-    EVT_SET_FOCUS(wxSCICallTip::OnFocus)
-    EVT_LEFT_DOWN(wxSCICallTip::OnLeftDown)
-END_EVENT_TABLE()
 
 
 //----------------------------------------------------------------------
@@ -173,6 +257,37 @@ static wxTextFileType wxConvertEOLMode(int scintillaMode)
 }
 #endif // wxUSE_DATAOBJ
 
+
+/* C::B begin */
+static int wxCountLines(const char* text, int scintillaMode)
+{
+    char eolchar;
+
+    switch (scintillaMode) {
+        case wxSCI_EOL_CRLF:
+        case wxSCI_EOL_LF:
+            eolchar = '\n';
+            break;
+        case wxSCI_EOL_CR:
+            eolchar = '\r';
+            break;
+        default:
+            return 0;
+    }
+
+    int count = 0;
+    int i     = 0;
+    while (text[i] != 0) {
+        if (text[i] == eolchar) {
+            count++;
+        }
+        i++;
+    }
+
+    return count;
+}
+/* C::B end */
+
 //----------------------------------------------------------------------
 // Constructor/Destructor
 
@@ -182,15 +297,14 @@ ScintillaWX::ScintillaWX(wxScintilla* win) {
     focusEvent = false;
     wMain = win;
     sci   = win;
-    wheelRotation = 0;
+    wheelVRotation = 0;
+    wheelHRotation = 0;
     Initialise();
 #ifdef __WXMSW__
-#if wxCHECK_VERSION(2, 5, 0)
     sysCaretBitmap = 0;
     sysCaretWidth = 0;
     sysCaretHeight = 0;
 #endif
-#endif
 }
 
 
@@ -208,12 +322,11 @@ void ScintillaWX::Initialise() {
     dropTarget = new wxSCIDropTarget;
     dropTarget->SetScintilla(this);
     sci->SetDropTarget(dropTarget);
-#endif
-#ifdef __WXMAC__
-    vs.extraFontFlag = false;  // UseAntiAliasing
-#else
+/* C::B begin */
+    dragRectangle = false;
+/* C::B end */
+#endif // wxUSE_DRAG_AND_DROP
     vs.extraFontFlag = true;   // UseAntiAliasing
-#endif
 }
 
 
@@ -227,32 +340,45 @@ void ScintillaWX::Finalise() {
 
 void ScintillaWX::StartDrag() {
 #if wxUSE_DRAG_AND_DROP
-    wxString dragText = sci2wx(drag.s, drag.len);
+    wxString dragText = sci2wx (drag.Data(), drag.Length());
 
     // Send an event to allow the drag text to be changed
     wxScintillaEvent evt(wxEVT_SCI_START_DRAG, sci->GetId());
-    evt.SetEventObject(sci);
+    evt.SetEventObject (sci);
     evt.SetDragText(dragText);
-    evt.SetDragAllowMove(true);
-    evt.SetPosition(wxMin(sci->GetSelectionStart(),
-                          sci->GetSelectionEnd()));
-    sci->GetEventHandler()->ProcessEvent(evt);
-    dragText = evt.GetDragText();
+    evt.SetDragFlags(wxDrag_DefaultMove);
+    evt.SetPosition (wxMin(sci->GetSelectionStart(),
+	                       sci->GetSelectionEnd()));
+    sci->GetEventHandler()->ProcessEvent (evt);
 
-    if (dragText.Length()) {
+/* C::B begin */
+    UndoGroup ug(pdoc);
+/* C::B end */
+
+    dragText = evt.GetDragText();
+/* C::B begin */
+    dragRectangle = drag.rectangular;
+/* C::B end */
+    if ( !dragText.empty() ) {
         wxDropSource        source(sci);
         wxTextDataObject    data(dragText);
         wxDragResult        result;
 
         source.SetData(data);
         dropWentOutside = true;
-        result = source.DoDragDrop(evt.GetDragAllowMove());
+        inDragDrop = ddDragging;
+        result = source.DoDragDrop(evt.GetDragFlags());
         if (result == wxDragMove && dropWentOutside)
             ClearSelection();
-        inDragDrop = false;
-        SetDragPosition(invalidPosition);
+        inDragDrop = ddNone;
+        SetDragPosition(SelectionPosition(invalidPosition));
+/* C::B begin */
+        wxScintillaEvent evtFin(wxEVT_SCI_FINISHED_DRAG, sci->GetId());
+        evtFin.SetEventObject(sci);
+        sci->GetEventHandler()->ProcessEvent(evtFin);
+/* C::B end */
     }
-#endif
+#endif // wxUSE_DRAG_AND_DROP
 }
 
 
@@ -260,11 +386,9 @@ bool ScintillaWX::SetIdle(bool on) {
     if (idler.state != on) {
         // connect or disconnect the EVT_IDLE handler
         if (on)
-            sci->Connect(wxID_ANY, wxEVT_IDLE,
-                         (wxObjectEventFunction) (wxEventFunction) (wxIdleEventFunction) &wxScintilla::OnIdle);
+            sci->Connect(wxID_ANY, wxEVT_IDLE, wxIdleEventHandler(wxScintilla::OnIdle));
         else
-            sci->Disconnect(wxID_ANY, wxEVT_IDLE,
-                            (wxObjectEventFunction) (wxEventFunction) (wxIdleEventFunction) &wxScintilla::OnIdle);
+            sci->Disconnect(wxID_ANY, wxEVT_IDLE, wxIdleEventHandler(wxScintilla::OnIdle));
         idler.state = on;
     }
     return idler.state;
@@ -272,17 +396,17 @@ bool ScintillaWX::SetIdle(bool on) {
 
 
 void ScintillaWX::SetTicking(bool on) {
-    wxSCITimer* stiTimer;
+    wxSCITimer* sciTimer;
     if (timer.ticking != on) {
         timer.ticking = on;
         if (timer.ticking) {
-            stiTimer = new wxSCITimer(this);
-            stiTimer->Start(timer.tickSize);
-            timer.tickerID = stiTimer;
+            sciTimer = new wxSCITimer(this);
+            sciTimer->Start(timer.tickSize);
+            timer.tickerID = sciTimer;
         } else {
-            stiTimer = (wxSCITimer*)timer.tickerID;
-            stiTimer->Stop();
-            delete stiTimer;
+            sciTimer = (wxSCITimer*)timer.tickerID;
+            sciTimer->Stop();
+            delete sciTimer;
             timer.tickerID = 0;
         }
     }
@@ -309,7 +433,6 @@ bool ScintillaWX::HaveMouseCapture() {
 void ScintillaWX::ScrollText(int linesToMove) {
     int dy = vs.lineHeight * (linesToMove);
     sci->ScrollWindow(0, dy);
-    sci->Update();
 }
 
 void ScintillaWX::SetVerticalScrollPos() {
@@ -366,7 +489,7 @@ bool ScintillaWX::ModifyScrollBars(int nMax, int nPage) {
     int horizEnd = scrollWidth;
     if (horizEnd < 0)
         horizEnd = 0;
-    if (!horizontalScrollBarVisible || (wrapState != eWrapNone))
+    if (!horizontalScrollBarVisible || Wrapping())
         horizEnd = 0;
     int pageWidth = rcText.Width();
 
@@ -398,6 +521,11 @@ bool ScintillaWX::ModifyScrollBars(int nMax, int nPage) {
     return modified;
 }
 
+/* C::B begin */
+void ScintillaWX::NotifyFocus(bool focus) {
+    sci->NotifyFocus(focus);
+}
+/* C::B end */
 
 void ScintillaWX::NotifyChange() {
     sci->NotifyChange();
@@ -423,38 +551,94 @@ void ScintillaWX::CancelModes() {
 
 
 void ScintillaWX::Copy() {
-    if (currentPos != anchor) {
+/* C::B begin */
+    if (!SelectionEmpty()) {
+/* C::B end */
         SelectionText st;
         CopySelectionRange(&st);
-        CopyToClipboard(st);
+/* C::B begin */
+#ifdef __WXGTK__
+		for (int i=0; i<5; i++)
+        	CopyToClipboard(st);
+#else
+     	CopyToClipboard(st);
+#endif
+/* C::B end */
     }
 }
 
 
 void ScintillaWX::Paste() {
-    pdoc->BeginUndoAction();
+/* C::B begin */
+    UndoGroup ug(pdoc);
+	// Selection::First
+    SelectionPosition firstPosition = SelectionStart();
+    if (sel.IsRectangular() && !sel.Empty()) {
+        for (size_t i=0; i<sel.Count()-1; i++) {
+            sel.RotateMain();
+            if (firstPosition > SelectionStart())
+                firstPosition = SelectionStart();
+        }
+    }
+/* C::B end */
     ClearSelection();
 
 #if wxUSE_DATAOBJ
     wxTextDataObject data;
-    bool gotData = false;
+/* C::B begin */
+    wxString textString;
 
+    bool  rectangular = false;
+
+    wxTheClipboard->UsePrimarySelection(false);
     if (wxTheClipboard->Open()) {
-        wxTheClipboard->UsePrimarySelection(false);
-        gotData = wxTheClipboard->GetData(data);
-        wxTheClipboard->Close();
+        // Leave the following lines that way to enable compilation with GCC 3.3.3
+        wxDataFormat dataFormat(wxString(wxT("application/x-cbrectdata")));
+        wxCustomDataObject selData(dataFormat);
+        bool gotRectData = wxTheClipboard->GetData(selData);
+
+        if (gotRectData && selData.GetSize()>1) {
+            wxTheClipboard->Close();
+            const char* rectBuf = (const char*)selData.GetData();
+            rectangular = rectBuf[0] == (char)1;
+            int len = selData.GetDataSize()-1;
+            char* buffer = new char[len];
+            memcpy (buffer, rectBuf+1, len);
+            textString = sci2wx(buffer, len);
+            delete [] buffer;
+        } else {
+            bool gotData = wxTheClipboard->GetData(data);
+            wxTheClipboard->Close();
+            if (gotData) {
+                textString = wxTextBuffer::Translate(data.GetText(),
+                                                     wxConvertEOLMode(pdoc->eolMode));
+            }
+        }
     }
-    if (gotData) {
-        wxString   text = wxTextBuffer::Translate(data.GetText(),
-                                                  wxConvertEOLMode(pdoc->eolMode));
-        wxWX2MBbuf buf = (wxWX2MBbuf)wx2sci(text);
-        int        len = strlen(buf);
-        pdoc->InsertString(currentPos, buf, len);
-        SetEmptySelection(currentPos + len);
+
+    wxWX2MBbuf buf = (wxWX2MBbuf)wx2sci(textString);
+#if wxUSE_UNICODE
+    // free up the old character buffer in case the text is real big
+    data.SetText(wxEmptyString);
+    textString = wxEmptyString;
+#endif
+    int len  = strlen(buf);
+    int newPos = 0;
+    int caretMain = CurrentPosition();
+    if (rectangular) {
+        SelectionPosition selStart = sel.Range(sel.Main()).Start();
+        int newLine = pdoc->LineFromPosition (caretMain) + wxCountLines (buf, pdoc->eolMode);
+        int newCol = pdoc->GetColumn(caretMain);
+        PasteRectangular (selStart, buf, len);
+        newPos = pdoc->FindColumn (newLine, newCol);
+    } else {
+        pdoc->InsertString (caretMain, buf, len);
+        newPos = caretMain + len;
     }
+    SetEmptySelection (newPos);
+/* C::B end */
 #endif // wxUSE_DATAOBJ
 
-    pdoc->EndUndoAction();
     NotifyChange();
     Redraw();
 }
@@ -462,10 +646,30 @@ void ScintillaWX::Paste() {
 
 void ScintillaWX::CopyToClipboard(const SelectionText& st) {
 #if wxUSE_CLIPBOARD
+    if ( !st.Length() )
+        return;
+
+    wxTheClipboard->UsePrimarySelection(false);
     if (wxTheClipboard->Open()) {
-        wxTheClipboard->UsePrimarySelection(false);
-        wxString text = wxTextBuffer::Translate(sci2wx(st.s, st.len-1));
-        wxTheClipboard->SetData(new wxTextDataObject(text));
+        wxString text = wxTextBuffer::Translate(sci2wx(st.Data(), st.Length()));
+
+/* C::B begin */
+        // composite object will hold "plain text" for pasting in other programs and a custom
+        // object for local use that remembers what kind of selection was made (stream or
+        // rectangular).
+        wxDataObjectComposite* obj = new wxDataObjectComposite();
+        wxCustomDataObject* rectData = new wxCustomDataObject (wxDataFormat(wxString(wxT("application/x-cbrectdata"))));
+
+        char* buffer = new char[st.LengthWithTerminator()];
+        buffer[0] = (st.rectangular)? (char)1 : (char)0;
+        memcpy (buffer+1, st.Data(), st.Length());
+        rectData->SetData (st.LengthWithTerminator(), buffer);
+        delete [] buffer;
+
+        obj->Add (rectData, true);
+        obj->Add (new wxTextDataObject (text));
+        wxTheClipboard->SetData (obj);
+/* C::B end */
         wxTheClipboard->Close();
     }
 #else
@@ -480,12 +684,12 @@ bool ScintillaWX::CanPaste() {
     bool didOpen;
 
     if (Editor::CanPaste()) {
+        wxTheClipboard->UsePrimarySelection(false);
         didOpen = !wxTheClipboard->IsOpened();
         if ( didOpen )
             wxTheClipboard->Open();
 
         if (wxTheClipboard->IsOpened()) {
-            wxTheClipboard->UsePrimarySelection(false);
             canPaste = wxTheClipboard->IsSupported(wxUSE_UNICODE ? wxDF_UNICODETEXT : wxDF_TEXT);
             if (didOpen)
                 wxTheClipboard->Close();
@@ -516,25 +720,25 @@ void ScintillaWX::AddToPopUp(const char *label, int cmd, bool enabled) {
 }
 
 
-// This is called by the Editor base class whenever something is selected
+// This is called by the Editor base class whenever something is selected.
+// For wxGTK we can put this text in the primary selection and then other apps
+// can paste with the middle button.
 void ScintillaWX::ClaimSelection() {
 #if 0
-    // Until wxGTK is able to support using both the primary selection and the
-    // clipboard at the same time I think it causes more problems than it is
-    // worth to implement this method.  Selecting text should not clear the
-    // clipboard.  --Robin
 #ifdef __WXGTK__
     // Put the selected text in the PRIMARY selection
-    if (currentPos != anchor) {
+/* C::B begin */
+    if (!SelectionEmpty()) {
+/* C::B end */
         SelectionText st;
         CopySelectionRange(&st);
+        wxTheClipboard->UsePrimarySelection(true);
         if (wxTheClipboard->Open()) {
-            wxTheClipboard->UsePrimarySelection(true);
             wxString text = sci2wx(st.s, st.len);
             wxTheClipboard->SetData(new wxTextDataObject(text));
-            wxTheClipboard->UsePrimarySelection(false);
             wxTheClipboard->Close();
         }
+        wxTheClipboard->UsePrimarySelection(false);
     }
 #endif
 #endif
@@ -548,10 +752,8 @@ void ScintillaWX::UpdateSystemCaret() {
             DestroySystemCaret();
             CreateSystemCaret();
         }
-        Point pos = LocationFromPosition(currentPos);
-#if wxCHECK_VERSION(2, 5, 0)
+        Point pos = PointMainCaret();
         ::SetCaretPos(pos.x, pos.y);
-#endif
     }
 #endif
 }
@@ -559,23 +761,18 @@ void ScintillaWX::UpdateSystemCaret() {
 
 bool ScintillaWX::HasCaretSizeChanged() {
 #ifdef __WXMSW__
-#if !wxCHECK_VERSION(2, 5, 0)
-    return false;
-#else
-    if (( (0 != vs.caretWidth) && (sysCaretWidth != vs.caretWidth) )
-        || (0 != vs.lineHeight) && (sysCaretHeight != vs.lineHeight)) {
+/* C::B begin */
+    if (    ( (0 != vs.caretWidth) && (sysCaretWidth  != vs.caretWidth) )
+         || ( (0 != vs.lineHeight) && (sysCaretHeight != vs.lineHeight) ) ) {
+/* C::B end */
         return true;
     }
-#endif
 #endif
     return false;
 }
 
 bool ScintillaWX::CreateSystemCaret() {
 #ifdef __WXMSW__
-#if !wxCHECK_VERSION(2, 5, 0)
-    return false;
-#else
     sysCaretWidth = vs.caretWidth;
     if (0 == sysCaretWidth) {
         sysCaretWidth = 1;
@@ -591,7 +788,6 @@ bool ScintillaWX::CreateSystemCaret() {
                                 sysCaretWidth, sysCaretHeight);
     ::ShowCaret(GetHwndOf(sci));
     return retval != 0;
-#endif
 #else
     return false;
 #endif
@@ -599,9 +795,6 @@ bool ScintillaWX::CreateSystemCaret() {
 
 bool ScintillaWX::DestroySystemCaret() {
 #ifdef __WXMSW__
-#if !wxCHECK_VERSION(2, 5, 0)
-    return false;
-#else
     ::HideCaret(GetHwndOf(sci));
     BOOL retval = ::DestroyCaret();
     if (sysCaretBitmap) {
@@ -609,7 +802,6 @@ bool ScintillaWX::DestroySystemCaret() {
         sysCaretBitmap = 0;
     }
     return retval != 0;
-#endif
 #else
     return false;
 #endif
@@ -618,11 +810,12 @@ bool ScintillaWX::DestroySystemCaret() {
 
 //----------------------------------------------------------------------
 
-long ScintillaWX::DefWndProc(unsigned int /*iMessage*/, unsigned long /*wParam*/, long /*lParam*/) {
+
+sptr_t ScintillaWX::DefWndProc(unsigned int /*iMessage*/, uptr_t /*wParam*/, sptr_t /*lParam*/) {
     return 0;
 }
 
-long ScintillaWX::WndProc(unsigned int iMessage, unsigned long wParam, long lParam) {
+sptr_t ScintillaWX::WndProc(unsigned int iMessage, uptr_t wParam, sptr_t lParam) {
       switch (iMessage) {
       case SCI_CALLTIPSHOW: {
           // NOTE: This is copied here from scintilla/src/ScintillaBase.cxx
@@ -632,13 +825,28 @@ long ScintillaWX::WndProc(unsigned int iMessage, unsigned long wParam, long lPar
           Point pt = LocationFromPosition(wParam);
           char* defn = reinterpret_cast<char *>(lParam);
           AutoCompleteCancel();
-          pt.y += vs.lineHeight;
-          PRectangle rc = ct.CallTipStart(currentPos, pt,
+/* C::B begin */
+          //pt.y += vs.lineHeight;
+/* C::B end */
+/* C::B begin */
+          /* This fix will allow you to actually modify the calltip font (it
+           * was hardcoded to STYLE_DEFAULT instead of allowing user to
+           * override it when STYLE_CALLTIP is set). */
+          int ctStyle = ct.UseStyleCallTip() ? STYLE_CALLTIP : STYLE_DEFAULT;
+          if (ct.UseStyleCallTip())
+          {
+              ct.SetForeBack(vs.styles[STYLE_CALLTIP].fore, vs.styles[STYLE_CALLTIP].back);
+          }
+/* C::B end */
+          int caretMain = sel.MainCaret();
+          PRectangle rc = ct.CallTipStart(caretMain, pt,
+                                          vs.lineHeight,
                                           defn,
-                                          vs.styles[STYLE_DEFAULT].fontName,
-                                          vs.styles[STYLE_DEFAULT].sizeZoomed,
+                                          vs.styles[ctStyle].fontName,
+                                          vs.styles[ctStyle].sizeZoomed,
                                           CodePage(),
-                                          vs.styles[STYLE_DEFAULT].characterSet,
+                                          vs.styles[ctStyle].characterSet,
+                                          vs.technology,
                                           wMain);
           // If the call-tip window would be out of the client
           // space, adjust so it displays above the text.
@@ -652,24 +860,52 @@ long ScintillaWX::WndProc(unsigned int iMessage, unsigned long wParam, long lPar
               rc.top -= offset;
               rc.bottom -= offset;
           }
+/* C::B begin */
+          // If the call-tip window would be out of the client space to
+          // the right, adjust it so right egde is at the right edge of
+          // the client.
+          if (rc.right > rcClient.right) {
+              rc.left -= rc.right - rcClient.right;
+              rc.right = rcClient.right;
+          }
+/* C::B end */
           // Now display the window.
           CreateCallTipWindow(rc);
           ct.wCallTip.SetPositionRelative(rc, wMain);
           ct.wCallTip.Show();
           break;
       }
-/*? TODO
+
+/* C::B begin */
+      case SCI_GETDIRECTFUNCTION:
+            return reinterpret_cast<sptr_t>(DirectFunction);
+
+      case SCI_GETDIRECTPOINTER:
+            return reinterpret_cast<sptr_t>(this);
+
+      case SCI_GRABFOCUS:
+            sci->SetFocus();
+            break;
+/* C::B end */
+
 #ifdef SCI_LEXER
       case SCI_LOADLEXERLIBRARY:
             LexerManager::GetInstance()->Load((const char*)lParam);
             break;
-#endif ?*/
+#endif
+
       default:
           return ScintillaBase::WndProc(iMessage, wParam, lParam);
       }
       return 0;
 }
 
+/* C::B begin */
+sptr_t ScintillaWX::DirectFunction(ScintillaWX *wxsci, unsigned int iMessage, uptr_t wParam, sptr_t lParam)
+{
+	return wxsci->WndProc(iMessage, wParam, lParam);
+}
+/* C::B end */
 
 
 //----------------------------------------------------------------------
@@ -678,27 +914,55 @@ long ScintillaWX::WndProc(unsigned int iMessage, unsigned long wParam, long lPar
 void ScintillaWX::DoPaint(wxDC* dc, wxRect rect) {
 
     paintState = painting;
-    Surface* surfaceWindow = Surface::Allocate();
-    surfaceWindow->Init(dc, wMain.GetID());
-    rcPaint = PRectangleFromwxRect(rect);
-    PRectangle rcClient = GetClientRectangle();
-    paintingAllText = rcPaint.Contains(rcClient);
+    AutoSurface surfaceWindow(dc, this);
+    if (surfaceWindow) {
+        rcPaint = PRectangleFromwxRect(rect);
+        PRectangle rcClient = GetClientRectangle();
+        paintingAllText = rcPaint.Contains(rcClient);
 
-//    dc->BeginDrawing(); // Deprecated - it's an empty function anyway
-    ClipChildren(*dc, rcPaint);
-    Paint(surfaceWindow, rcPaint);
+        ClipChildren(*dc, rcPaint);
+        Paint(surfaceWindow, rcPaint);
+        surfaceWindow->Release();
+    }
 
-    delete surfaceWindow;
     if (paintState == paintAbandoned) {
         // Painting area was insufficient to cover new styling or brace
-        // highlight positions
-        FullPaint();
+        // highlight positions.  So trigger a new paint event that will
+        // repaint the whole window.
+        sci->Refresh(false);
+
+#if defined(__WXOSX__)
+        // On Mac we also need to finish the current paint to make sure that
+        // everything is on the screen that needs to be there between now and
+        // when the next paint event arrives.
+        FullPaintDC(dc);
+#endif
     }
     paintState = notPainting;
-//    dc->EndDrawing(); // Deprecated - it's an empty function anyway
 }
 
 
+// Force the whole window to be repainted
+void ScintillaWX::FullPaint() {
+    sci->Refresh(false);
+    sci->Update();
+}
+
+
+void ScintillaWX::FullPaintDC(wxDC* dc) {
+    paintState = painting;
+    rcPaint = GetClientRectangle();
+    paintingAllText = true;
+    AutoSurface surfaceWindow(dc, this);
+    if (surfaceWindow) {
+        Paint(surfaceWindow, rcPaint);
+        surfaceWindow->Release();
+    }
+    paintState = notPainting;
+}
+
+
+
 void ScintillaWX::DoHScroll(int type, int pos) {
     int xPos = xOffset;
     PRectangle rcText = GetTextRectangle();
@@ -745,14 +1009,31 @@ void ScintillaWX::DoVScroll(int type, int pos) {
     ScrollTo(topLineNew);
 }
 
-void ScintillaWX::DoMouseWheel(int rotation, int delta,
-                               int linesPerAction, int ctrlDown,
-                               bool isPageScroll ) {
+void ScintillaWX::DoMouseWheel(wxMouseWheelAxis axis, int rotation, int delta,
+                               int linesPerAction, int columnsPerAction,
+                               bool ctrlDown, bool isPageScroll) {
     int topLineNew = topLine;
     int lines;
+    int xPos = xOffset;
+    int pixels;
 
-    if (ctrlDown) {  // Zoom the fonts if Ctrl key down
+    if (axis == wxMOUSE_WHEEL_HORIZONTAL) {
+        wheelHRotation += rotation * (columnsPerAction * vs.spaceWidth);
+        pixels = wheelHRotation / delta;
+        wheelHRotation -= pixels * delta;
+        if (pixels != 0) {
+            xPos += pixels;
+            PRectangle rcText = GetTextRectangle();
+            if (xPos > scrollWidth - rcText.Width()) {
+                xPos = scrollWidth - rcText.Width();
+            }
+            HorizontalScrollTo(xPos);
+        }
+    }
+    else if (ctrlDown) {  // Zoom the fonts if Ctrl key down
+/* C::B begin */
         if (rotation < 0) {
+/* C::B end */
             KeyCommand(SCI_ZOOMIN);
         }
         else {
@@ -762,9 +1043,9 @@ void ScintillaWX::DoMouseWheel(int rotation, int delta,
     else { // otherwise just scroll the window
         if ( !delta )
             delta = 120;
-        wheelRotation += rotation;
-        lines = wheelRotation / delta;
-        wheelRotation -= lines * delta;
+        wheelVRotation += rotation;
+        lines = wheelVRotation / delta;
+        wheelVRotation -= lines * delta;
         if (lines != 0) {
             if (isPageScroll)
                 lines = lines * LinesOnScreen();  // lines is either +1 or -1
@@ -785,6 +1066,9 @@ void ScintillaWX::DoLoseFocus(){
     focusEvent = true;
     SetFocusState(false);
     focusEvent = false;
+/* C::B begin */
+    SetMouseCapture(false);
+/* C::B end */
     DestroySystemCaret();
 }
 
@@ -812,31 +1096,36 @@ void ScintillaWX::DoLeftButtonMove(Point pt) {
     ButtonMove(pt);
 }
 
-#ifdef __WXGTK__
+/* C::B begin */
+//#ifdef __WXGTK__
+#if 0 // emulated in cbStyledTextCtrl::OnMouseMiddleClick() due to buggy wxClipboard
+/* C::B end */
 void ScintillaWX::DoMiddleButtonUp(Point pt) {
     // Set the current position to the mouse click point and
     // then paste in the PRIMARY selection, if any.  wxGTK only.
     int newPos = PositionFromLocation(pt);
-    MovePositionTo(newPos, noSel, true);
+    MovePositionTo(newPos, Selection::noSel, true);
 
-    pdoc->BeginUndoAction();
+/* C::B begin */
+    UndoGroup ug(pdoc);
+/* C::B end */
     wxTextDataObject data;
     bool gotData = false;
+    wxTheClipboard->UsePrimarySelection(true);
     if (wxTheClipboard->Open()) {
-        wxTheClipboard->UsePrimarySelection(true);
         gotData = wxTheClipboard->GetData(data);
-        wxTheClipboard->UsePrimarySelection(false);
         wxTheClipboard->Close();
     }
+    wxTheClipboard->UsePrimarySelection(false);
     if (gotData) {
-        wxString   text = wxTextBuffer::Translate(data.GetText(),
-                                                  wxConvertEOLMode(pdoc->eolMode));
+        wxString  text = wxTextBuffer::Translate(data.GetText(),
+                                                 wxConvertEOLMode(pdoc->eolMode));
         wxWX2MBbuf buf = (wxWX2MBbuf)wx2sci(text);
         int        len = strlen(buf);
-        pdoc->InsertString(currentPos, buf, len);
-        SetEmptySelection(currentPos + len);
+        int caretMain = sel.MainCaret();
+        pdoc->InsertString(caretMain, buf, len);
+        SetEmptySelection(caretMain + len);
     }
-    pdoc->EndUndoAction();
     NotifyChange();
     Redraw();
 
@@ -865,6 +1154,17 @@ void ScintillaWX::DoAddChar(int key) {
 int  ScintillaWX::DoKeyDown(const wxKeyEvent& evt, bool* consumed)
 {
     int key = evt.GetKeyCode();
+/* C::B begin */
+#if wxCHECK_VERSION(2, 9, 0)
+    if (key == WXK_NONE) {
+        // This is a Unicode character not representable in Latin-1 or some key
+        // without key code at all (e.g. dead key or VK_PROCESSKEY under MSW).
+        if ( consumed )
+            *consumed = false;
+        return 0;
+    }
+#endif
+/* C::B end */
     bool shift = evt.ShiftDown(),
          ctrl  = evt.ControlDown(),
          alt   = evt.AltDown();
@@ -873,26 +1173,26 @@ int  ScintillaWX::DoKeyDown(const wxKeyEvent& evt, bool* consumed)
         key += 'A' - 1;
 
     switch (key) {
-    case WXK_NUMPAD_DOWN:       // fall through
-    case WXK_DOWN:              key = SCK_DOWN;     break;
-    case WXK_NUMPAD_UP:         // fall through
-    case WXK_UP:                key = SCK_UP;       break;
-    case WXK_NUMPAD_LEFT:       // fall through
-    case WXK_LEFT:              key = SCK_LEFT;     break;
-    case WXK_NUMPAD_RIGHT:      // fall through
-    case WXK_RIGHT:             key = SCK_RIGHT;    break;
-    case WXK_NUMPAD_HOME:       // fall through
-    case WXK_HOME:              key = SCK_HOME;     break;
-    case WXK_NUMPAD_END:        // fall through
-    case WXK_END:               key = SCK_END;      break;
+    case WXK_DOWN:              // fall through
+    case WXK_NUMPAD_DOWN:       key = SCK_DOWN;     break;
+    case WXK_UP:                // fall through
+    case WXK_NUMPAD_UP:         key = SCK_UP;       break;
+    case WXK_LEFT:              // fall through
+    case WXK_NUMPAD_LEFT:       key = SCK_LEFT;     break;
+    case WXK_RIGHT:             // fall through
+    case WXK_NUMPAD_RIGHT:      key = SCK_RIGHT;    break;
+    case WXK_HOME:              // fall through
+    case WXK_NUMPAD_HOME:       key = SCK_HOME;     break;
+    case WXK_END:               // fall through
+    case WXK_NUMPAD_END:        key = SCK_END;      break;
 #if !wxCHECK_VERSION(2, 8, 0)
-    case WXK_PRIOR:     		// fall through
+    case WXK_PRIOR:             // fall through
     case WXK_NUMPAD_PRIOR:      // fall through
 #endif
     case WXK_PAGEUP:            // fall through
     case WXK_NUMPAD_PAGEUP:     key = SCK_PRIOR;    break;
 #if !wxCHECK_VERSION(2, 8, 0)
-    case WXK_NEXT:   			// fall through
+    case WXK_NEXT:              // fall through
     case WXK_NUMPAD_NEXT:       // fall through
 #endif
     case WXK_PAGEDOWN:          // fall through
@@ -915,7 +1215,7 @@ int  ScintillaWX::DoKeyDown(const wxKeyEvent& evt, bool* consumed)
     case WXK_CONTROL:           key = 0; break;
     case WXK_ALT:               key = 0; break;
     case WXK_SHIFT:             key = 0; break;
-    case WXK_MENU:              key = 0; break;
+    case WXK_MENU:              key = SCK_MENU;     break;
     }
 
 #ifdef __WXMAC__
@@ -970,7 +1270,7 @@ void ScintillaWX::DoOnIdle(wxIdleEvent& evt) {
 
 #if wxUSE_DRAG_AND_DROP
 bool ScintillaWX::DoDropText(long x, long y, const wxString& data) {
-    SetDragPosition(invalidPosition);
+    SetDragPosition(SelectionPosition(invalidPosition));
 
     wxString text = wxTextBuffer::Translate(data,
                                             wxConvertEOLMode(pdoc->eolMode));
@@ -987,10 +1287,12 @@ bool ScintillaWX::DoDropText(long x, long y, const wxString& data) {
 
     dragResult = evt.GetDragResult();
     if (dragResult == wxDragMove || dragResult == wxDragCopy) {
-        DropAt(evt.GetPosition(),
+        DropAt(SelectionPosition(evt.GetPosition()),
                wx2sci(evt.GetDragText()),
                dragResult == wxDragMove,
-               false); // TODO: rectangular?
+/* C::B begin */
+               dragRectangle);
+/* C::B end */
         return true;
     }
     return false;
@@ -1004,7 +1306,7 @@ wxDragResult ScintillaWX::DoDragEnter(wxCoord WXUNUSED(x), wxCoord WXUNUSED(y),
 
 
 wxDragResult ScintillaWX::DoDragOver(wxCoord x, wxCoord y, wxDragResult def) {
-    SetDragPosition(PositionFromLocation(Point(x, y)));
+    SetDragPosition(SelectionPosition(PositionFromLocation(Point(x, y))));
 
     // Send an event to allow the drag result to be changed
     wxScintillaEvent evt(wxEVT_SCI_DRAG_OVER, sci->GetId());
@@ -1021,20 +1323,11 @@ wxDragResult ScintillaWX::DoDragOver(wxCoord x, wxCoord y, wxDragResult def) {
 
 
 void ScintillaWX::DoDragLeave() {
-    SetDragPosition(invalidPosition);
+    SetDragPosition(SelectionPosition(invalidPosition));
 }
-#endif
+#endif // wxUSE_DRAG_AND_DROP
 //----------------------------------------------------------------------
 
-// Force the whole window to be repainted
-void ScintillaWX::FullPaint() {
-#ifndef __WXMAC__
-    sci->Refresh(false);
-#endif
-    sci->Update();
-}
-
-
 void ScintillaWX::DoScrollToLine(int line) {
     ScrollTo(line);
 }
@@ -1044,31 +1337,25 @@ void ScintillaWX::DoScrollToColumn(int column) {
     HorizontalScrollTo(column * vs.spaceWidth);
 }
 
-#ifdef __WXGTK__
-void ScintillaWX::ClipChildren(wxDC& dc, PRectangle rect) {
-// wxGTK > 2.5 doesn't appear to need this explicit clipping code any longer
-#if !wxCHECK_VERSION(2, 5, 0)
-    wxRegion rgn(wxRectFromPRectangle(rect));
-    if (ac.Active()) {
-        wxRect childRect = ((wxWindow*)ac.lb->GetID())->GetRect();
-        rgn.Subtract(childRect);
-    }
-    if (ct.inCallTipMode) {
-        wxSCICallTip* tip = (wxSCICallTip*)ct.wCallTip.GetID();
-        wxRect childRect = tip->GetRect();
-#if wxUSE_POPUPWIN && wxSCI_USE_POPUP
-        childRect.SetPosition(tip->GetMyPosition());
-#endif
-        rgn.Subtract(childRect);
-    }
-
-    dc.SetClippingRegion(rgn);
-#endif
+// wxGTK doesn't appear to need this explicit clipping code any longer, but I
+// will leave it here commented out for a while just in case...
+void ScintillaWX::ClipChildren(wxDC& WXUNUSED(dc), PRectangle WXUNUSED(rect))
+{
+//     wxRegion rgn(wxRectFromPRectangle(rect));
+//     if (ac.Active()) {
+//         wxRect childRect = ((wxWindow*)ac.lb->GetID())->GetRect();
+//         rgn.Subtract(childRect);
+//     }
+//     if (ct.inCallTipMode) {
+//         wxSCICallTip* tip = (wxSCICallTip*)ct.wCallTip.GetID();
+//         wxRect childRect = tip->GetRect();
+// #if wxUSE_POPUPWIN
+//         childRect.SetPosition(tip->GetMyPosition());
+// #endif
+//         rgn.Subtract(childRect);
+//     }
+//     dc.SetClippingRegion(rgn);
 }
-#else
-void ScintillaWX::ClipChildren(wxDC& WXUNUSED(dc), PRectangle WXUNUSED(rect)) {
-}
-#endif
 
 
 void ScintillaWX::SetUseAntiAliasing(bool useAA) {
@@ -1077,7 +1364,7 @@ void ScintillaWX::SetUseAntiAliasing(bool useAA) {
 }
 
 bool ScintillaWX::GetUseAntiAliasing() {
-    return vs.extraFontFlag;
+    return vs.extraFontFlag != 0;
 }
 
 //----------------------------------------------------------------------
