@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 4909 $
- * $Id: dlgaboutplugin.cpp 4909 2008-02-27 13:15:26Z mortenmacfly $
- * $HeadURL: svn://svn.berlios.de/codeblocks/tags/8.02/src/src/dlgaboutplugin.cpp $
+ * $Revision: 7468 $
+ * $Id: dlgaboutplugin.cpp 7468 2011-09-27 05:08:04Z jenslody $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/src/dlgaboutplugin.cpp $
  */
 
 #include "sdk.h"
@@ -22,7 +22,7 @@
 // class constructor
 dlgAboutPlugin::dlgAboutPlugin(wxWindow* parent, const PluginInfo* pi)
 {
-	wxXmlResource::Get()->LoadDialog(this, parent, _T("dlgAboutPlugin"));
+	wxXmlResource::Get()->LoadObject(this, parent, _T("dlgAboutPlugin"),_T("wxScrollingDialog"));
 
 	XRCCTRL(*this, "lblTitle", wxStaticText)->SetLabel(pi->title);
 	XRCCTRL(*this, "txtDescription", wxTextCtrl)->SetValue(pi->description);
