@@ -15,13 +15,14 @@ class cbSplashScreen : public wxFrame
 {
   private:
     wxBitmap m_label;
-    wxTimer m_timer;
-    wxRegion r;
+    wxTimer  m_timer;
+//    wxRegion m_region; // was used for 08/02 splash screen (transparent regions)
   public:
     // A value of -1 for timeout makes it stay forever (you need to close it manually)
     cbSplashScreen(wxBitmap &label, long timeout, wxWindow *parent, wxWindowID id, long style = wxSTAY_ON_TOP | wxNO_BORDER | wxFRAME_NO_TASKBAR | wxFRAME_SHAPED);
     ~cbSplashScreen();
 
+    static void DrawReleaseInfo(wxDC &dc);
   private:
     void DoPaint(wxDC &dc);
     void OnPaint(wxPaintEvent &);
