@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision$
- * $Id$
- * $HeadURL$
+ * $Revision: 9129 $
+ * $Id: mainframe.cpp 9129 2013-06-01 16:15:33Z mortenmacfly $
+ * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/tools/cb_share_config/mainframe.cpp $
  */
 
 #include "mainframe.h"
@@ -126,7 +126,7 @@ MainFrame::MainFrame(wxWindow* parent,wxWindowID id) :
 	bszMain->Fit(this);
 	bszMain->SetSizeHints(this);
 	Center();
-	
+
 	Connect(ID_BTN_FILE_SRC,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&MainFrame::OnBtnFileSrcClick);
 	Connect(ID_BTN_FILE_DST,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&MainFrame::OnBtnFileDstClick);
 	Connect(ID_BTN_TRANSFER,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&MainFrame::OnBtnTransferClick);
@@ -147,7 +147,7 @@ MainFrame::~MainFrame()
 
 //***********************************************************************
 
-void MainFrame::OnBtnFileSrcClick(wxCommandEvent& event)
+void MainFrame::OnBtnFileSrcClick(wxCommandEvent& /*event*/)
 {
   wxString filename = FileSelector();
   if (filename.IsEmpty() || SameConfig(filename, txtFileDst))
@@ -169,7 +169,7 @@ void MainFrame::OnBtnFileSrcClick(wxCommandEvent& event)
 
 //***********************************************************************
 
-void MainFrame::OnBtnFileDstClick(wxCommandEvent& event)
+void MainFrame::OnBtnFileDstClick(wxCommandEvent& /*event*/)
 {
   wxString filename = FileSelector();
   if (filename.IsEmpty() || SameConfig(filename, txtFileSrc))
@@ -177,6 +177,10 @@ void MainFrame::OnBtnFileDstClick(wxCommandEvent& event)
 
   if (!LoadConfig(filename, &mCfgDst) || !mCfgDst)
   {
+    wxMessageBox(wxT("Hint: To backup (export) your configuration use the \"Export\" button,\n"
+                     "to transfer to an existing (valid Code::Blocks) configuration file,\n"
+                     "use the \"Transfer\" button."),
+                 wxT("Information"), wxICON_INFORMATION | wxOK);
     mCfgDstValid = false;
     return;
   }
@@ -191,7 +195,7 @@ void MainFrame::OnBtnFileDstClick(wxCommandEvent& event)
 
 //***********************************************************************
 
-void MainFrame::OnBtnTransferClick(wxCommandEvent& event)
+void MainFrame::OnBtnTransferClick(wxCommandEvent& /*event*/)
 {
   if (mCfgSrcValid && mCfgDstValid)
   {
@@ -200,9 +204,9 @@ void MainFrame::OnBtnTransferClick(wxCommandEvent& event)
     {
       // Set all (checked) variables of lstEnvVars
       int items_selected = 0;
-      for (int i=0; i<clbCfgSrc->GetCount(); ++i)
+      for (int i = 0; i < static_cast<int>(clbCfgSrc->GetCount()); ++i)
       {
-        if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size()>i))
+        if (clbCfgSrc->IsChecked(i) && (static_cast<int>(mNodesSrc.size()) > i))
         {
           items_selected++;
 
@@ -245,15 +249,15 @@ void MainFrame::OnBtnTransferClick(wxCommandEvent& event)
 
 //***********************************************************************
 
-void MainFrame::OnBtnUncheckClick(wxCommandEvent& event)
+void MainFrame::OnBtnUncheckClick(wxCommandEvent& /*event*/)
 {
-  for (int i=0; i<clbCfgSrc->GetCount(); ++i)
+  for (int i=0; i < static_cast<int>(clbCfgSrc->GetCount()); ++i)
     clbCfgSrc->Check(i, false);
 }// OnBtnUncheckClick
 
 //***********************************************************************
 
-void MainFrame::OnBtnExportClick(wxCommandEvent& event)
+void MainFrame::OnBtnExportClick(wxCommandEvent& /*event*/)
 {
   TiXmlDocument* doc = new TiXmlDocument();
 
@@ -276,9 +280,9 @@ void MainFrame::OnBtnExportClick(wxCommandEvent& event)
 
       // Save all (checked) variables of lstEnvVars
       int items_selected = 0;
-      for (int i=0; i<clbCfgSrc->GetCount(); ++i)
+      for (int i=0; i < static_cast<int>(clbCfgSrc->GetCount()); ++i)
       {
-        if (clbCfgSrc->IsChecked(i) && (mNodesSrc.size()>i))
+        if (clbCfgSrc->IsChecked(i) && (static_cast<int>(mNodesSrc.size()) > i))
         {
           items_selected++;
 
@@ -287,9 +291,9 @@ void MainFrame::OnBtnExportClick(wxCommandEvent& event)
           wxArrayString path_arr = PathToArray(path);
 
           TiXmlElement* element  = root;
-          for (size_t i=0; i<path_arr.Count(); ++i)
+          for (size_t p=0; p<path_arr.Count(); ++p)
           {
-            wxString section_path = path_arr.Item(i);
+            wxString section_path = path_arr.Item(p);
             if (element->NoChildren())
             {
               // element has no children -> create new child named after section
@@ -351,7 +355,7 @@ void MainFrame::OnBtnExportClick(wxCommandEvent& event)
           wxT("*.conf"),                                          // default extension
           wxT("Code::Blocks configuration files (*.conf)|*.conf|"
               "All files (*.*)|*.*"),                             // wildcards
-          wxSAVE                                                  // flags
+          wxFD_SAVE                                               // flags
         );
         if (!filename.IsEmpty())
         {
@@ -385,7 +389,7 @@ void MainFrame::OnBtnExportClick(wxCommandEvent& event)
 
 //***********************************************************************
 
-void MainFrame::OnBtnSaveClick(wxCommandEvent& event)
+void MainFrame::OnBtnSaveClick(wxCommandEvent& /*event*/)
 {
   if (wxMessageBox(wxT("Are you sure to save destination configuration file?"),
                    wxT("Question"), wxICON_QUESTION | wxYES_NO | wxNO_DEFAULT ) == wxYES)
@@ -405,7 +409,7 @@ void MainFrame::OnBtnSaveClick(wxCommandEvent& event)
 
 //***********************************************************************
 
-void MainFrame::OnBtnCloseClick(wxCommandEvent& event)
+void MainFrame::OnBtnCloseClick(wxCommandEvent& /*event*/)
 {
 	Close();
 }// OnBtnCloseClick
@@ -416,7 +420,7 @@ wxString MainFrame::FileSelector()
 {
 #ifdef __WXMSW__
   TCHAR szPath[MAX_PATH];
-  SHGetFolderPath(NULL, CSIDL_APPDATA, NULL, 0, szPath);
+  SHGetFolderPath(NULL, CSIDL_APPDATA, 0, 0, szPath);
   wxString config_folder = wxString(szPath) + wxT("\\codeblocks");
 #else
   wxFileName f;
@@ -433,10 +437,7 @@ wxString MainFrame::FileSelector()
     wxT("*.conf"),                                   // default extension
     wxT("Code::Blocks configuration files (*.conf)|*.conf|"
         "All files (*.*)|*.*"),                      // wildcards
-    wxOPEN | wxFILE_MUST_EXIST                       // flags
-#if (WXWIN_COMPATIBILITY_2_4)
-    | wxHIDE_READONLY
-#endif
+    wxFD_OPEN | wxFD_FILE_MUST_EXIST                 // flags
   );
 
   return filename;
@@ -449,7 +450,7 @@ bool MainFrame::LoadConfig(const wxString& filename, TiXmlDocument** doc)
   if (*doc) delete *doc;
   *doc = new TiXmlDocument();
 
-  if(!TiXmlLoadDocument(filename, *doc))
+  if (!TiXmlLoadDocument(filename, *doc))
   {
     wxMessageBox(wxT("Error accessing configuration file!"),
                  wxT("Error"), wxICON_EXCLAMATION | wxOK);
@@ -465,7 +466,7 @@ bool MainFrame::LoadConfig(const wxString& filename, TiXmlDocument** doc)
     return false;
 
   const char *vers = docroot->Attribute("version");
-  if(!vers || atoi(vers) != 1)
+  if (!vers || atoi(vers) != 1)
   {
     wxMessageBox(wxT("Unknown config file version encountered!"),
                  wxT("Error"), wxICON_EXCLAMATION | wxOK);
@@ -508,7 +509,7 @@ void MainFrame::OfferConfig(TiXmlDocument* config, wxListBox* listbox,
   TiXmlNode* child = NULL;
   for (child = cfgroot->FirstChild(); child; child = child->NextSibling())
   {
-    if (child->Type()==TiXmlNode::ELEMENT)
+    if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
     {
       OfferNode(&child, listbox, nodes);
     }
@@ -521,75 +522,130 @@ void MainFrame::OfferNode(TiXmlNode** node,               wxListBox* listbox,
                           std::vector<TiXmlNode*> *nodes, const wxString& prefix)
 {
   wxString section((*node)->Value(), wxConvLocal);
+  const wxString &sectionLower = section.MakeLower();
 
-  if      (section.MakeLower().Matches(wxT("envvars")))     // envvar plugin variables
+  if      (sectionLower.Matches(wxT("auto_complete"))) // auto complete (abbreviations)
   {
     listbox->Append(wxT("<") + section + wxT(">"));
     nodes->push_back(*node);
   }
-  else if (section.MakeLower().Matches(wxT("gcv")))         // global variables
-  {
-    listbox->Append(wxT("<") + section + wxT(">"));
-    nodes->push_back(*node);
-  }
-  else if (section.MakeLower().Matches(wxT("help_plugin"))) // help plugin files
-  {
-    listbox->Append(wxT("<") + section + wxT(">"));
-    nodes->push_back(*node);
-  }
-  else if (section.MakeLower().Matches(wxT("tools")))       // tools setup by the user
-  {
-    listbox->Append(wxT("<") + section + wxT(">"));
-    nodes->push_back(*node);
-  }
-  else if (section.MakeLower().Matches(wxT("compiler")))    // compiler sets
+  else if (sectionLower.Matches(wxT("code_completion"))) // code completion plugin token replacements
   {
     TiXmlNode* child = NULL;
     for (child = (*node)->FirstChild(); child; child = child->NextSibling())
     {
-      if (child->Type()==TiXmlNode::ELEMENT)
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
+        OfferNode(&child, listbox, nodes, wxT("<code_completion>")); // recursive call
+    }
+  }
+  else if (sectionLower.Matches(wxT("compiler")))    // compiler sets
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node); // COMPLETE compiler section
+
+    TiXmlNode* child = NULL;
+    for (child = (*node)->FirstChild(); child; child = child->NextSibling())
+    {
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
         OfferNode(&child, listbox, nodes, wxT("<compiler>")); // recursive call
     }
   }
-  else if (section.MakeLower().Matches(wxT("editor")))      // editor colour sets
+  else if (sectionLower.Matches(wxT("debugger_common"))) // debugger common options
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node); // COMPLETE debugger section
+
+    TiXmlNode* child = NULL;
+    for (child = (*node)->FirstChild(); child; child = child->NextSibling())
+    {
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
+        OfferNode(&child, listbox, nodes, wxT("<debugger_common>")); // recursive call
+    }
+  }
+  else if (sectionLower.Matches(wxT("editor")))      // editor colour sets
   {
     TiXmlNode* child = NULL;
     for (child = (*node)->FirstChild(); child; child = child->NextSibling())
     {
-      if (child->Type()==TiXmlNode::ELEMENT)
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
         OfferNode(&child, listbox, nodes, wxT("<editor>")); // recursive call
     }
   }
-  else if (section.MakeLower().Matches(wxT("project_manager"))) // file groups
+  else if (sectionLower.Matches(wxT("envvars")))     // envvar plugin variables
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("gcv")))         // global variables
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("help_plugin"))) // help plugin files
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("mime_types")))  // mime types
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("plugins")))     // plugins
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("colours")))     // plugins
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  else if (sectionLower.Matches(wxT("project_manager"))) // file groups
   {
     TiXmlNode* child = NULL;
     for (child = (*node)->FirstChild(); child; child = child->NextSibling())
     {
-      if (child->Type()==TiXmlNode::ELEMENT)
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
         OfferNode(&child, listbox, nodes, wxT("<project_manager>")); // recursive call
     }
   }
+  else if (sectionLower.Matches(wxT("tools")))       // tools setup by the user
+  {
+    listbox->Append(wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+
+  // ----------------------------------------------------------
+  // 1st recursion level: code_completion -> token_replacements
+  // ----------------------------------------------------------
+  else if (   prefix.Matches(wxT("<code_completion>"))
+           && sectionLower.Matches(wxT("token_replacements")))// token replacements
+  {
+    listbox->Append(prefix + wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
 
   // -----------------------------------------------
   // 1st recursion level: compiler -> sets/user sets
   // -----------------------------------------------
   else if (   prefix.Matches(wxT("<compiler>"))
-           && section.MakeLower().Matches(wxT("sets")))     // compiler sets
+           && sectionLower.Matches(wxT("sets")))     // compiler sets
   {
     TiXmlNode* child = NULL;
     for (child = (*node)->FirstChild(); child; child = child->NextSibling())
     {
-      if (child->Type()==TiXmlNode::ELEMENT)
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
         OfferNode(&child, listbox, nodes, wxT("<compiler><sets>")); // recursive call
     }
   }
   else if (   prefix.Matches(wxT("<compiler>"))
-           && section.MakeLower().Matches(wxT("user_sets")))// compiler user sets
+           && sectionLower.Matches(wxT("user_sets")))// compiler user sets
   {
     TiXmlNode* child = NULL;
     for (child = (*node)->FirstChild(); child; child = child->NextSibling())
     {
-      if (child->Type()==TiXmlNode::ELEMENT)
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
         OfferNode(&child, listbox, nodes, wxT("<compiler><user_sets>")); // recursive call
     }
   }
@@ -612,11 +668,60 @@ void MainFrame::OfferNode(TiXmlNode** node,               wxListBox* listbox,
     nodes->push_back(*node);
   }
 
+  // --------------------------------------------
+  // 1st recursion level: debugger_common -> sets
+  // --------------------------------------------
+  else if (   prefix.Matches(wxT("<debugger_common>"))
+           && sectionLower.Matches(wxT("sets")))     // debugger sets
+  {
+    TiXmlNode* child = NULL;
+    for (child = (*node)->FirstChild(); child; child = child->NextSibling())
+    {
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
+        OfferNode(&child, listbox, nodes, wxT("<debugger_common><sets>")); // recursive call
+    }
+  }
+
+  // ---------------------------------------------------------------
+  // 2nd recursion level: debugger_common -> sets -> individual sets
+  // ---------------------------------------------------------------
+  else if (prefix.Matches(wxT("<debugger_common><sets>"))) // individual debugger sets
+  {
+    listbox->Append(prefix + wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+
   // ------------------------------------------
   // 1st recursion level: editor -> colour sets
   // ------------------------------------------
   else if (   prefix.Matches(wxT("<editor>"))
-           && section.MakeLower().Matches(wxT("colour_sets")))// colour sets
+           && sectionLower.Matches(wxT("colour_sets")))// colour sets
+  {
+    TiXmlNode* child = NULL;
+    for (child = (*node)->FirstChild(); child; child = child->NextSibling())
+    {
+      if (child->Type()==TiXmlNode::TINYXML_ELEMENT)
+        OfferNode(&child, listbox, nodes, wxT("<editor><colour_sets>")); // recursive call
+    }
+    listbox->Append(prefix + wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+  // --------------------------------------------------------
+  // 2st recursion level: editor -> colour sets -> theme name
+  // --------------------------------------------------------
+  else if (   prefix.Matches(wxT("<editor><colour_sets>"))
+           && !sectionLower.Matches(wxT("active_colour_set"))
+           && !sectionLower.Matches(wxT("active_lang"))) // colour sets themes
+  {
+    listbox->Append(prefix + wxT("<") + section + wxT(">"));
+    nodes->push_back(*node);
+  }
+
+  // -------------------------------------------
+  // 1st recursion level: editor -> default code
+  // -------------------------------------------
+  else if (   prefix.Matches(wxT("<editor>"))
+           && sectionLower.Matches(wxT("default_code")))// default code
   {
     listbox->Append(prefix + wxT("<") + section + wxT(">"));
     nodes->push_back(*node);
@@ -626,7 +731,7 @@ void MainFrame::OfferNode(TiXmlNode** node,               wxListBox* listbox,
   // 1st recursion level: project_manager -> file_groups
   // ---------------------------------------------------
   else if (   prefix.Matches(wxT("<project_manager>"))
-           && section.MakeLower().Matches(wxT("file_groups")))// file groups
+           && sectionLower.Matches(wxT("file_groups")))// file groups
   {
     listbox->Append(prefix + wxT("<") + section + wxT(">"));
     nodes->push_back(*node);
@@ -639,7 +744,6 @@ bool MainFrame::TransferNode(TiXmlNode** node, const wxArrayString& path)
 {
   if (!path.IsEmpty())
   {
-    int           level     = 0;
     TiXmlElement* element   = mCfgDst->FirstChildElement("CodeBlocksConfig");
     TiXmlNode*    node_copy = (*node)->Clone();
 
@@ -736,7 +840,7 @@ wxArrayString MainFrame::PathToArray(const wxString& path)
 
 bool MainFrame::TiXmlLoadDocument(const wxString& filename, TiXmlDocument*doc)
 {
-  if(!doc || !wxFile::Access(filename, wxFile::read))
+  if (!doc || !wxFile::Access(filename, wxFile::read))
     return false;
 
   wxFile file(filename);
@@ -763,8 +867,8 @@ bool MainFrame::TiXmlSaveDocument(const wxString& filename, TiXmlDocument* doc)
   doc->Accept(&printer);
 
   wxTempFile file(filename);
-  if(file.IsOpened())
-    if(file.Write(printer.CStr(), printer.Size()) && file.Commit())
+  if (file.IsOpened())
+    if (file.Write(printer.CStr(), printer.Size()) && file.Commit())
       return true;
 
   return false;
@@ -774,7 +878,7 @@ bool MainFrame::TiXmlSaveDocument(const wxString& filename, TiXmlDocument* doc)
 
 bool MainFrame::TiXmlSuccess(TiXmlDocument* doc)
 {
-  if(doc->ErrorId())
+  if (doc->ErrorId())
   {
     wxMessageBox(wxT("TinyXML error: ") +
 #if wxUSE_UNICODE
